@@ -149,19 +149,17 @@ enum TransparencyCodes {
 */
 class DRW_Coord {
 public:
-    DRW_Coord() { x = 0; y = 0; z = 0; }
-    DRW_Coord(double ix, double iy, double iz) {
-        x = ix; y = iy; z = iz;
-    }
+    DRW_Coord():x(0), y(0),z(0) {}
+    DRW_Coord(double ix, double iy, double iz): x(ix), y(iy),z(iz){}
 
-     DRW_Coord operator = (const DRW_Coord& data) {
+     DRW_Coord& operator = (const DRW_Coord& data) {
         x = data.x;  y = data.y;  z = data.z;
         return *this;
     }
 /*!< convert to unitary vector */
     void unitize(){
         double dist;
-        dist = sqrt(x*x + y*y + z*z);
+		dist = hypot(hypot(x, y), z);
         if (dist > 0.0) {
             x= x/dist;
             y= y/dist;
@@ -183,16 +181,9 @@ public:
 */
 class DRW_Vertex2D {
 public:
-    DRW_Vertex2D() {
-//        eType = DRW::LWPOLYLINE;
-        stawidth = endwidth = bulge = 0;
-    }
-    DRW_Vertex2D(double sx, double sy, double b) {
-        stawidth = endwidth = 0;
-        x = sx;
-        y =sy;
-        bulge = b;
-    }
+    DRW_Vertex2D(): x(0), y(0), stawidth(0), endwidth(0), bulge(0){}
+
+    DRW_Vertex2D(double sx, double sy, double b): x(sx), y(sy), stawidth(0), endwidth(0), bulge(b) {}
 
 public:
     double x;                 /*!< x coordinate, code 10 */
@@ -218,68 +209,61 @@ public:
         INVALID
     };
 //TODO: add INT64 support
-    DRW_Variant() {
-        type = INVALID;
-    }
+    DRW_Variant(): sdata(std::string()), vdata(), content(0), vType(INVALID), vCode(0) {}
 
-    DRW_Variant(int c, dint32 i) {
-        code = c; addInt(i);
-    }
-    DRW_Variant(int c, duint32 i) {
-        code = c; addInt(static_cast<dint32>(i));//RLZ: verify if worrk with big numbers
-    }
-    DRW_Variant(int c, double d) {
-        code = c; addDouble(d);
-    }
-    DRW_Variant(int c, UTF8STRING s) {
-        code = c; addString(s);
-    }
-    DRW_Variant(int c, DRW_Coord crd) {
-        code = c; addCoord(crd);
-    }
-    DRW_Variant(const DRW_Variant& d) {
-        code = d.code;
-        type = d.type;
-        content = d.content;
-        if (d.type == COORD) {
-            vdata = d.vdata;
+    DRW_Variant(int c, dint32 i): sdata(std::string()), vdata(), content(i), vType(INTEGER), vCode(c){}
+
+    DRW_Variant(int c, duint32 i): sdata(std::string()), vdata(), content(static_cast<dint32>(i)), vType(INTEGER), vCode(c) {}
+
+    DRW_Variant(int c, double d): sdata(std::string()), vdata(), content(d), vType(DOUBLE), vCode(c) {}
+
+    DRW_Variant(int c, UTF8STRING s): sdata(s), vdata(), content(&sdata), vType(STRING), vCode(c) {}
+
+    DRW_Variant(int c, DRW_Coord crd): sdata(std::string()), vdata(crd), content(&vdata), vType(COORD), vCode(c) {}
+
+    DRW_Variant(const DRW_Variant& d): sdata(d.sdata), vdata(d.vdata), content(d.content), vType(d.vType), vCode(d.vCode) {
+        if (d.vType == COORD)
             content.v = &vdata;
-        }
-        if (d.type == STRING) {
-            sdata = d.sdata;
+        if (d.vType == STRING)
             content.s = &sdata;
-        }
     }
 
     ~DRW_Variant() {
     }
 
-    void addString(UTF8STRING s) {setType(STRING); sdata = s; content.s = &sdata;}
-    void addInt(int i) {setType(INTEGER); content.i = i;}
-    void addDouble(double d) {setType(DOUBLE); content.d = d;}
-    void addCoord() {setType(COORD); vdata.x=0.0; vdata.y=0.0; vdata.z=0.0; content.v = &vdata;}
-    void addCoord(DRW_Coord v) {setType(COORD); vdata = v; content.v = &vdata;}
-    void setType(enum TYPE t) { type = t;}
-    void setCoordX(double d) { if (type == COORD) vdata.x = d;}
-    void setCoordY(double d) { if (type == COORD) vdata.y = d;}
-    void setCoordZ(double d) { if (type == COORD) vdata.z = d;}
-
-private:
-    typedef union {
-        UTF8STRING *s;
-        dint32 i;
-        double d;
-        DRW_Coord *v;
-    } DRW_VarContent;
-
-public:
-    DRW_VarContent content;
-    enum TYPE type;
-    int code;            /*!< dxf code of this value*/
+    void addString(int c, UTF8STRING s) {vType = STRING; sdata = s; content.s = &sdata; vCode=c;}
+    void addInt(int c, int i) {vType = INTEGER; content.i = i; vCode=c;}
+    void addDouble(int c, double d) {vType = DOUBLE; content.d = d; vCode=c;}
+    void addCoord(int c, DRW_Coord v) {vType = COORD; vdata = v; content.v = &vdata; vCode=c;}
+    void setCoordX(double d) { if (vType == COORD) vdata.x = d;}
+    void setCoordY(double d) { if (vType == COORD) vdata.y = d;}
+    void setCoordZ(double d) { if (vType == COORD) vdata.z = d;}
+    enum TYPE type() { return vType;}
+    int code() { return vCode;}            /*!< returns dxf code of this value*/
 
 private:
     std::string sdata;
     DRW_Coord vdata;
+
+private:
+    union DRW_VarContent{
+        UTF8STRING *s;
+        dint32 i;
+        double d;
+        DRW_Coord *v;
+
+        DRW_VarContent(UTF8STRING *sd):s(sd){}
+        DRW_VarContent(dint32 id):i(id){}
+        DRW_VarContent(double dd):d(dd){}
+        DRW_VarContent(DRW_Coord *vd):v(vd){}
+    };
+
+public:
+    DRW_VarContent content;
+private:
+    enum TYPE vType;
+    int vCode;            /*!< dxf code of this value*/
+
 };
 
 //! Class to handle dwg handles
