@@ -38,84 +38,66 @@ void DRW_Header::parseCode(int code, dxfReader *reader){
         vars[name]=curr;
         break;
     case 1:
-        curr->addString(reader->getUtf8String());
+        curr->addString(code, reader->getUtf8String());
         if (name =="$ACADVER") {
             reader->setVersion(curr->content.s, true);
             version = reader->getVersion();
         }
-        curr->code = code;
         break;
     case 2:
-        curr->addString(reader->getUtf8String());
-        curr->code = code;
+        curr->addString(code, reader->getUtf8String());
         break;
     case 3:
-        curr->addString(reader->getUtf8String());
+        curr->addString(code, reader->getUtf8String());
         if (name =="$DWGCODEPAGE") {
             reader->setCodePage(curr->content.s);
-            curr->addString(reader->getCodePage());
+            curr->addString(code, reader->getCodePage());
         }
-        curr->code = code;
         break;
     case 6:
-        curr->addString(reader->getUtf8String());
-        curr->code = code;
+        curr->addString(code, reader->getUtf8String());
         break;
     case 7:
-        curr->addString(reader->getUtf8String());
-        curr->code = code;
+        curr->addString(code, reader->getUtf8String());
         break;
     case 8:
-        curr->addString(reader->getUtf8String());
-        curr->code = code;
+        curr->addString(code, reader->getUtf8String());
         break;
     case 10:
-        curr->addCoord();
-        curr->setCoordX(reader->getDouble());
-        curr->code = code;
+        curr->addCoord(code, DRW_Coord(reader->getDouble(), 0.0, 0.0));
         break;
     case 20:
         curr->setCoordY(reader->getDouble());
         break;
     case 30:
         curr->setCoordZ(reader->getDouble());
-        curr->code = code;
         break;
     case 40:
-        curr->addDouble(reader->getDouble());
-        curr->code = code;
+        curr->addDouble(code, reader->getDouble());
         break;
     case 50:
-        curr->addDouble(reader->getDouble());
-        curr->code = code;
+        curr->addDouble(code, reader->getDouble());
         break;
     case 62:
-        curr->addInt(reader->getInt32());
-        curr->code = code;
+        curr->addInt(code, reader->getInt32());
         break;
     case 70:
-        curr->addInt(reader->getInt32());
-        curr->code = code;
+        curr->addInt(code, reader->getInt32());
         break;
     case 280:
-        curr->addInt(reader->getInt32());
-        curr->code = code;
+        curr->addInt(code, reader->getInt32());
         break;
     case 290:
-        curr->addInt(reader->getInt32());
-        curr->code = code;
+        curr->addInt(code, reader->getInt32());
         break;
     case 370:
-        curr->addInt(reader->getInt32());
-        curr->code = code;
+        curr->addInt(code, reader->getInt32());
         break;
     case 380:
-        curr->addInt(reader->getInt32());
-        curr->code = code;
+        curr->addInt(code, reader->getInt32());
         break;
     case 390:
-        curr->addString(reader->getUtf8String());
-        curr->code = code;
+        curr->addString(code, reader->getUtf8String());
         break;
     default:
         break;
@@ -1687,30 +1669,22 @@ void DRW_Header::write(dxfWriter *writer, DRW::Version ver){
 }
 
 void DRW_Header::addDouble(std::string key, double value, int code){
-    curr = new DRW_Variant();
-    curr->addDouble( value );
-    curr->code = code;
+    curr = new DRW_Variant(code, value);
     vars[key] =curr;
 }
 
 void DRW_Header::addInt(std::string key, int value, int code){
-    curr = new DRW_Variant();
-    curr->addInt( value );
-    curr->code = code;
+    curr = new DRW_Variant(code, value);
     vars[key] =curr;
 }
 
 void DRW_Header::addStr(std::string key, std::string value, int code){
-    curr = new DRW_Variant();
-    curr->addString( value );
-    curr->code = code;
+    curr = new DRW_Variant(code, value);
     vars[key] =curr;
 }
 
 void DRW_Header::addCoord(std::string key, DRW_Coord value, int code){
-    curr = new DRW_Variant();
-    curr->addCoord( value );
-    curr->code = code;
+    curr = new DRW_Variant(code, value);
     vars[key] =curr;
 }
 
@@ -1720,7 +1694,7 @@ bool DRW_Header::getDouble(std::string key, double *varDouble){
     it=vars.find( key);
     if (it != vars.end()) {
         DRW_Variant *var = (*it).second;
-        if (var->type == DRW_Variant::DOUBLE) {
+        if (var->type() == DRW_Variant::DOUBLE) {
             *varDouble = var->content.d;
             result = true;
         }
@@ -1736,7 +1710,7 @@ bool DRW_Header::getInt(std::string key, int *varInt){
     it=vars.find( key);
     if (it != vars.end()) {
         DRW_Variant *var = (*it).second;
-        if (var->type == DRW_Variant::INTEGER) {
+        if (var->type() == DRW_Variant::INTEGER) {
             *varInt = var->content.i;
             result = true;
         }
@@ -1752,7 +1726,7 @@ bool DRW_Header::getStr(std::string key, std::string *varStr){
     it=vars.find( key);
     if (it != vars.end()) {
         DRW_Variant *var = (*it).second;
-        if (var->type == DRW_Variant::STRING) {
+        if (var->type() == DRW_Variant::STRING) {
             *varStr = *var->content.s;
             result = true;
         }
@@ -1768,7 +1742,7 @@ bool DRW_Header::getCoord(std::string key, DRW_Coord *varCoord){
     it=vars.find( key);
     if (it != vars.end()) {
         DRW_Variant *var = (*it).second;
-        if (var->type == DRW_Variant::COORD) {
+        if (var->type() == DRW_Variant::COORD) {
             *varCoord = *var->content.v;
             result = true;
         }
@@ -2391,7 +2365,7 @@ bool DRW_Header::parseDwg(DRW::Version version, dwgBuffer *buf, dwgBuffer *hBbuf
     if (DRW_DBGGL == DRW_dbg::DEBUG){
         for (std::map<std::string,DRW_Variant*>::iterator it=vars.begin(); it!=vars.end(); ++it){
             DRW_DBG("\n"); DRW_DBG(it->first); DRW_DBG(": ");
-            switch (it->second->type){
+            switch (it->second->type()){
             case DRW_Variant::INTEGER:
                 DRW_DBG(it->second->content.i);
                 break;
@@ -2409,7 +2383,7 @@ bool DRW_Header::parseDwg(DRW::Version version, dwgBuffer *buf, dwgBuffer *hBbuf
             default:
                 break;
             }
-             DRW_DBG(" code: ");DRW_DBG(it->second->code);
+             DRW_DBG(" code: ");DRW_DBG(it->second->code());
         }
     }
 
@@ -2426,8 +2400,9 @@ bool DRW_Header::parseDwg(DRW::Version version, dwgBuffer *buf, dwgBuffer *hBbuf
     }
 
     //temporary code to show header end sentinel
-    duint64 sz= buf->size()-1;
-    if (version < DRW::AC1018) {//pre 2004
+//    duint64 sz= buf->size()-1;
+	duint64 sz;
+	if (version < DRW::AC1018) {//pre 2004
         sz= buf->size()-16;
         buf->setPosition(sz);
         DRW_DBG("\nseting position to: "); DRW_DBG(buf->getPosition());
