@@ -15,46 +15,44 @@
 #include <fstream>
 #include <string>
 #include <sstream>
+#include <map>
 #include "dwgreader.h"
 #include "drw_textcodec.h"
 #include "drw_dbg.h"
+namespace {
+//helper function to cleanup pointers in Look Up Tables
+template<typename T>
+void mapCleanUp(std::map<duint32, T*>& table)
+{
+	for (auto& item: table)
+		delete item.second;
+}
+}
 
 dwgReader::~dwgReader(){
-    for (std::map<duint32, DRW_LType*>::iterator it=ltypemap.begin(); it!=ltypemap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Layer*>::iterator it=layermap.begin(); it!=layermap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Block*>::iterator it=blockmap.begin(); it!=blockmap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Textstyle*>::iterator it=stylemap.begin(); it!=stylemap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Dimstyle*>::iterator it=dimstylemap.begin(); it!=dimstylemap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Vport*>::iterator it=vportmap.begin(); it!=vportmap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Class*>::iterator it=classesmap.begin(); it!=classesmap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_Block_Record*>::iterator it=blockRecordmap.begin(); it!=blockRecordmap.end(); ++it)
-        delete(it->second);
-    for (std::map<duint32, DRW_AppId*>::iterator it=appIdmap.begin(); it!=appIdmap.end(); ++it)
-        delete(it->second);
-
-    delete fileBuf;
+	mapCleanUp(ltypemap);
+	mapCleanUp(layermap);
+	mapCleanUp(blockmap);
+	mapCleanUp(stylemap);
+	mapCleanUp(dimstylemap);
+	mapCleanUp(vportmap);
+	mapCleanUp(classesmap);
+	mapCleanUp(blockRecordmap);
+	mapCleanUp(appIdmap);
 }
 
 void dwgReader::parseAttribs(DRW_Entity* e){
-    if (e != NULL){
-        duint32 ltref =e->lTypeH.ref;
-        duint32 lyref =e->layerH.ref;
-        std::map<duint32, DRW_LType*>::iterator lt_it = ltypemap.find(ltref);
-        if (lt_it != ltypemap.end()){
-            e->lineType = (lt_it->second)->name;
-        }
-        std::map<duint32, DRW_Layer*>::iterator ly_it = layermap.find(lyref);
-        if (ly_it != layermap.end()){
-            e->layer = (ly_it->second)->name;
-        }
-    }
+	if (!e) return;
+	duint32 ltref =e->lTypeH.ref;
+	duint32 lyref =e->layerH.ref;
+	std::map<duint32, DRW_LType*>::iterator lt_it = ltypemap.find(ltref);
+	if (lt_it != ltypemap.end()){
+		e->lineType = (lt_it->second)->name;
+	}
+	std::map<duint32, DRW_Layer*>::iterator ly_it = layermap.find(lyref);
+	if (ly_it != layermap.end()){
+		e->layer = (ly_it->second)->name;
+	}
 }
 
 std::string dwgReader::findTableName(DRW::TTYPE table, dint32 handle){
@@ -98,14 +96,14 @@ std::string dwgReader::findTableName(DRW::TTYPE table, dint32 handle){
     return name;
 }
 
-bool dwgReader::readDwgHeader(DRW_Header& hdr, dwgBuffer *buf, dwgBuffer *hBuf){
+bool dwgReader::readDwgHeader(DRW_Header& hdr, dwgBuffer* buf, dwgBuffer* hBuf){
     bool ret = hdr.parseDwg(version, buf, hBuf, maintenanceVersion);
     //RLZ: copy objectControl handles
     return ret;
 }
 
 //RLZ: TODO add check instead print
-bool dwgReader::checkSentinel(dwgBuffer *buf, enum secEnum::DWGSection, bool start){
+bool dwgReader::checkSentinel(dwgBuffer* buf, enum secEnum::DWGSection, bool start){
     DRW_UNUSED(start);
     for (int i=0; i<16;i++) {
         DRW_DBGH(buf->getRawChar8()); DRW_DBG(" ");
@@ -120,7 +118,7 @@ bool dwgReader::checkSentinel(dwgBuffer *buf, enum secEnum::DWGSection, bool sta
  *  2 bytes size + data bytes
  *  last section are 2 bytes size + 2 bytes crc (size value always 2)
 **/
-bool dwgReader::readDwgHandles(dwgBuffer *dbuf, duint32 offset, duint32 size) {
+bool dwgReader::readDwgHandles(dwgBuffer* dbuf, duint32 offset, duint32 size) {
     DRW_DBG("\ndwgReader::readDwgHandles\n");
     if (!dbuf->setPosition(offset))
         return false;
@@ -132,14 +130,15 @@ bool dwgReader::readDwgHandles(dwgBuffer *dbuf, duint32 offset, duint32 size) {
 
     int startPos = offset;
 
-    while (maxPos > dbuf->getPosition()) {
+	std::vector<duint8> tmpByteStr;
+	while (maxPos > dbuf->getPosition()) {
         DRW_DBG("\nstart handles section buf->curPosition()= "); DRW_DBG(dbuf->getPosition()); DRW_DBG("\n");
         duint16 size = dbuf->getBERawShort16();
         DRW_DBG("object map section size= "); DRW_DBG(size); DRW_DBG("\n");
         dbuf->setPosition(startPos);
-        duint8 *tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         if (size != 2){
             buff.setPosition(2);
             int lastHandle = 0;
@@ -155,7 +154,6 @@ bool dwgReader::readDwgHandles(dwgBuffer *dbuf, duint32 offset, duint32 size) {
         }
         //verify crc
         duint16 crcCalc = buff.crc8(0xc0c1,0,size);
-        delete[]tmpByteStr;
         duint16 crcRead = dbuf->getBERawShort16();
         DRW_DBG("object map section crc8 read= "); DRW_DBG(crcRead);
         DRW_DBG("\nobject map section crc8 calculated= "); DRW_DBG(crcCalc);
@@ -172,7 +170,7 @@ bool dwgReader::readDwgHandles(dwgBuffer *dbuf, duint32 offset, duint32 size) {
  * Reads all the object referenced in the object map section of the DWG file
  * (using their object file offsets)
  */
-bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
+bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer* dbuf) {
     DRW_DBG("\ndwgReader::readDwgTables start\n");
     bool ret = true;
     bool ret2 = true;
@@ -180,7 +178,7 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
     std::map<duint32, objHandle>::iterator mit;
     dint16 oType;
     duint32 bs = 0; //bit size of handle stream 2010+
-    duint8 *tmpByteStr;
+	std::vector<duint8> tmpByteStr;
 
     //parse linetypes, start with linetype Control
     mit = ObjectMap.find(hdr.linetypeCtrl);
@@ -198,9 +196,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[csize];
-        dbuf->getBytes(tmpByteStr, csize);
-        dwgBuffer cbuff(tmpByteStr, csize, &decoder);
+		tmpByteStr.resize(csize);
+		dbuf->getBytes(tmpByteStr.data(), csize);
+		dwgBuffer cbuff(tmpByteStr.data(), csize, &decoder);
         //verify if object are correct
         oType = cbuff.getObjType(version);
         if (oType != 0x38) {
@@ -213,7 +211,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             if(ret)
                 ret = ret2;
         }
-        delete[]tmpByteStr;
         for (std::list<duint32>::iterator it=ltControl.hadlesList.begin(); it != ltControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -231,14 +228,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[lsize];
-                dbuf->getBytes(tmpByteStr, lsize);
-                dwgBuffer lbuff(tmpByteStr, lsize, &decoder);
+				tmpByteStr.resize(lsize);
+				dbuf->getBytes(tmpByteStr.data(), lsize);
+				dwgBuffer lbuff(tmpByteStr.data(), lsize, &decoder);
                 ret2 = lt->parseDwg(version, &lbuff, bs);
                 ltypemap[lt->handle] = lt;
                 if(ret)
                     ret = ret2;
-                delete[]tmpByteStr;
             }
         }
     }
@@ -259,9 +255,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         //verify if object are correct
         oType = buff.getObjType(version);
         if (oType != 0x32) {
@@ -274,7 +270,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             if(ret)
                 ret = ret2;
         }
-        delete[]tmpByteStr;
         for (std::list<duint32>::iterator it=layControl.hadlesList.begin(); it != layControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -291,14 +286,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 ret2 = la->parseDwg(version, &buff, bs);
                 layermap[la->handle] = la;
                 if(ret)
-                    ret = ret2;
-                delete[]tmpByteStr;
+					ret = ret2;
             }
         }
     }
@@ -329,9 +323,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         //verify if object are correct
         oType = buff.getObjType(version);
         if (oType != 0x34) {
@@ -344,7 +338,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             if(ret)
                 ret = ret2;
         }
-        delete[]tmpByteStr;
         for (std::list<duint32>::iterator it=styControl.hadlesList.begin(); it != styControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -361,14 +354,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 ret2 = sty->parseDwg(version, &buff, bs);
                 stylemap[sty->handle] = sty;
                 if(ret)
-                    ret = ret2;
-                delete[]tmpByteStr;
+					ret = ret2;
             }
         }
     }
@@ -389,9 +381,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         //verify if object are correct
         oType = buff.getObjType(version);
         if (oType != 0x44) {
@@ -404,7 +396,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             if(ret)
                 ret = ret2;
         }
-        delete[]tmpByteStr;
         for (std::list<duint32>::iterator it=dimstyControl.hadlesList.begin(); it != dimstyControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -421,14 +412,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 ret2 = sty->parseDwg(version, &buff, bs);
                 dimstylemap[sty->handle] = sty;
                 if(ret)
-                    ret = ret2;
-                delete[]tmpByteStr;
+					ret = ret2;
             }
         }
     }
@@ -449,9 +439,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         //verify if object are correct
         oType = buff.getObjType(version);
         if (oType != 0x40) {
@@ -464,7 +454,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             if(ret)
                 ret = ret2;
         }
-        delete[]tmpByteStr;
         for (std::list<duint32>::iterator it=vportControl.hadlesList.begin(); it != vportControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -481,14 +470,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 ret2 = vp->parseDwg(version, &buff, bs);
                 vportmap[vp->handle] = vp;
                 if(ret)
-                    ret = ret2;
-                delete[]tmpByteStr;
+					ret = ret2;
             }
         }
     }
@@ -509,9 +497,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[csize];
-        dbuf->getBytes(tmpByteStr, csize);
-        dwgBuffer buff(tmpByteStr, csize, &decoder);
+		tmpByteStr.resize(csize);
+		dbuf->getBytes(tmpByteStr.data(), csize);
+		dwgBuffer buff(tmpByteStr.data(), csize, &decoder);
         //verify if object are correct
         oType = buff.getObjType(version);
         if (oType != 0x30) {
@@ -523,8 +511,7 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             ret2 = blockControl.parseDwg(version, &buff, bs);
             if(ret)
                 ret = ret2;
-        }
-        delete[]tmpByteStr;
+		}
         for (std::list<duint32>::iterator it=blockControl.hadlesList.begin(); it != blockControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -541,14 +528,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 ret2 = br->parseDwg(version, &buff, bs);
                 blockRecordmap[br->handle] = br;
                 if(ret)
-                    ret = ret2;
-                delete[]tmpByteStr;
+					ret = ret2;
             }
         }
     }
@@ -570,9 +556,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         //verify if object are correct
         oType = buff.getObjType(version);
         if (oType != 0x42) {
@@ -585,7 +571,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
             if(ret)
                 ret = ret2;
         }
-        delete[]tmpByteStr;
         for (std::list<duint32>::iterator it=appIdControl.hadlesList.begin(); it != appIdControl.hadlesList.end(); ++it){
             mit = ObjectMap.find(*it);
             if (mit==ObjectMap.end()) {
@@ -602,14 +587,13 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     bs = dbuf->getUModularChar();
                 else
                     bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 ret2 = ai->parseDwg(version, &buff, bs);
                 appIdmap[ai->handle] = ai;
                 if(ret)
                     ret = ret2;
-                delete[]tmpByteStr;
             }
         }
     }
@@ -632,9 +616,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                 bs = dbuf->getUModularChar();
             else
                 bs = 0;
-            tmpByteStr = new duint8[size];
-            dbuf->getBytes(tmpByteStr, size);
-            dwgBuffer buff(tmpByteStr, size, &decoder);
+			tmpByteStr.resize(size);
+			dbuf->getBytes(tmpByteStr.data(), size);
+			dwgBuffer buff(tmpByteStr.data(), size, &decoder);
             //verify if object are correct
             oType = buff.getObjType(version);
             if (oType != 0x3C) {
@@ -647,7 +631,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                 if(ret)
                     ret = ret2;
             }
-            delete[]tmpByteStr;
         }
 
         mit = ObjectMap.find(hdr.ucsCtrl);
@@ -666,9 +649,9 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                 bs = dbuf->getUModularChar();
             else
                 bs = 0;
-            tmpByteStr = new duint8[size];
-            dbuf->getBytes(tmpByteStr, size);
-            dwgBuffer buff(tmpByteStr, size, &decoder);
+			tmpByteStr.resize(size);
+			dbuf->getBytes(tmpByteStr.data(), size);
+			dwgBuffer buff(tmpByteStr.data(), size, &decoder);
             //verify if object are correct
             oType = buff.getObjType(version);
             if (oType != 0x3E) {
@@ -681,7 +664,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                 if(ret)
                     ret = ret2;
             }
-            delete[]tmpByteStr;
         }
 
         if (version < DRW::AC1018) {//r2000-
@@ -698,12 +680,11 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                 dbuf->setPosition(oc.loc);
                 int size = dbuf->getModularShort();
                 if (version > DRW::AC1021) //2010+
-                    bs = dbuf->getUModularChar();
-                else
-                    bs = 0;
-                tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+					/*bs =*/ dbuf->getUModularChar();
+//                else bs = 0;
+				tmpByteStr.resize(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 //verify if object are correct
                 oType = buff.getObjType(version);
                 if (oType != 0x46) {
@@ -716,7 +697,6 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
                     if(ret)
                         ret = ret2;*/
                 }
-                delete[]tmpByteStr;
             }
         }
     }
@@ -724,11 +704,10 @@ bool dwgReader::readDwgTables(DRW_Header& hdr, dwgBuffer *dbuf) {
     return ret;
 }
 
-bool dwgReader::readDwgBlocks(DRW_Interface& intfa, dwgBuffer *dbuf){
+bool dwgReader::readDwgBlocks(DRW_Interface& intfa, dwgBuffer* dbuf){
     bool ret = true;
     bool ret2 = true;
     duint32 bs =0;
-    duint8 *tmpByteStr;
     std::map<duint32, objHandle>::iterator mit;
     DRW_DBG("\nobject map total size= "); DRW_DBG(ObjectMap.size());
 
@@ -755,12 +734,12 @@ bool dwgReader::readDwgBlocks(DRW_Interface& intfa, dwgBuffer *dbuf){
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+
+		std::vector<duint8> tmpByteStr(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         DRW_Block bk;
         ret2 = bk.parseDwg(version, &buff, bs);
-        delete[]tmpByteStr;
         ret = ret && ret2;
         parseAttribs(&bk);
         //complete block entity with block record data
@@ -832,13 +811,12 @@ bool dwgReader::readDwgBlocks(DRW_Interface& intfa, dwgBuffer *dbuf){
             bs = dbuf->getUModularChar();
         else
             bs = 0;
-        tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
-        dwgBuffer buff1(tmpByteStr, size, &decoder);
+		tmpByteStr.resize(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
+		dwgBuffer buff1(tmpByteStr.data(), size, &decoder);
         DRW_Block end;
         end.isEnd = true;
         ret2 = end.parseDwg(version, &buff1, bs);
-        delete[]tmpByteStr;
         ret = ret && ret2;
         if (bk.parentHandle == DRW::NoHandle) bk.parentHandle= bkr->handle;
         parseAttribs(&end);
@@ -848,7 +826,7 @@ bool dwgReader::readDwgBlocks(DRW_Interface& intfa, dwgBuffer *dbuf){
     return ret;
 }
 
-bool dwgReader::readPlineVertex(DRW_Polyline& pline, dwgBuffer *dbuf){
+bool dwgReader::readPlineVertex(DRW_Polyline& pline, dwgBuffer* dbuf){
     bool ret = true;
     bool ret2 = true;
     objHandle oc;
@@ -874,14 +852,13 @@ bool dwgReader::readPlineVertex(DRW_Polyline& pline, dwgBuffer *dbuf){
                 if (version > DRW::AC1021) {//2010+
                     bs = dbuf->getUModularChar();
                 }
-                duint8 *tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				std::vector<duint8> tmpByteStr(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 dint16 oType = buff.getObjType(version);
                 buff.resetPosition();
                 DRW_DBG(" object type= "); DRW_DBG(oType); DRW_DBG("\n");
                 ret2 = vt.parseDwg(version, &buff, bs, pline.basePoint.z);
-                delete[]tmpByteStr;
                 pline.addVertex(vt);
                 nextEntLink = vt.nextEntLink; \
                 prevEntLink = vt.prevEntLink;
@@ -911,14 +888,13 @@ bool dwgReader::readPlineVertex(DRW_Polyline& pline, dwgBuffer *dbuf){
                 if (version > DRW::AC1021) {//2010+
                     bs = dbuf->getUModularChar();
                 }
-                duint8 *tmpByteStr = new duint8[size];
-                dbuf->getBytes(tmpByteStr, size);
-                dwgBuffer buff(tmpByteStr, size, &decoder);
+				std::vector<duint8> tmpByteStr(size);
+				dbuf->getBytes(tmpByteStr.data(), size);
+				dwgBuffer buff(tmpByteStr.data(), size, &decoder);
                 dint16 oType = buff.getObjType(version);
                 buff.resetPosition();
                 DRW_DBG(" object type= "); DRW_DBG(oType); DRW_DBG("\n");
                 ret2 = vt.parseDwg(version, &buff, bs, pline.basePoint.z);
-                delete[]tmpByteStr;
                 pline.addVertex(vt);
                 nextEntLink = vt.nextEntLink; \
                 prevEntLink = vt.prevEntLink;
@@ -932,11 +908,12 @@ bool dwgReader::readPlineVertex(DRW_Polyline& pline, dwgBuffer *dbuf){
     return ret;
 }
 
-bool dwgReader::readDwgEntities(DRW_Interface& intfa, dwgBuffer *dbuf){
+bool dwgReader::readDwgEntities(DRW_Interface& intfa, dwgBuffer* dbuf){
     bool ret = true;
     bool ret2 = true;
 
     DRW_DBG("\nobject map total size= "); DRW_DBG(ObjectMap.size());
+
     std::map<duint32, objHandle>::iterator itB=ObjectMap.begin();
     std::map<duint32, objHandle>::iterator itE=ObjectMap.end();
     while (itB != itE){
@@ -952,7 +929,7 @@ bool dwgReader::readDwgEntities(DRW_Interface& intfa, dwgBuffer *dbuf){
 /**
  * Reads a dwg drawing entity (dwg object entity) given its offset in the file
  */
-bool dwgReader::readDwgEntity(dwgBuffer *dbuf, objHandle& obj, DRW_Interface& intfa){
+bool dwgReader::readDwgEntity(dwgBuffer* dbuf, objHandle& obj, DRW_Interface& intfa){
     bool ret = true;
     duint32 bs = 0;
 
@@ -973,15 +950,14 @@ bool dwgReader::readDwgEntity(dwgBuffer *dbuf, objHandle& obj, DRW_Interface& in
         if (version > DRW::AC1021) {//2010+
             bs = dbuf->getUModularChar();
         }
-        duint8 *tmpByteStr = new duint8[size];
-        dbuf->getBytes(tmpByteStr, size);
+		std::vector<duint8> tmpByteStr(size);
+		dbuf->getBytes(tmpByteStr.data(), size);
         //verify if getBytes is ok:
         if (!dbuf->isGood()){
             DRW_DBG(" Warning: readDwgEntity, bad size\n");
-            delete[]tmpByteStr;
             return false;
         }
-        dwgBuffer buff(tmpByteStr, size, &decoder);
+		dwgBuffer buff(tmpByteStr.data(), size, &decoder);
         dint16 oType = buff.getObjType(version);
         buff.resetPosition();
 
@@ -989,7 +965,6 @@ bool dwgReader::readDwgEntity(dwgBuffer *dbuf, objHandle& obj, DRW_Interface& in
             std::map<duint32, DRW_Class*>::iterator it = classesmap.find(oType);
             if (it == classesmap.end()){//fail, not found in classes set error
                 DRW_DBG("Class "); DRW_DBG(oType);DRW_DBG("not found, handle: "); DRW_DBG(obj.handle); DRW_DBG("\n");
-                delete[]tmpByteStr;
                 return false;
             } else {
                 DRW_Class *cl = it->second;
@@ -1164,11 +1139,10 @@ bool dwgReader::readDwgEntity(dwgBuffer *dbuf, objHandle& obj, DRW_Interface& in
         if (!ret){
             DRW_DBG("Warning: Entity type "); DRW_DBG(oType);DRW_DBG("has failed, handle: "); DRW_DBG(obj.handle); DRW_DBG("\n");
         }
-        delete[]tmpByteStr;
     return ret;
 }
 
-bool dwgReader::readDwgObjects(DRW_Interface& intfa, dwgBuffer *dbuf){
+bool dwgReader::readDwgObjects(DRW_Interface& intfa, dwgBuffer*  dbuf){
     bool ret = true;
     bool ret2 = true;
 
@@ -1197,7 +1171,7 @@ bool dwgReader::readDwgObjects(DRW_Interface& intfa, dwgBuffer *dbuf){
 /**
  * Reads a dwg drawing object (dwg object object) given its offset in the file
  */
-bool dwgReader::readDwgObject(dwgBuffer *dbuf, objHandle& obj, DRW_Interface& intfa){
+bool dwgReader::readDwgObject(dwgBuffer* dbuf, objHandle& obj, DRW_Interface& intfa){
     bool ret = true;
     duint32 bs = 0;
 
@@ -1243,7 +1217,7 @@ bool dwgReader::readDwgObject(dwgBuffer *dbuf, objHandle& obj, DRW_Interface& in
 
 
 
-bool DRW_ObjControl::parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs){
+bool DRW_ObjControl::parseDwg(DRW::Version version, dwgBuffer* buf, duint32 bs){
 int unkData=0;
     bool ret = DRW_TableEntry::parseDwg(version, buf, NULL, bs);
     DRW_DBG("\n***************************** parsing object control entry *********************************************\n");
