@@ -31,6 +31,8 @@
 #include "rs_graphic.h"
 #include "rs_debug.h"
 
+
+
 RS_ActionBlocksToggleView::RS_ActionBlocksToggleView(
     RS_EntityContainer& container,
     RS_GraphicView& graphicView)
@@ -38,12 +40,6 @@ RS_ActionBlocksToggleView::RS_ActionBlocksToggleView(
                     container, graphicView) {}
 
 
-QAction* RS_ActionBlocksToggleView::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-	QAction* action = new QAction(QIcon(":/ui/layertoggle.png"), tr("Toggle Block &Visibility"), nullptr);
-	return action;
-}
-
-
 void RS_ActionBlocksToggleView::trigger() {
     RS_DEBUG->print("toggle block");
 	if (graphic) {
