@@ -27,6 +27,7 @@
 #ifndef RS_ACTIONDIMLEADER_H
 #define RS_ACTIONDIMLEADER_H
 
+#include<memory>
 #include "rs_previewactioninterface.h"
 
 class RS_Leader;
@@ -51,24 +52,22 @@ public:
 public:
     RS_ActionDimLeader(RS_EntityContainer& container,
                       RS_GraphicView& graphicView);
-	~RS_ActionDimLeader() = default;
-	
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
+	~RS_ActionDimLeader() override;
 
     void reset();
 
-    virtual void init(int status=0);
-    virtual void trigger();
+	void init(int status=0) override;
+	void trigger() override;
 	
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
-    virtual void keyPressEvent(QKeyEvent*);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
+	void keyPressEvent(QKeyEvent*) override;
 	
-	virtual void coordinateEvent(RS_CoordinateEvent* e);
-    virtual void commandEvent(RS_CommandEvent* e);
-	virtual QStringList getAvailableCommands();
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
+	void coordinateEvent(RS_CoordinateEvent* e) override;
+	void commandEvent(RS_CommandEvent* e) override;
+	QStringList getAvailableCommands() override;
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 
 protected:
     /**
@@ -78,8 +77,8 @@ protected:
 	/**
 	 * Points set so far.
 	 */
-	std::vector<RS_Vector> points;
-
+	struct Points;
+	std::unique_ptr<Points> pPoints;
 };
 
 #endif
