@@ -30,8 +30,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "rs_circle.h"
 #include "rs_ellipse.h"
 #include "rs_coordinateevent.h"
+#include "rs_preview.h"
+
+#include <QDebug>
 #include "rs_debug.h"
 
+struct RS_ActionDrawEllipseCenter3Points::Points {
+	RS_VectorSolutions points;
+	RS_CircleData cData;
+	RS_EllipseData eData;
+	bool valid{false};
+};
+
 /**
  * Constructor.
  *
@@ -40,27 +50,19 @@ RS_ActionDrawEllipseCenter3Points::RS_ActionDrawEllipseCenter3Points(
     RS_EntityContainer& container,
     RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Draw ellipse by center and 3 points",
-						   container, graphicView),
-		  cData(new RS_CircleData({0.,0.},1.)),
-		  eData(new RS_EllipseData{{0.,0.}, {1.,0.}, 1., 0., 0., false})
+						   container, graphicView)
+		, pPoints(new Points{})
 {
 	actionType=RS2::ActionDrawEllipseCenter3Points;
 }
 
 RS_ActionDrawEllipseCenter3Points::~RS_ActionDrawEllipseCenter3Points() = default;
 
-QAction* RS_ActionDrawEllipseCenter3Points::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-    QAction* action;
-
-	action = new QAction(QIcon(":/extui/ellipsecenter3points.png"), tr("Ellipse Center and &3 Points"), nullptr);
-    return action;
-}
-
 void RS_ActionDrawEllipseCenter3Points::init(int status) {
     RS_PreviewActionInterface::init(status);
 
     if (status==SetCenter) {
-        points.clean();
+		pPoints->points.clear();
     }
     drawSnapper();
 }
@@ -71,7 +73,7 @@ void RS_ActionDrawEllipseCenter3Points::trigger() {
     RS_PreviewActionInterface::trigger();
 
 
-	RS_Ellipse* ellipse=new RS_Ellipse(container, *eData);
+	RS_Ellipse* ellipse=new RS_Ellipse(container, pPoints->eData);
 
     deletePreview();
     container->addEntity(ellipse);
@@ -99,14 +101,14 @@ void RS_ActionDrawEllipseCenter3Points::mouseMoveEvent(QMouseEvent* e) {
     //    RS_DEBUG->print("RS_ActionDrawEllipseCenter3Points::mouseMoveEvent begin");
     RS_Vector mouse = snapPoint(e);
     if(getStatus() == SetCenter) return;
-    points.resize(getStatus());
-    points.push_back(mouse);
+	pPoints->points.resize(getStatus());
+	pPoints->points.push_back(mouse);
     if(preparePreview()) {
         switch(getStatus()) {
 
         case SetPoint1:
-        {
-			RS_Circle* circle=new RS_Circle(preview.get(), *cData);
+		{
+			RS_Circle* circle=new RS_Circle(preview.get(), pPoints->cData);
             deletePreview();
             preview->addEntity(circle);
             drawPreview();
@@ -117,7 +119,7 @@ void RS_ActionDrawEllipseCenter3Points::mouseMoveEvent(QMouseEvent* e) {
         case SetPoint3:
         {
             deletePreview();
-			RS_Ellipse* e=new RS_Ellipse(preview.get(), *eData);
+			RS_Ellipse* e=new RS_Ellipse(preview.get(), pPoints->eData);
             preview->addEntity(e);
             drawPreview();
         }
@@ -131,14 +133,16 @@ void RS_ActionDrawEllipseCenter3Points::mouseMoveEvent(QMouseEvent* e) {
 
 
 bool RS_ActionDrawEllipseCenter3Points::preparePreview(){
-    valid=false;
+	pPoints->valid=false;
     switch(getStatus()) {
     case SetPoint1:
     {
-		RS_Circle c(preview.get(), *cData);
-        valid= c.createFromCR(points.get(0),points.get(0).distanceTo(points.get(1)));
-        if(valid){
-			cData.reset(new RS_CircleData(c.getData()));
+		RS_Circle c(preview.get(), pPoints->cData);
+		pPoints->valid= c.createFromCR(pPoints->points.at(0),
+							  pPoints->points.get(0).distanceTo(pPoints->points.get(1)));
+
+		if (pPoints->valid){
+			pPoints->cData = c.getData();
         }
 
     }
@@ -146,17 +150,17 @@ bool RS_ActionDrawEllipseCenter3Points::preparePreview(){
     case SetPoint2:
     case SetPoint3:
     {
-		RS_Ellipse e(preview.get(), *eData);
-        valid= e.createFromCenter3Points(points);
-        if(valid){
-			eData.reset(new RS_EllipseData(e.getData()));
+		RS_Ellipse e(preview.get(), pPoints->eData);
+		pPoints->valid= e.createFromCenter3Points(pPoints->points);
+		if (pPoints->valid){
+			pPoints->eData = e.getData();
         }
     }
         break;
     default:
         break;
-    }
-    return valid;
+	}
+	return pPoints->valid;
 }
 
 void RS_ActionDrawEllipseCenter3Points::mouseReleaseEvent(QMouseEvent* e) {
@@ -175,12 +179,10 @@ void RS_ActionDrawEllipseCenter3Points::mouseReleaseEvent(QMouseEvent* e) {
 
 
 void RS_ActionDrawEllipseCenter3Points::coordinateEvent(RS_CoordinateEvent* e) {
-	if (!e) {
-        return;
-    }
+	if (!e) return;
     RS_Vector mouse = e->getCoordinate();
-    points.alloc(getStatus()+1);
-    points.set(getStatus(),mouse);
+	pPoints->points.alloc(getStatus()+1);
+	pPoints->points.set(getStatus(), mouse);
 
     switch (getStatus()) {
     case SetCenter:
@@ -190,7 +192,7 @@ void RS_ActionDrawEllipseCenter3Points::coordinateEvent(RS_CoordinateEvent* e) {
     case SetPoint1:
     case SetPoint2:
         for(int i=0;i<getStatus()-1;i++) {
-			if( (mouse-points.get(i)).squared() < RS_TOLERANCE15) {
+			if( (mouse-pPoints->points.get(i)).squared() < RS_TOLERANCE15) {
                 return;//refuse to accept points already chosen
             }
         }
@@ -218,10 +220,8 @@ void RS_ActionDrawEllipseCenter3Points::commandEvent(RS_CommandEvent* e) {
     QString c = e->getCommand().toLower();
 
     if (checkCommand("help", c)) {
-        if (RS_DIALOGFACTORY) {
             RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
                                              + getAvailableCommands().join(", "));
-        }
         return;
     }
 
@@ -237,9 +237,7 @@ void RS_ActionDrawEllipseCenter3Points::commandEvent(RS_CommandEvent* e) {
                     setStatus(SetAngle1);
                 }
             } else {
-                if (RS_DIALOGFACTORY) {
                     RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression"));
-                }
             }
         }
         break;
@@ -250,11 +248,8 @@ void RS_ActionDrawEllipseCenter3Points::commandEvent(RS_CommandEvent* e) {
             if (ok) {
                 angle1 = RS_Math::deg2rad(a);
                 setStatus(SetAngle2);
-            } else {
-                if (RS_DIALOGFACTORY) {
+			} else
                     RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression"));
-                }
-            }
         }
         break;
 
@@ -264,10 +259,8 @@ void RS_ActionDrawEllipseCenter3Points::commandEvent(RS_CommandEvent* e) {
             if (ok) {
                 angle2 = RS_Math::deg2rad(a);
                 trigger();
-            } else {
-                if (RS_DIALOGFACTORY) {
+			} else
                     RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression"));
-                }
             }
         }
         break;
@@ -280,39 +273,34 @@ void RS_ActionDrawEllipseCenter3Points::commandEvent(RS_CommandEvent* e) {
 
 
 QStringList RS_ActionDrawEllipseCenter3Points::getAvailableCommands() {
-    QStringList cmd;
-    return cmd;
+	return {};
 }
 
-
-
 void RS_ActionDrawEllipseCenter3Points::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case SetCenter:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the center of ellipse"),
-                                                tr("Cancel"));
-            break;
+	switch (getStatus()) {
+	case SetCenter:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the center of ellipse"),
+											tr("Cancel"));
+		break;
 
-        case SetPoint1:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the first point on ellipse"),
-                                                tr("Cancel"));
-            break;
-        case SetPoint2:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the second point on ellipse"),
-                                                tr("Back"));
-            break;
+	case SetPoint1:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the first point on ellipse"),
+											tr("Cancel"));
+		break;
+	case SetPoint2:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the second point on ellipse"),
+											tr("Back"));
+		break;
 
-        case SetPoint3:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the third point on ellipse"),
-                                                tr("Back"));
-            break;
+	case SetPoint3:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the third point on ellipse"),
+											tr("Back"));
+		break;
 
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 void RS_ActionDrawEllipseCenter3Points::updateMouseCursor() {
