@@ -29,8 +29,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "rs_commandevent.h"
 #include "rs_ellipse.h"
 #include "rs_line.h"
+#include "rs_preview.h"
 #include "rs_debug.h"
 
+struct RS_ActionDrawEllipseInscribe::Points {
+std::vector<RS_Line*> lines;
+RS_EllipseData eData;
+bool valid{false};
+};
 /**
  * Constructor.
  *
@@ -40,29 +46,21 @@ RS_ActionDrawEllipseInscribe::RS_ActionDrawEllipseInscribe(
     RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Draw ellipse inscribed",
 						   container, graphicView)
-		,eData(new RS_EllipseData{})
-		,valid(false)
+		, pPoints(new Points{})
 {
 	actionType=RS2::ActionDrawEllipseInscribe;
 }
 
 RS_ActionDrawEllipseInscribe::~RS_ActionDrawEllipseInscribe() = default;
 
-QAction* RS_ActionDrawEllipseInscribe::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-    QAction* action;
-
-	action = new QAction(QIcon(":/extui/ellipseinscribed.png"), tr("Ellipse &Inscribed"), nullptr);
-    return action;
-}
-
 void RS_ActionDrawEllipseInscribe::clearLines(bool checkStatus)
 {
-	while(lines.size() ){
-		if(checkStatus && (int) lines.size()<=getStatus() )
+	while(pPoints->lines.size() ){
+		if(checkStatus && (int) pPoints->lines.size()<=getStatus() )
 			break;
-		lines.back()->setHighlighted(false);
-		graphicView->drawEntity(lines.back());
-		lines.pop_back();
+		pPoints->lines.back()->setHighlighted(false);
+		graphicView->drawEntity(pPoints->lines.back());
+		pPoints->lines.pop_back();
 	}
 }
 
@@ -84,7 +82,7 @@ void RS_ActionDrawEllipseInscribe::trigger() {
     RS_PreviewActionInterface::trigger();
 
 
-	RS_Ellipse* ellipse=new RS_Ellipse(container, *eData);
+	RS_Ellipse* ellipse=new RS_Ellipse(container, pPoints->eData);
 
     deletePreview();
     container->addEntity(ellipse);
@@ -96,7 +94,7 @@ void RS_ActionDrawEllipseInscribe::trigger() {
         document->endUndoCycle();
     }
 
-	for(RS_Line*const p: lines) {
+	for(RS_Line*const p: pPoints->lines) {
 		if(!p) continue;
 		p->setHighlighted(false);
 		graphicView->drawEntity(p);
@@ -120,7 +118,7 @@ void RS_ActionDrawEllipseInscribe::mouseMoveEvent(QMouseEvent* e) {
         RS_Entity*  en = catchEntity(e, RS2::EntityLine, RS2::ResolveAll);
         if(!en) return;
         if(!(en->isVisible() && en->rtti()== RS2::EntityLine)) return;
-        for(auto p: lines){
+		for(auto p: pPoints->lines){
             if(en == p) return; //do not pull in the same line again
         }
 
@@ -131,11 +129,11 @@ void RS_ActionDrawEllipseInscribe::mouseMoveEvent(QMouseEvent* e) {
 		deletePreview();
 
 		clearLines(true);
-		lines.push_back(static_cast<RS_Line*>(en));
+		pPoints->lines.push_back(static_cast<RS_Line*>(en));
 		if(preparePreview()) {
-			lines.back()->setHighlighted(true);
-			graphicView->drawEntity(lines.back());
-			RS_Ellipse* e=new RS_Ellipse(preview.get(), *eData);
+			pPoints->lines.back()->setHighlighted(true);
+			graphicView->drawEntity(pPoints->lines.back());
+			RS_Ellipse* e=new RS_Ellipse(preview.get(), pPoints->eData);
             preview->addEntity(e);
             drawPreview();
         }
@@ -146,17 +144,17 @@ void RS_ActionDrawEllipseInscribe::mouseMoveEvent(QMouseEvent* e) {
 
 
 bool RS_ActionDrawEllipseInscribe::preparePreview(){
-    valid=false;
+	pPoints->valid=false;
     if(getStatus() == SetLine4) {
 		RS_Ellipse e{preview.get(), RS_EllipseData()};
-        valid= e.createInscribeQuadrilateral(lines);
-        if(valid){
-			eData.reset(new RS_EllipseData(e.getData()));
-        }else if( RS_DIALOGFACTORY){
+		pPoints->valid= e.createInscribeQuadrilateral(pPoints->lines);
+		if (pPoints->valid){
+			pPoints->eData = e.getData();
+		} else if ( RS_DIALOGFACTORY){
             RS_DIALOGFACTORY->commandMessage(tr("Can not determine uniquely an ellipse"));
         }
     }
-    return valid;
+	return pPoints->valid;
 }
 
 void RS_ActionDrawEllipseInscribe::mouseReleaseEvent(QMouseEvent* e) {
@@ -166,14 +164,14 @@ void RS_ActionDrawEllipseInscribe::mouseReleaseEvent(QMouseEvent* e) {
         RS_Entity*  en = catchEntity(e, RS2::EntityLine, RS2::ResolveAll);
         if(!en) return;
         if(!(en->isVisible() && en->rtti()== RS2::EntityLine)) return;
-        for(int i=0;i<getStatus();i++) {
-            if(en->getId() == lines[i]->getId()) return; //do not pull in the same line again
+		for(int i=0; i<getStatus(); ++i) {
+			if(en->getId() == pPoints->lines[i]->getId()) return; //do not pull in the same line again
         }
         if(en->getParent()) {
 			if ( en->getParent()->ignoredOnModification()) return;
         }
 		clearLines(true);
-		lines.push_back(static_cast<RS_Line*>(en));
+		pPoints->lines.push_back(static_cast<RS_Line*>(en));
 
         switch (getStatus()) {
         case SetLine1:
@@ -195,9 +193,9 @@ void RS_ActionDrawEllipseInscribe::mouseReleaseEvent(QMouseEvent* e) {
         // Return to last status:
         if(getStatus()>0){
 			clearLines(true);
-			lines.back()->setHighlighted(false);
-			graphicView->drawEntity(lines.back());
-            lines.pop_back();
+			pPoints->lines.back()->setHighlighted(false);
+			graphicView->drawEntity(pPoints->lines.back());
+			pPoints->lines.pop_back();
             deletePreview();
         }
         init(getStatus()-1);
@@ -216,10 +214,8 @@ void RS_ActionDrawEllipse4Line::commandEvent(RS_CommandEvent* e) {
     QString c = e->getCommand().toLower();
 
     if (checkCommand("help", c)) {
-		if (RS_DIALOGFACTORY) {
             RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
                                              + getAvailableCommands().join(", "));
-        }
         return;
     }
 
@@ -234,11 +230,8 @@ void RS_ActionDrawEllipse4Line::commandEvent(RS_CommandEvent* e) {
                 } else {
                     setStatus(SetAngle1);
                 }
-            } else {
-				if (RS_DIALOGFACTORY) {
+			} else
                     RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression"));
-                }
-            }
         }
         break;
 
@@ -248,11 +241,8 @@ void RS_ActionDrawEllipse4Line::commandEvent(RS_CommandEvent* e) {
             if (ok) {
                 angle1 = RS_Math::deg2rad(a);
                 setStatus(SetAngle2);
-            } else {
-				if (RS_DIALOGFACTORY) {
+			} else
                     RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression"));
-                }
-            }
         }
         break;
 
@@ -262,11 +252,8 @@ void RS_ActionDrawEllipse4Line::commandEvent(RS_CommandEvent* e) {
             if (ok) {
                 angle2 = RS_Math::deg2rad(a);
                 trigger();
-            } else {
-				if (RS_DIALOGFACTORY) {
+			} else
                     RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression"));
-                }
-            }
         }
         break;
 
@@ -285,37 +272,35 @@ QStringList RS_ActionDrawEllipseInscribe::getAvailableCommands() {
 
 
 void RS_ActionDrawEllipseInscribe::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case SetLine1:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the first line"),
-                                                tr("Cancel"));
-            break;
+	switch (getStatus()) {
+	case SetLine1:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the first line"),
+											tr("Cancel"));
+		break;
 
-        case SetLine2:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the second line"),
-                                                tr("Back"));
-            break;
+	case SetLine2:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the second line"),
+											tr("Back"));
+		break;
 
-        case SetLine3:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the third line"),
-                                                tr("Back"));
-            break;
+	case SetLine3:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the third line"),
+											tr("Back"));
+		break;
 
-        case SetLine4:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the fourth line"),
-                                                tr("Back"));
-            break;
+	case SetLine4:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify the fourth line"),
+											tr("Back"));
+		break;
 
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 void RS_ActionDrawEllipseInscribe::updateMouseCursor() {
-    graphicView->setMouseCursor(RS2::CadCursor);
+    graphicView->setMouseCursor(RS2::SelectCursor);
 }
 
 // EOF
