@@ -46,24 +46,22 @@ class RS_ActionDrawLinePolygonCenCor : public RS_PreviewActionInterface {
 public:
     RS_ActionDrawLinePolygonCenCor(RS_EntityContainer& container,
                               RS_GraphicView& graphicView);
-    ~RS_ActionDrawLinePolygonCenCor() = default;
+	~RS_ActionDrawLinePolygonCenCor() override;
 
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
+	void trigger() override;
+	
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
+	void updateMouseButtonHints() override;
+	
+	void coordinateEvent(RS_CoordinateEvent* e) override;
+	void commandEvent(RS_CommandEvent* e) override;
+		QStringList getAvailableCommands() override;
+	
+	void hideOptions() override;
+	void showOptions() override;
 
-    virtual void trigger();
-	
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
-    virtual void updateMouseButtonHints();
-	
-	virtual void coordinateEvent(RS_CoordinateEvent* e);
-    virtual void commandEvent(RS_CommandEvent* e);
-        virtual QStringList getAvailableCommands();
-	
-    virtual void hideOptions();
-    virtual void showOptions();
-
-    virtual void updateMouseCursor();
+	void updateMouseCursor() override;
 
 	int getNumber() const{
 		return number;
@@ -74,10 +72,8 @@ public:
 	}
 
 private:
-	/** Center of polygon */
-	RS_Vector center;
-	/** Edge */
-	RS_Vector corner;
+	struct Points;
+	std::unique_ptr<Points> pPoints;
 	/** Number of edges. */
 	int number;
 	/** Last status before entering text. */
