@@ -33,28 +33,28 @@
 #include "rs_commandevent.h"
 #include "rs_creation.h"
 #include "rs_coordinateevent.h"
+#include "rs_preview.h"
 #include "rs_debug.h"
 
+struct RS_ActionDrawLinePolygonCorCor::Points {
+	/** 1st corner */
+	RS_Vector corner1;
+	/** 2nd corner */
+	RS_Vector corner2;
+};
+
 RS_ActionDrawLinePolygonCorCor::RS_ActionDrawLinePolygonCorCor(
     RS_EntityContainer& container,
     RS_GraphicView& graphicView)
 		:RS_PreviewActionInterface("Draw Polygons (Corner,Corner)", container, graphicView)
-		,corner1(false)
-		,corner2(false)
+		, pPoints(new Points{})
 		,number(3)
 		,lastStatus(SetCorner1)
 {
 	actionType=RS2::ActionDrawLinePolygonCorCor;
 }
 
-QAction* RS_ActionDrawLinePolygonCorCor::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-        // tr("Polygon")
-    QAction* action = new QAction(tr("Polygo&n (Cor,Cor)"), NULL);
-        action->setIcon(QIcon(":/extui/linespolygon2.png"));
-    //action->zetStatusTip(tr("Draw polygon with two corners"));
-    return action;
-}
-
+RS_ActionDrawLinePolygonCorCor::~RS_ActionDrawLinePolygonCorCor() = default;
 
 void RS_ActionDrawLinePolygonCorCor::trigger() {
     RS_PreviewActionInterface::trigger();
@@ -62,7 +62,7 @@ void RS_ActionDrawLinePolygonCorCor::trigger() {
     deletePreview();
 
     RS_Creation creation(container, graphicView);
-    bool ok = creation.createPolygon2(corner1, corner2, number);
+	bool ok = creation.createPolygon2(pPoints->corner1, pPoints->corner2, number);
 
     if (!ok) {
         RS_DEBUG->print("RS_ActionDrawLinePolygon2::trigger:"
@@ -82,12 +82,12 @@ void RS_ActionDrawLinePolygonCorCor::mouseMoveEvent(QMouseEvent* e) {
         break;
 
     case SetCorner2:
-        if (corner1.valid) {
-            corner2 = mouse;
+		if (pPoints->corner1.valid) {
+			pPoints->corner2 = mouse;
             deletePreview();
 
 			RS_Creation creation(preview.get(), NULL, false);
-            creation.createPolygon2(corner1, corner2, number);
+			creation.createPolygon2(pPoints->corner1, pPoints->corner2, number);
 
             drawPreview();
         }
@@ -121,13 +121,13 @@ void RS_ActionDrawLinePolygonCorCor::coordinateEvent(RS_CoordinateEvent* e) {
 
     switch (getStatus()) {
     case SetCorner1:
-        corner1 = mouse;
+		pPoints->corner1 = mouse;
         setStatus(SetCorner2);
         graphicView->moveRelativeZero(mouse);
         break;
 
     case SetCorner2:
-        corner2 = mouse;
+		pPoints->corner2 = mouse;
         trigger();
         break;
 
@@ -139,27 +139,25 @@ void RS_ActionDrawLinePolygonCorCor::coordinateEvent(RS_CoordinateEvent* e) {
 
 
 void RS_ActionDrawLinePolygonCorCor::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case SetCorner1:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify first corner"),
-                                                tr("Cancel"));
-            break;
+	switch (getStatus()) {
+	case SetCorner1:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify first corner"),
+											tr("Cancel"));
+		break;
 
-        case SetCorner2:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify second corner"),
-                                                tr("Back"));
-            break;
+	case SetCorner2:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify second corner"),
+											tr("Back"));
+		break;
 
-        case SetNumber:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Number:"), tr("Back"));
-            break;
+	case SetNumber:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Number:"), tr("Back"));
+		break;
 
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 
@@ -167,9 +165,7 @@ void RS_ActionDrawLinePolygonCorCor::updateMouseButtonHints() {
 void RS_ActionDrawLinePolygonCorCor::showOptions() {
     RS_ActionInterface::showOptions();
 
-    if (RS_DIALOGFACTORY) {
-        RS_DIALOGFACTORY->requestOptions(this, true);
-    }
+	RS_DIALOGFACTORY->requestOptions(this, true);
 }
 
 
@@ -177,9 +173,7 @@ void RS_ActionDrawLinePolygonCorCor::showOptions() {
 void RS_ActionDrawLinePolygonCorCor::hideOptions() {
     RS_ActionInterface::hideOptions();
 
-    if (RS_DIALOGFACTORY) {
-        RS_DIALOGFACTORY->requestOptions(this, false);
-    }
+	RS_DIALOGFACTORY->requestOptions(this, false);
 }
 
 
@@ -188,10 +182,8 @@ void RS_ActionDrawLinePolygonCorCor::commandEvent(RS_CommandEvent* e) {
     QString c = e->getCommand().toLower();
 
     if (checkCommand("help", c)) {
-        if (RS_DIALOGFACTORY) {
-            RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
-                                             + getAvailableCommands().join(", "));
-        }
+		RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
+										 + getAvailableCommands().join(", "));
         return;
     }
 
@@ -212,20 +204,12 @@ void RS_ActionDrawLinePolygonCorCor::commandEvent(RS_CommandEvent* e) {
                 e->accept();
                 if (n>0 && n<10000) {
                     number = n;
-                } else {
-                    if (RS_DIALOGFACTORY) {
-                        RS_DIALOGFACTORY->commandMessage(tr("Not a valid number. "
-                                                            "Try 1..9999"));
-                    }
-                }
-            } else {
-                if (RS_DIALOGFACTORY) {
-                    RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression."));
-                }
-            }
-            if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->requestOptions(this, true, true);
-            }
+				} else
+					RS_DIALOGFACTORY->commandMessage(tr("Not a valid number. "
+														"Try 1..9999"));
+			} else
+				RS_DIALOGFACTORY->commandMessage(tr("Not a valid expression."));
+			RS_DIALOGFACTORY->requestOptions(this, true, true);
             setStatus(lastStatus);
         }
         break;
