@@ -37,24 +37,18 @@
 RS_ActionDrawPoint::RS_ActionDrawPoint(RS_EntityContainer& container,
                                        RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Draw Points",
-						   container, graphicView) {
+						   container, graphicView)
+		, pt(new RS_Vector{})
+{
 	actionType=RS2::ActionDrawPoint;
 }
 
-
-QAction* RS_ActionDrawPoint::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-	// (tr("Points")
-	QAction* action = new QAction(tr("&Points"),  NULL);
-	action->setIcon(QIcon(":/extui/points.png"));
-	action->setData(RS2::ActionDrawPoint);
-
-	return action;
-}
+RS_ActionDrawPoint::~RS_ActionDrawPoint() = default;
 
 
 void RS_ActionDrawPoint::trigger() {
-    if (pt.valid) {
-        RS_Point* point = new RS_Point(container, RS_PointData(pt));
+	if (pt->valid) {
+		RS_Point* point = new RS_Point(container, RS_PointData(*pt));
         container->addEntity(point);
 
         if (document) {
@@ -63,7 +57,7 @@ void RS_ActionDrawPoint::trigger() {
             document->endUndoCycle();
         }
 
-		graphicView->moveRelativeZero(pt);
+		graphicView->moveRelativeZero(*pt);
 		graphicView->redraw((RS2::RedrawMethod) (RS2::RedrawDrawing | RS2::RedrawOverlay));
     }
 }
@@ -88,13 +82,13 @@ void RS_ActionDrawPoint::mouseReleaseEvent(QMouseEvent* e) {
 
 
 void RS_ActionDrawPoint::coordinateEvent(RS_CoordinateEvent* e) {
-    if (e==NULL) {
+	if (e==nullptr) {
         return;
     }
 
     RS_Vector mouse = e->getCoordinate();
 
-    pt = mouse;
+	*pt = mouse;
     trigger();
 }
 
@@ -103,34 +97,29 @@ void RS_ActionDrawPoint::coordinateEvent(RS_CoordinateEvent* e) {
 void RS_ActionDrawPoint::commandEvent(RS_CommandEvent* e) {
     QString c = e->getCommand().toLower();
 
-    if (checkCommand("help", c)) {
-        if (RS_DIALOGFACTORY) {
-            RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
-                                             + getAvailableCommands().join(", "));
-        }
-        return;
-    }
+	if (checkCommand("help", c)) {
+		RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
+										 + getAvailableCommands().join(", "));
+		return;
+	}
 }
 
 
 
 QStringList RS_ActionDrawPoint::getAvailableCommands() {
-    QStringList cmd;
-    return cmd;
+	return {};
 }
 
 
 void RS_ActionDrawPoint::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case 0:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify location"), tr("Cancel"));
-            break;
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	switch (getStatus()) {
+	case 0:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify location"), tr("Cancel"));
+		break;
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 
