@@ -34,14 +34,19 @@
 #include "rs_line.h"
 #include "rs_text.h"
 #include "rs_coordinateevent.h"
+#include "rs_preview.h"
 #include "rs_debug.h"
 
+struct RS_ActionDrawText::Points {
+	RS_Vector pos;
+	RS_Vector secPos;
+};
+
 RS_ActionDrawText::RS_ActionDrawText(RS_EntityContainer& container,
                                      RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Draw Text",
 						   container, graphicView)
-		,pos(false)
-		,secPos(false)
+		, pPoints(new Points{})
 		,textChanged(true)
 {
 	actionType=RS2::ActionDrawText;
@@ -50,46 +55,35 @@ RS_ActionDrawText::RS_ActionDrawText(RS_EntityContainer& container,
 RS_ActionDrawText::~RS_ActionDrawText() = default;
 
 
-QAction* RS_ActionDrawText::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-	// tr("Text")
-	QAction* action = new QAction(tr("&Text"),  NULL);
-	action->setIcon(QIcon(":/extui/menutext.png"));
-	action->setData(RS2::ActionDrawText);
-	return action;
-}
-
-
 void RS_ActionDrawText::init(int status) {
-    RS_ActionInterface::init(status);
-    if (RS_DIALOGFACTORY) {
+	RS_ActionInterface::init(status);
 
-        switch (status) {
-        case ShowDialog: {
-                reset();
+	switch (status) {
+	case ShowDialog: {
+		reset();
 
-				RS_Text tmp(NULL, *data);
-                if (RS_DIALOGFACTORY->requestTextDialog(&tmp)) {
-					data.reset(new RS_TextData(tmp.getData()));
-                    setStatus(SetPos);
-                    showOptions();
-                } else {
-                    hideOptions();
-                    setFinished();
-                }
-            }
-            break;
+		RS_Text tmp(NULL, *data);
+		if (RS_DIALOGFACTORY->requestTextDialog(&tmp)) {
+			data.reset(new RS_TextData(tmp.getData()));
+			setStatus(SetPos);
+			showOptions();
+		} else {
+			hideOptions();
+			setFinished();
+		}
+	}
+		break;
 
-        case SetPos:
-            RS_DIALOGFACTORY->requestOptions(this, true, true);
-            deletePreview();
-            preview->setVisible(true);
-            preparePreview();
-            break;
+	case SetPos:
+		RS_DIALOGFACTORY->requestOptions(this, true, true);
+		deletePreview();
+		preview->setVisible(true);
+		preparePreview();
+		break;
 
-        default:
-            break;
-        }
-    }
+	default:
+		break;
+	}
 }
 
 
@@ -113,7 +107,7 @@ void RS_ActionDrawText::trigger() {
 
     RS_DEBUG->print("RS_ActionDrawText::trigger()");
 
-    if (pos.valid) {
+	if (pPoints->pos.valid) {
         deletePreview();
 
 		RS_Text* text = new RS_Text(container, *data);
@@ -129,7 +123,7 @@ void RS_ActionDrawText::trigger() {
                 graphicView->redraw(RS2::RedrawDrawing);
 
         textChanged = true;
-        secPos = RS_Vector(false);
+		pPoints->secPos = {};
         setStatus(SetPos);
     }
 }
@@ -137,12 +131,12 @@ void RS_ActionDrawText::trigger() {
 
 void RS_ActionDrawText::preparePreview() {
 	if (data->halign == RS_TextData::HAFit || data->halign == RS_TextData::HAAligned) {
-        if (secPos.valid) {
-            RS_Line* text = new RS_Line(pos, secPos);
+		if (pPoints->secPos.valid) {
+			RS_Line* text = new RS_Line(pPoints->pos, pPoints->secPos);
             preview->addEntity(text);
         }
     } else {
-		data->insertionPoint = pos;
+		data->insertionPoint = pPoints->pos;
 		RS_Text* text = new RS_Text(preview.get(), *data);
         text->update();
         preview->addEntity(text);
@@ -156,9 +150,9 @@ void RS_ActionDrawText::mouseMoveEvent(QMouseEvent* e) {
 
     if (getStatus()==SetPos) {
         RS_Vector mouse = snapPoint(e);
-        RS_Vector mov = mouse-pos;
-        pos = mouse;
-        if (textChanged || pos.valid == false || preview->isEmpty()) {
+		RS_Vector mov = mouse - pPoints->pos;
+		pPoints->pos = mouse;
+		if (textChanged || pPoints->pos.valid == false || preview->isEmpty()) {
             deletePreview();
             preparePreview();
         } else {
@@ -167,7 +161,7 @@ void RS_ActionDrawText::mouseMoveEvent(QMouseEvent* e) {
         }
         drawPreview();
     } else if (getStatus()==SetSecPos) {
-        secPos = snapPoint(e);
+		pPoints->secPos = snapPoint(e);
         deletePreview();
         preparePreview();
         drawPreview();
@@ -225,13 +219,11 @@ void RS_ActionDrawText::coordinateEvent(RS_CoordinateEvent* e) {
 void RS_ActionDrawText::commandEvent(RS_CommandEvent* e) {
     QString c = e->getCommand().toLower();
 
-    if (checkCommand("help", c)) {
-        if (RS_DIALOGFACTORY) {
-            RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
-                                             + getAvailableCommands().join(", "));
-        }
-        return;
-    }
+	if (checkCommand("help", c)) {
+		RS_DIALOGFACTORY->commandMessage(msgAvailableCommands()
+										 + getAvailableCommands().join(", "));
+		return;
+	}
 
     switch (getStatus()) {
     case SetPos:
@@ -244,9 +236,7 @@ void RS_ActionDrawText::commandEvent(RS_CommandEvent* e) {
 
     case SetText: {
             setText(e->getCommand());
-            if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->requestOptions(this, true, true);
-            }
+			RS_DIALOGFACTORY->requestOptions(this, true, true);
             graphicView->enableCoordinateInput();
             setStatus(SetPos);
         }
@@ -272,9 +262,7 @@ QStringList RS_ActionDrawText::getAvailableCommands() {
 void RS_ActionDrawText::showOptions() {
     RS_ActionInterface::showOptions();
 
-    if (RS_DIALOGFACTORY) {
-        RS_DIALOGFACTORY->requestOptions(this, true, true);
-    }
+	RS_DIALOGFACTORY->requestOptions(this, true, true);
 }
 
 
@@ -282,34 +270,30 @@ void RS_ActionDrawText::showOptions() {
 void RS_ActionDrawText::hideOptions() {
     RS_ActionInterface::hideOptions();
 
-    if (RS_DIALOGFACTORY) {
-        RS_DIALOGFACTORY->requestOptions(this, false);
-    }
+	RS_DIALOGFACTORY->requestOptions(this, false);
 }
 
 
 
 void RS_ActionDrawText::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case SetPos:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify insertion point"),
-                                                tr("Cancel"));
-            break;
-        case SetSecPos:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify second point"),
-                                                tr("Cancel"));
-            break;
-        case ShowDialog:
-        case SetText:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Enter text:"),
-                                                tr("Back"));
-            break;
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	switch (getStatus()) {
+	case SetPos:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify insertion point"),
+											tr("Cancel"));
+		break;
+	case SetSecPos:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify second point"),
+											tr("Cancel"));
+		break;
+	case ShowDialog:
+	case SetText:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Enter text:"),
+											tr("Back"));
+		break;
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 
