@@ -45,33 +45,6 @@ RS_ActionEditUndo::RS_ActionEditUndo(bool undo,
 {
 }
 
-QAction* RS_ActionEditUndo::createGUIAction(RS2::ActionType type, QObject* parent) {
-    QAction* action;
-    if (type==RS2::ActionEditUndo) {
-                // tr("Undo")
-                action = new QAction(tr("&Undo"), parent);
-#if QT_VERSION >= 0x040600
-                action->setIcon(QIcon::fromTheme("edit-undo", QIcon(":/actions/undo2.png")));
-#else
-				action->setIcon(QIcon(":/actions/undo2.png"));
-#endif
-                action->setShortcut(QKeySequence::Undo);
-                //action->zetStatusTip(tr("Undoes last action"));
-    } else {
-                // tr("Redo")
-                action = new QAction(tr("&Redo"), parent);
-#if QT_VERSION >= 0x040600
-                action->setIcon(QIcon::fromTheme("edit-redo", QIcon(":/actions/redo2.png")));
-#else
-                action->setIcon(QIcon(":/actions/redo2.png"));
-#endif
-                action->setShortcut(QKeySequence::Redo);
-                //action->zetStatusTip(tr("Redoes last action"));
-    }
-
-    return action;
-}
-
 void RS_ActionEditUndo::init(int status) {
     RS_ActionInterface::init(status);
     trigger();
@@ -80,22 +53,18 @@ void RS_ActionEditUndo::init(int status) {
 
 
 void RS_ActionEditUndo::trigger() {
-    if (undo) {
-        if(!document->undo()) {
-			if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->commandMessage(tr("Nothing to undo!"));
-            }
-        }
-    } else {
-        if(!document->redo()) {
-			if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->commandMessage(tr("Nothing to redo!"));
-            }
-        }
-    }
+	if (undo) {
+		if(!document->undo())
+			RS_DIALOGFACTORY->commandMessage(tr("Nothing to undo!"));
+	} else {
+		if(!document->redo())
+			RS_DIALOGFACTORY->commandMessage(tr("Nothing to redo!"));
+	}
 
-    if (graphic) {
+	if (graphic)
+    {
         graphic->addBlockNotification();
+        graphic->setModified(true);
     }
     document->updateInserts();
 
