@@ -39,31 +39,21 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 RS_ActionLayersTogglePrint::RS_ActionLayersTogglePrint(
     RS_EntityContainer& container,
-    RS_GraphicView& graphicView)
-        :RS_ActionInterface("Toggle Layer Printing",
-                    container, graphicView) {}
-
-
-QAction* RS_ActionLayersTogglePrint::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-/* RVT_PORT    QAction* action = new QAction(tr("Toggle Layer Print"),
-                                  tr("&Toggle Print"),
-                                  QKeySequence(), NULL); */
-    QAction* action = new QAction(tr("Toggle Layer &Print"), NULL);
-     action->setIcon(QIcon(":/ui/fileprint.png"));
-    //action->zetStatusTip(tr("Toggle Print"));
-    return action;
-}
+    RS_GraphicView& graphicView,
+    RS_Layer* layer)
+        : RS_ActionInterface("Toggle Layer Printing", container, graphicView)
+        , a_layer(layer)
+{}
 
 void RS_ActionLayersTogglePrint::trigger() {
     RS_DEBUG->print("toggle layer printing");
     if (graphic) {
-        RS_Layer* layer = graphic->getActiveLayer();
-        if (layer) {
-            graphic->toggleLayerPrint( layer);
+        if (a_layer) {
+            graphic->toggleLayerPrint(a_layer);
 
 			// deselect entities on locked layer:
 			for(auto e: *container){
-                if (e && e->isVisible() && e->getLayer()==layer) {
+                if (e && e->isVisible() && e->getLayer()==a_layer) {
 
                     if (graphicView) {
                         graphicView->deleteEntity(e);
