@@ -51,21 +51,19 @@ public:
 public:
     RS_ActionModifyMirror(RS_EntityContainer& container,
                         RS_GraphicView& graphicView);
-	~RS_ActionModifyMirror();
+	~RS_ActionModifyMirror() override;
 	
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
-    virtual void init(int status=0);
-    virtual void trigger();
-	virtual void coordinateEvent(RS_CoordinateEvent* e);
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
+	void init(int status=0) override;
+	void trigger() override;
+	void coordinateEvent(RS_CoordinateEvent* e) override;
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 
 private:
-	std::unique_ptr<RS_MirrorData> data;
-    RS_Vector axisPoint1;
-    RS_Vector axisPoint2;
+	struct Points;
+	std::unique_ptr<Points> pPoints;
 };
 
 #endif
