@@ -51,27 +51,25 @@ public:
 public:
     RS_ActionModifyOffset(RS_EntityContainer& container,
                      RS_GraphicView& graphicView);
-    ~RS_ActionModifyOffset();
-
-        static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
+	~RS_ActionModifyOffset() override;
 
 //    void reset();
 
-    virtual void init(int status=0);
-    virtual void trigger();
+	void init(int status=0) override;
+	void trigger() override;
 
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
 
-    //        virtual void coordinateEvent(RS_CoordinateEvent* e);
-//    virtual void commandEvent(RS_CommandEvent* e);
-//    virtual QStringList getAvailableCommands();
+	//        void coordinateEvent(RS_CoordinateEvent* e) override;
+//    void commandEvent(RS_CommandEvent* e) override;
+//    QStringList getAvailableCommands() override;
 
-    virtual void hideOptions();
-    virtual void showOptions();
+	void hideOptions() override;
+	void showOptions() override;
 
-    virtual void updateMouseButtonHints();
-	virtual void updateMouseCursor();
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 
 protected:
 
