@@ -50,24 +50,23 @@ public:
 public:
     RS_ActionPolylineDelBetween(RS_EntityContainer& container,
                         RS_GraphicView& graphicView);
-	~RS_ActionPolylineDelBetween()=default;
+	~RS_ActionPolylineDelBetween() override;
 
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
-    virtual void init(int status=0);
+	void init(int status=0) override;
 	
-    virtual void trigger();
+	void trigger() override;
 	
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
 	
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 
 private:
     RS_Entity* delEntity;
 	RS_AtomicEntity* delSegment;
-    RS_Vector nodePoint1;
-    RS_Vector nodePoint2;
+	struct Points;
+	std::unique_ptr<Points> pPoints;
 };
 
 #endif
