@@ -34,6 +34,8 @@
 #include "rs_selection.h"
 #include "rs_debug.h"
 
+
+
 RS_ActionSelectContour::RS_ActionSelectContour(RS_EntityContainer& container,
         RS_GraphicView& graphicView)
 		:RS_ActionInterface("Select Contours", container, graphicView)
@@ -42,14 +44,6 @@ RS_ActionSelectContour::RS_ActionSelectContour(RS_EntityContainer& container,
 	actionType=RS2::ActionSelectContour;
 }
 
-QAction* RS_ActionSelectContour::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-        // tr("(De-)Select Contour")
-    QAction* action = new QAction(tr("(De-)Select &Contour"),  NULL);
-        action->setIcon(QIcon(":/extui/selectcontour.png"));
-        //action->zetStatusTip(tr("(De-)Selects connected entities"));
-    return action;
-}
-
 
 void RS_ActionSelectContour::trigger() {
     if (en) {
@@ -57,18 +51,12 @@ void RS_ActionSelectContour::trigger() {
             RS_Selection s(*container, graphicView);
             s.selectContour(en);
 
-            if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),container->totalSelectedLength());
-            }
-        } else {
-            if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->commandMessage(
-                    tr("Entity must be an Atomic Entity."));
-            }
-        }
-    } else {
+			RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),container->totalSelectedLength());
+		} else
+			RS_DIALOGFACTORY->commandMessage(
+						tr("Entity must be an Atomic Entity."));
+	} else
         RS_DEBUG->print("RS_ActionSelectContour::trigger: Entity is NULL\n");
-    }
 }
 
 
