@@ -32,8 +32,14 @@
 #include "rs_graphicview.h"
 #include "rs_selection.h"
 #include "rs_line.h"
+#include "rs_preview.h"
 #include "rs_debug.h"
 
+struct RS_ActionSelectIntersected::Points {
+	RS_Vector v1;
+	RS_Vector v2;
+};
+
 /**
  * Constructor.
  *
@@ -45,31 +51,17 @@ RS_ActionSelectIntersected::RS_ActionSelectIntersected(
     bool select)
         : RS_PreviewActionInterface("Select Intersected",
 							container, graphicView)
+		, pPoints(new Points{})
 		,select(select)
 {
 	actionType=RS2::ActionSelectIntersected;
 }
 
-
-QAction* RS_ActionSelectIntersected::createGUIAction(RS2::ActionType type, QObject* /*parent*/) {
-    QAction* action;
-    if (type==RS2::ActionSelectIntersected) {
-        action = new QAction(tr("Select Intersected Entities"),  NULL);
-                action->setIcon(QIcon(":/extui/selectinters.png"));
-        //action->zetStatusTip(tr("Selects all entities intersected by a line"));
-    } else {
-        action = new QAction(tr("Deselect Intersected Entities"), NULL);
-                action->setIcon(QIcon(":/extui/deselectinters.png"));
-        //action->zetStatusTip(tr("Deselects all entities intersected by a line"));
-    }
-    return action;
-}
-
+RS_ActionSelectIntersected::~RS_ActionSelectIntersected() = default;
 
 void RS_ActionSelectIntersected::init(int status) {
     RS_PreviewActionInterface::init(status);
-
-    v1 = v2 = RS_Vector(false);
+	pPoints.reset(new Points{});
     snapMode.clear();
     snapMode.restriction = RS2::RestrictNothing;
 }
@@ -79,15 +71,13 @@ void RS_ActionSelectIntersected::init(int status) {
 void RS_ActionSelectIntersected::trigger() {
     RS_PreviewActionInterface::trigger();
 
-    if (v1.valid && v2.valid) {
-        if (graphicView->toGuiDX(v1.distanceTo(v2))>10) {
+	if (pPoints->v1.valid && pPoints->v2.valid) {
+		if (graphicView->toGuiDX(pPoints->v1.distanceTo(pPoints->v2))>10) {
 
             RS_Selection s(*container, graphicView);
-            s.selectIntersected(v1, v2, select);
+			s.selectIntersected(pPoints->v1, pPoints->v2, select);
 
-            if (RS_DIALOGFACTORY) {
-                RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),container->totalSelectedLength());
-            }
+			RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),container->totalSelectedLength());
 
             init();
         }
@@ -97,10 +87,10 @@ void RS_ActionSelectIntersected::trigger() {
 
 
 void RS_ActionSelectIntersected::mouseMoveEvent(QMouseEvent* e) {
-    if (getStatus()==SetPoint2 && v1.valid) {
-        v2 = snapPoint(e);
+	if (getStatus()==SetPoint2 && pPoints->v1.valid) {
+		pPoints->v2 = snapPoint(e);
         deletePreview();
-		preview->addEntity(new RS_Line{preview.get(), v1, v2});
+		preview->addEntity(new RS_Line{preview.get(), pPoints->v1, pPoints->v2});
         drawPreview();
     }
 }
@@ -111,7 +101,7 @@ void RS_ActionSelectIntersected::mousePressEvent(QMouseEvent* e) {
     if (e->button()==Qt::LeftButton) {
         switch (getStatus()) {
         case SetPoint1:
-            v1 = snapPoint(e);
+			pPoints->v1 = snapPoint(e);
             setStatus(SetPoint2);
             break;
 
@@ -121,7 +111,7 @@ void RS_ActionSelectIntersected::mousePressEvent(QMouseEvent* e) {
     }
 
     RS_DEBUG->print("RS_ActionSelectIntersected::mousePressEvent(): %f %f",
-                    v1.x, v1.y);
+					pPoints->v1.x, pPoints->v1.y);
 }
 
 
@@ -135,7 +125,7 @@ void RS_ActionSelectIntersected::mouseReleaseEvent(QMouseEvent* e) {
         init(getStatus()-1);
     } else if (e->button()==Qt::LeftButton) {
         if (getStatus()==SetPoint2) {
-            v2 = snapPoint(e);
+			pPoints->v2 = snapPoint(e);
             trigger();
         }
     }
@@ -144,19 +134,17 @@ void RS_ActionSelectIntersected::mouseReleaseEvent(QMouseEvent* e) {
 
 
 void RS_ActionSelectIntersected::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case SetPoint1:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Choose first point of intersection line"), tr("Cancel"));
-            break;
-        case SetPoint2:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Choose second point of intersection line"), tr("Back"));
-            break;
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	switch (getStatus()) {
+	case SetPoint1:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Choose first point of intersection line"), tr("Cancel"));
+		break;
+	case SetPoint2:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Choose second point of intersection line"), tr("Back"));
+		break;
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 void RS_ActionSelectIntersected::updateMouseCursor() {
