@@ -50,26 +50,23 @@ public:
     RS_ActionSelectWindow(RS_EntityContainer& container,
                          RS_GraphicView& graphicView,
                          bool select);
-	~RS_ActionSelectWindow()=default;
+	~RS_ActionSelectWindow() override;
 
-	static QAction* createGUIAction(RS2::ActionType type, QObject* /*parent*/);
-
-    virtual void init(int status=0);
+	void init(int status=0) override;
 	
-    virtual void trigger();
+	void trigger() override;
 	
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mousePressEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mousePressEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
 	
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 
-protected:
-    RS_Vector v1;
-    RS_Vector v2;
-
-    bool select;
+private:
+	bool select;
+	struct Points;
+	std::unique_ptr<Points> pPoints;
 };
 
 #endif
