@@ -40,12 +40,9 @@ class RS_ActionZoomRedraw : public RS_ActionInterface {
 public:
     RS_ActionZoomRedraw(RS_EntityContainer& container,
                       RS_GraphicView& graphicView);
-    ~RS_ActionZoomRedraw() = default;
 
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
-
-    virtual void init(int status=0);
-    virtual void trigger();
+	void init(int status=0) override;
+	void trigger() override;
 };
 
 #endif
