@@ -29,6 +29,7 @@
 #include<QMouseEvent>
 #include "rs_snapper.h"
 
+#include "rs_point.h"
 #include "rs_circle.h"
 #include "rs_line.h"
 #include "rs_dialogfactory.h"
@@ -36,21 +37,74 @@
 #include "rs_grid.h"
 #include "rs_settings.h"
 #include "rs_overlayline.h"
-#include "rs_entitycontainer.h"
 #include "rs_coordinateevent.h"
+#include "rs_entitycontainer.h"
 #include "rs_pen.h"
 #include "rs_debug.h"
 
+struct RS_Snapper::Indicator
+{
+    bool lines_state;
+    QString lines_type;
+    RS_Pen lines_pen;
+
+    bool shape_state;
+    QString shape_type;
+    RS_Pen shape_pen;
+};
+
 struct RS_Snapper::ImpData {
-QString snap_indicator;
-RS_Pen line_pen;
-RS_Pen circle_pen;
 RS_Vector snapCoord;
 RS_Vector snapSpot;
 };
 
-namespace {
-RS_Pen const crossHairPen{RS_Color(255,194,0), RS2::Width00, RS2::DashLine2};
+/**
+ * Constructor.
+ */
+RS_Snapper::RS_Snapper(RS_EntityContainer& container, RS_GraphicView& graphicView)
+    :container(&container)
+    ,graphicView(&graphicView)
+	,pImpData(new ImpData{})
+    ,snap_indicator(new Indicator{})
+{}
+
+RS_Snapper::~RS_Snapper()
+{
+    delete snap_indicator;
+}
+
+/**
+ * Initialize (called by all constructors)
+ */
+void RS_Snapper::init() 
+{
+    snapMode = graphicView->getDefaultSnapMode();
+	keyEntity = nullptr;
+	pImpData->snapSpot = RS_Vector{false};
+	pImpData->snapCoord = RS_Vector{false};
+	m_SnapDistance = 1.0;
+
+    RS_SETTINGS->beginGroup("/Appearance");
+    snap_indicator->lines_state = RS_SETTINGS->readNumEntry("/indicator_lines_state", 1);
+    snap_indicator->lines_type = RS_SETTINGS->readEntry("/indicator_lines_type", "Crosshair");
+    snap_indicator->shape_state = RS_SETTINGS->readNumEntry("/indicator_shape_state", 1);
+    snap_indicator->shape_type = RS_SETTINGS->readEntry("/indicator_shape_type", "Circle");
+    RS_SETTINGS->endGroup();
+
+    RS_SETTINGS->beginGroup("Colors");
+    QString snap_color = RS_SETTINGS->readEntry("/snap_indicator", Colors::snap_indicator);
+    RS_SETTINGS->endGroup();
+
+	snap_indicator->lines_pen = RS_Pen(RS_Color(snap_color), RS2::Width00, RS2::DashLine2);
+	snap_indicator->shape_pen = RS_Pen(RS_Color(snap_color), RS2::Width00, RS2::SolidLine);
+	snap_indicator->shape_pen.setScreenWidth(1);
+
+    snapRange=getSnapRange();
+}
+
+void RS_Snapper::finish() {
+    finished = true;
+    deleteSnapper();
 }
 
 /**
@@ -89,52 +143,8 @@ bool RS_SnapMode::operator ==(RS_SnapMode const& rhs) const{
 	return true;
 }
 
-/**
- * Constructor.
- */
-RS_Snapper::RS_Snapper(RS_EntityContainer& container, RS_GraphicView& graphicView)
-    :container(&container)
-    ,graphicView(&graphicView)
-	,pImpData(new ImpData{})
-{
-    init();
-}
-
-RS_Snapper::~RS_Snapper() = default;
-
-/**
- * Initialize (called by all constructors)
- */
-void RS_Snapper::init() {
-    snapMode = graphicView->getDefaultSnapMode();
-    //snapRes = graphicView->getSnapRestriction();
-	keyEntity = nullptr;
-	pImpData->snapSpot = RS_Vector{false};
-	pImpData->snapCoord = RS_Vector{false};
-	m_SnapDistance = 1.0;
-//    RS_SETTINGS->beginGroup("/Snap");
-//    snapRange = RS_SETTINGS->readNumEntry("/Range", 20);
-//    //middlePoints behaviors weird, add brutal force here
-//    //todo, clean up middlePoints
-//    //middlePoints= RS_SETTINGS->readNumEntry("/MiddlePoints", 1);
-//    //distance=RS_SETTINGS->readEntry("/Distance", QString("1")).toDouble();
-//    RS_SETTINGS->endGroup();
-    RS_SETTINGS->beginGroup("/Appearance");
-    showCrosshairs = (bool)RS_SETTINGS->readNumEntry("/ShowCrosshairs", 1);
-	pImpData->snap_indicator = RS_SETTINGS->readEntry("/SnapIndicator", "Crosshair");
-    RS_SETTINGS->endGroup();
-
-    snapRange=getSnapRange();
-}
-
-void RS_Snapper::finish() {
-    finished = true;
-    deleteSnapper();
-}
-
 void RS_Snapper::setSnapMode(const RS_SnapMode& snapMode) {
     this->snapMode = snapMode;
-	if (!RS_DIALOGFACTORY) return;
 	RS_DIALOGFACTORY->requestSnapDistOptions(m_SnapDistance, snapMode.snapDistance);
     RS_DIALOGFACTORY->requestSnapMiddleOptions(middlePoints, snapMode.snapMiddle);
 //std::cout<<"RS_Snapper::setSnapMode(): middlePoints="<<middlePoints<<std::endl;
@@ -158,7 +168,7 @@ RS_Vector RS_Snapper::snapFree(QMouseEvent* e) {
     }
 	pImpData->snapSpot=graphicView->toGraph(e->x(), e->y());
 	pImpData->snapCoord=pImpData->snapSpot;
-    showCrosshairs=true;
+    snap_indicator->lines_state=true;
 	return pImpData->snapCoord;
 }
 
@@ -168,9 +178,8 @@ RS_Vector RS_Snapper::snapFree(QMouseEvent* e) {
  * @param e A mouse event.
  * @return The coordinates of the point or an invalid vector.
  */
-RS_Vector RS_Snapper::snapPoint(QMouseEvent* e) {
-        RS_DEBUG->print("RS_Snapper::snapPoint");
-
+RS_Vector RS_Snapper::snapPoint(QMouseEvent* e)
+{
 	pImpData->snapSpot = RS_Vector(false);
     RS_Vector t(false);
 
@@ -203,9 +212,7 @@ RS_Vector RS_Snapper::snapPoint(QMouseEvent* e) {
     if (snapMode.snapMiddle) {
         //this is still brutal force
         //todo: accept value from widget QG_SnapMiddleOptions
-		if(RS_DIALOGFACTORY ) {
-            RS_DIALOGFACTORY->requestSnapMiddleOptions(middlePoints, snapMode.snapMiddle);
-        }
+		RS_DIALOGFACTORY->requestSnapMiddleOptions(middlePoints, snapMode.snapMiddle);
         t = snapMiddle(mouseCoord);
 		double ds2=mouseCoord.squaredTo(t);
         if (ds2 < ds2Min){
@@ -216,9 +223,7 @@ RS_Vector RS_Snapper::snapPoint(QMouseEvent* e) {
     if (snapMode.snapDistance) {
         //this is still brutal force
         //todo: accept value from widget QG_SnapDistOptions
-		if(RS_DIALOGFACTORY ) {
-			RS_DIALOGFACTORY->requestSnapDistOptions(m_SnapDistance, snapMode.snapDistance);
-        }
+		RS_DIALOGFACTORY->requestSnapDistOptions(m_SnapDistance, snapMode.snapDistance);
         t = snapDist(mouseCoord);
 		double ds2=mouseCoord.squaredTo(t);
         if (ds2 < ds2Min){
@@ -249,7 +254,7 @@ RS_Vector RS_Snapper::snapPoint(QMouseEvent* e) {
         t = snapGrid(mouseCoord);
 		double ds2=mouseCoord.squaredTo(t);
         if (ds2 < ds2Min){
-            ds2Min=ds2;
+//            ds2Min=ds2;
 			pImpData->snapSpot = t;
         }
     }
@@ -309,11 +314,10 @@ RS_Vector RS_Snapper::snapPoint(const RS_Vector& coord, bool setSpot)
     if(coord.valid){
 		pImpData->snapSpot=coord;
 		if(setSpot) pImpData->snapCoord = coord;
-        drawSnapper();
-		if (RS_DIALOGFACTORY) {
-			RS_DIALOGFACTORY->updateCoordinateWidget(pImpData->snapCoord,
+		drawSnapper();
+		RS_DIALOGFACTORY->updateCoordinateWidget(
+					pImpData->snapCoord,
 					pImpData->snapCoord - graphicView->getRelativeZero());
-        }
     }
     return coord;
 }
@@ -694,129 +698,208 @@ void RS_Snapper::showOptions() {
 /**
  * Deletes the snapper from the screen.
  */
-void RS_Snapper::deleteSnapper() {// RVT_PORT (can be deleted??)
-        RS_DEBUG->print("RS_Snapper::Delete Snapper");
-
-        graphicView->getOverlayContainer(RS2::Snapper)->clear();
-        graphicView->redraw(RS2::RedrawOverlay); // redraw will happen in the mouse movement event
+void RS_Snapper::deleteSnapper()
+{
+    graphicView->getOverlayContainer(RS2::Snapper)->clear();
+    graphicView->redraw(RS2::RedrawOverlay); // redraw will happen in the mouse movement event
 }
 
 
 
 /**
- * We could properly speed this up by calling the draw function of this snapper within the paint event
- * this will avoid creating/deletion of the lines
+ * creates the snap indicator
  */
-
-void RS_Snapper::drawSnapper() {
-	//clear the old snaper from overlay
-	graphicView->getOverlayContainer(RS2::Snapper)->clear();
-	if (!finished && pImpData->snapSpot) {
-		RS_EntityContainer *container=graphicView->getOverlayContainer(RS2::Snapper);
-
-		if (pImpData->snapCoord) {
-			RS_DEBUG->print("RS_Snapper::Snapped draw start");
-			// Pen for snapper
-			RS_Pen pen(RS_Color(255,194,0), RS2::Width00, RS2::SolidLine);
-			pen.setScreenWidth(1);
-
-			// Circle to show snap area
-			RS_Circle *circle=new RS_Circle(container,
-			{pImpData->snapCoord, 4/graphicView->getFactor().x});
-			circle->setPen(pen);
-
-			container->addEntity(circle);
-
-			// crosshairs:
-			if (showCrosshairs) {
-				if(graphicView->isGridIsometric())
-					//isometric crosshair
-					drawCrossHairIso();
-				else
-					//orthogonal crosshair
-					drawCrossHairOrth();
-			}
-			graphicView->redraw(RS2::RedrawOverlay); // redraw will happen in the mouse movement event
-			RS_DEBUG->print("RS_Snapper::Snapped draw end");
-		}
-		if (pImpData->snapCoord && pImpData->snapCoord != pImpData->snapSpot) {
-
-			RS_OverlayLine *line=new RS_OverlayLine(container,
-			{graphicView->toGui(pImpData->snapSpot)+RS_Vector{-5.,0.},
-			 graphicView->toGui(pImpData->snapSpot)+RS_Vector{-1.,4.}});
-			line->setPen(crossHairPen);
-			container->addEntity(line);
-			line=new RS_OverlayLine(container,
-			{graphicView->toGui(pImpData->snapSpot)+RS_Vector{0.,5.},
-			 graphicView->toGui(pImpData->snapSpot)+RS_Vector{4.,1.}});
-			line->setPen(crossHairPen);
-			container->addEntity(line);
-			line=new RS_OverlayLine(container,
-			{graphicView->toGui(pImpData->snapSpot)+RS_Vector{5.,0.},
-			 graphicView->toGui(pImpData->snapSpot)+RS_Vector{1.,-4.}});
-			line->setPen(crossHairPen);
-			container->addEntity(line);
-			line=new RS_OverlayLine(container,
-			{graphicView->toGui(pImpData->snapSpot)+RS_Vector{0.,-5.},
-			 graphicView->toGui(pImpData->snapSpot)+RS_Vector{-4.,-1.}});
-			line->setPen(crossHairPen);
-			container->addEntity(line);
-
-			graphicView->redraw(RS2::RedrawOverlay); // redraw will happen in the mouse movement event
-		}
-	}
-}
-
-//draw crosshair isometric
-void RS_Snapper::drawCrossHairIso()
+void RS_Snapper::drawSnapper()
 {
-	auto container=graphicView->getOverlayContainer(RS2::Snapper);
-	RS2::CrosshairType chType=graphicView->getCrosshairType();
-	RS_Vector direction1;
-	RS_Vector direction2{0.,1.};
-	double const l=graphicView->getWidth()+graphicView->getHeight();
-	switch(chType){
-	case RS2::RightCrosshair:
-		direction1=RS_Vector(M_PI*5./6.)*l;
-		direction2*=l;
-		break;
-	case RS2::LeftCrosshair:
-		direction1=RS_Vector(M_PI*1./6.)*l;
-		direction2*=l;
-		break;
-	default:
-		direction1=RS_Vector(M_PI*1./6.)*l;
-		direction2=RS_Vector(M_PI*5./6.)*l;
-	}
-	RS_Vector const& center = graphicView->toGui(pImpData->snapCoord);
-	RS_OverlayLine *line=new RS_OverlayLine(container,
-	{center-direction1,center+direction1});
-	line->setPen(crossHairPen);
-	container->addEntity(line);
-	line=new RS_OverlayLine(container,
-	{center-direction2,center+direction2});
-	line->setPen(crossHairPen);
-	container->addEntity(line);
-}
+    // We could properly speed this up by calling the draw function of this snapper within the paint event
+    // this will avoid creating/deletion of the lines
 
-//draw crosshair orthogonal
-void RS_Snapper::drawCrossHairOrth()
-{
-	auto container=graphicView->getOverlayContainer(RS2::Snapper);
+    graphicView->getOverlayContainer(RS2::Snapper)->clear();
+	if (!finished && pImpData->snapSpot.valid)
+    {
+        RS_EntityContainer *container=graphicView->getOverlayContainer(RS2::Snapper);
 
-	RS_OverlayLine *line=new RS_OverlayLine(container,
-	{{0., graphicView->toGuiY(pImpData->snapCoord.y)},
-	 {double(graphicView->getWidth()), graphicView->toGuiY(pImpData->snapCoord.y)}
-											});
-	line->setPen(crossHairPen);
-	container->addEntity(line);
+        if (snap_indicator->lines_state)
+        {
+            QString type = snap_indicator->lines_type;
 
-	line=new RS_OverlayLine(container,
-	{{graphicView->toGuiX(pImpData->snapCoord.x),0.},
-	 {graphicView->toGuiX(pImpData->snapCoord.x),
-	  double(graphicView->getHeight())}});
-	line->setPen(crossHairPen);
-	container->addEntity(line);
+            if (type == "Crosshair")
+            {
+                RS_OverlayLine *line = new RS_OverlayLine(nullptr,
+                    {{0., graphicView->toGuiY(pImpData->snapCoord.y)},
+                    {double(graphicView->getWidth()),
+                    graphicView->toGuiY(pImpData->snapCoord.y)}});
+
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+
+                line = new RS_OverlayLine(nullptr,
+                    {{graphicView->toGuiX(pImpData->snapCoord.x),0.},
+                    {graphicView->toGuiX(pImpData->snapCoord.x),
+                    double(graphicView->getHeight())}});
+
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+            }
+            else if (type == "Crosshair2")
+            {
+                double xenoRadius=16;
+
+                double snapX=graphicView->toGuiX(pImpData->snapCoord.x);
+                double snapY=graphicView->toGuiY(pImpData->snapCoord.y);
+
+                double viewWidth=double(graphicView->getWidth());
+                double viewHeight=double(graphicView->getHeight());
+
+                RS_OverlayLine *line;
+
+                // ----O     (Left)
+                line=new RS_OverlayLine(nullptr, {
+                    {0., snapY},
+                    {snapX-xenoRadius, snapY}
+                });
+                {
+                    line->setPen(snap_indicator->lines_pen);
+                    container->addEntity(line);
+                }
+
+                //     O---- (Right)
+                line=new RS_OverlayLine(nullptr, {
+                    {snapX+xenoRadius, snapY},
+                    {viewWidth, snapY}
+                });
+                {
+                    line->setPen(snap_indicator->lines_pen);
+                    container->addEntity(line);
+                }
+
+                // (Top)
+                line=new RS_OverlayLine(nullptr, {
+                    {snapX, 0.},
+                    {snapX, snapY-xenoRadius}
+                });
+                {
+                    line->setPen(snap_indicator->lines_pen);
+                    container->addEntity(line);
+                }
+
+                // (Bottom)
+                line=new RS_OverlayLine(nullptr, {
+                    {snapX, snapY+xenoRadius},
+                    {snapX, viewHeight}
+                });
+                {
+                    line->setPen(snap_indicator->lines_pen);
+                    container->addEntity(line);
+                }
+            }
+            else if (type == "Isometric")
+            {
+                //isometric crosshair
+                RS2::CrosshairType chType=graphicView->getCrosshairType();
+                RS_Vector direction1;
+                RS_Vector direction2(0.,1.);
+                double l=graphicView->getWidth()+graphicView->getHeight();
+                switch(chType){
+                case RS2::RightCrosshair:
+                    direction1=RS_Vector(M_PI*5./6.)*l;
+                    direction2*=l;
+                    break;
+                case RS2::LeftCrosshair:
+                    direction1=RS_Vector(M_PI*1./6.)*l;
+                    direction2*=l;
+                    break;
+                default:
+                    direction1=RS_Vector(M_PI*1./6.)*l;
+                    direction2=RS_Vector(M_PI*5./6.)*l;
+                }
+                RS_Vector center(graphicView->toGui(pImpData->snapCoord));
+                RS_OverlayLine *line=new RS_OverlayLine(container,
+                {center-direction1,center+direction1});
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+                line=new RS_OverlayLine(nullptr,
+                {center-direction2,center+direction2});
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+            }
+            else if (type == "Spiderweb")
+            {
+                RS_OverlayLine* line;
+                RS_Vector point1;
+                RS_Vector point2;
+
+                point1 = RS_Vector{0, 0};
+                point2 = RS_Vector{graphicView->toGuiX(pImpData->snapCoord.x),
+                                   graphicView->toGuiY(pImpData->snapCoord.y)};
+                line=new RS_OverlayLine{nullptr, {point1, point2}};
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+
+                point1 = RS_Vector(0, graphicView->getHeight());
+                line = new RS_OverlayLine{nullptr, {point1, point2}};
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+
+                point1 = RS_Vector(graphicView->getWidth(), 0);
+                line = new RS_OverlayLine(nullptr, {point1, point2});
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+
+                point1 = RS_Vector(graphicView->getWidth(), graphicView->getHeight());
+                line = new RS_OverlayLine(nullptr, {point1, point2});
+                line->setPen(snap_indicator->lines_pen);
+                container->addEntity(line);
+            }
+        }
+        if (snap_indicator->shape_state)
+        {
+            QString type = snap_indicator->shape_type;
+
+            if (type == "Circle")
+            {
+                RS_Circle *circle=new RS_Circle(container,
+                    {pImpData->snapCoord, 4./graphicView->getFactor().x});
+                circle->setPen(snap_indicator->shape_pen);
+                container->addEntity(circle);
+            }
+            else if (type == "Point")
+            {
+                RS_Point *point=new RS_Point(container, pImpData->snapCoord);
+                point->setPen(snap_indicator->shape_pen);
+                container->addEntity(point);
+            }
+            else if (type == "Square")
+            {
+                RS_Vector snap_point{graphicView->toGuiX(pImpData->snapCoord.x),
+                                     graphicView->toGuiY(pImpData->snapCoord.y)};
+
+                double a = 6.0;
+                RS_Vector p1 = snap_point + RS_Vector(-a, a);
+                RS_Vector p2 = snap_point + RS_Vector(a, a);
+                RS_Vector p3 = snap_point + RS_Vector(a, -a);
+                RS_Vector p4 = snap_point + RS_Vector(-a, -a);
+
+                RS_OverlayLine* line;
+                line=new RS_OverlayLine{nullptr, {p1, p2}};
+                line->setPen(snap_indicator->shape_pen);
+                container->addEntity(line);
+
+                line = new RS_OverlayLine{nullptr, {p2, p3}};
+                line->setPen(snap_indicator->shape_pen);
+                container->addEntity(line);
+
+                line = new RS_OverlayLine(nullptr, {p3, p4});
+                line->setPen(snap_indicator->shape_pen);
+                container->addEntity(line);
+
+                line = new RS_OverlayLine(nullptr, {p4, p1});
+                line->setPen(snap_indicator->shape_pen);
+                container->addEntity(line);
+            }
+        }
+        graphicView->redraw(RS2::RedrawOverlay); // redraw will happen in the mouse movement event
+    }
 }
 
 /**
