@@ -30,7 +30,6 @@
 
 #include<memory>
 #include "rs.h"
-#include "rs_vector.h"
 
 class RS_Entity;
 class RS_GraphicView;
@@ -198,19 +197,14 @@ protected:
      * Snap range for catching entities.
      */
     int snapRange;
-    /**
-     * Show large cross hairs.
-     */
-    bool showCrosshairs;
     bool finished{false};
 
 private:
-	//draw crosshair isometric
-	void drawCrossHairIso();
-	//draw crosshair orthogonal
-	void drawCrossHairOrth();
 	struct ImpData;
 	std::unique_ptr<ImpData> pImpData;
+
+    struct Indicator;
+    Indicator* snap_indicator{nullptr};
 };
 
 #endif
