@@ -49,8 +49,6 @@ class RS_Polyline;
 class RS_Text;
 class RS_Layer;
 class LC_Quadratic;
-class RS_GraphicView;
-
 class RS_Vector;
 class RS_VectorSolutions;
 class QString;
@@ -209,7 +207,7 @@ public:
 
 	bool isLocked() const;
 
-    virtual void undoStateChanged(bool undone);
+	void undoStateChanged(bool undone) override;
     virtual bool isUndone() const;
 
     /**
