@@ -34,9 +34,7 @@
  * Holds the data that defines a point.
  */
 struct RS_PointData {
-    RS_PointData(const RS_Vector& pos) {
-        this->pos = pos;
-    }
+    RS_PointData(const RS_Vector& pos): pos(pos) {}
 
     friend std::ostream& operator << (std::ostream& os, const RS_PointData& pd);
 
@@ -53,66 +51,66 @@ public:
     RS_Point(RS_EntityContainer* parent,
              const RS_PointData& d);
 
-	virtual RS_Entity* clone() const;
+	RS_Entity* clone() const override;
 
     /**	@return RS_ENTITY_POINT */
-    virtual RS2::EntityType rtti() const;
+	RS2::EntityType rtti() const override;
 
     /**
          * @return Start point of the entity.
          */
-    virtual RS_Vector getStartpoint() const;
+	RS_Vector getStartpoint() const override;
     /**
          * @return End point of the entity.
          */
-    virtual RS_Vector getEndpoint() const;
+	RS_Vector getEndpoint() const override;
 
-        virtual void moveStartpoint(const RS_Vector& pos);
+		void moveStartpoint(const RS_Vector& pos) override;
 
     /** @return Copy of data that defines the point. */
     RS_PointData getData() const;
 
-	virtual RS_VectorSolutions getRefPoints() const;
+	RS_VectorSolutions getRefPoints() const override;
 
     /** @return Position of the point */
     RS_Vector getPos() const;
 
     /** Sets a new position for this point. */
     void setPos(const RS_Vector& pos);
-    virtual RS_Vector getCenter() const;
-    virtual double getRadius() const;
-    virtual bool isTangent(const RS_CircleData& circleData) const;
+	RS_Vector getCenter() const override;
+	double getRadius() const override;
+	bool isTangent(const RS_CircleData& circleData) const override;
 
-    virtual RS_Vector getMiddlePoint(void)const;
-    virtual RS_Vector getNearestEndpoint(const RS_Vector& coord,
-                                         double* dist = nullptr)const;
-    virtual RS_Vector getNearestPointOnEntity(const RS_Vector& coord,
-            bool onEntity = true, double* dist = nullptr, RS_Entity** entity = nullptr)const;
-    virtual RS_Vector getNearestCenter(const RS_Vector& coord,
-                                       double* dist = nullptr)const;
-    virtual RS_Vector getNearestMiddle(const RS_Vector& coord,
+	RS_Vector getMiddlePoint(void)const override;
+	RS_Vector getNearestEndpoint(const RS_Vector& coord,
+										 double* dist = nullptr)const override;
+	RS_Vector getNearestPointOnEntity(const RS_Vector& coord,
+			bool onEntity = true, double* dist = nullptr, RS_Entity** entity = nullptr)const override;
+	RS_Vector getNearestCenter(const RS_Vector& coord,
+									   double* dist = nullptr)const override;
+	RS_Vector getNearestMiddle(const RS_Vector& coord,
                                        double* dist = nullptr,
-                                       int middlePoints = 1)const;
-    virtual RS_Vector getNearestDist(double distance,
+									   int middlePoints = 1)const override;
+	RS_Vector getNearestDist(double distance,
                                      const RS_Vector& coord,
-                                     double* dist = nullptr)const;
-    virtual double getDistanceToPoint(const RS_Vector& coord,
+									 double* dist = nullptr)const override;
+	double getDistanceToPoint(const RS_Vector& coord,
                                       RS_Entity** entity=nullptr,
                                       RS2::ResolveLevel level=RS2::ResolveNone,
-                                                                          double solidDist = RS_MAXDOUBLE)const;
+							  double solidDist = RS_MAXDOUBLE)const override;
 
-    virtual void move(const RS_Vector& offset);
-    virtual void rotate(const RS_Vector& center, const double& angle);
-    virtual void rotate(const RS_Vector& center, const RS_Vector& angleVector);
-    virtual void scale(const RS_Vector& center, const RS_Vector& factor);
-    virtual void mirror(const RS_Vector& axisPoint1, const RS_Vector& axisPoint2);
+	void move(const RS_Vector& offset) override;
+	void rotate(const RS_Vector& center, const double& angle) override;
+	void rotate(const RS_Vector& center, const RS_Vector& angleVector) override;
+	void scale(const RS_Vector& center, const RS_Vector& factor) override;
+	void mirror(const RS_Vector& axisPoint1, const RS_Vector& axisPoint2) override;
 
-    virtual void draw(RS_Painter* painter, RS_GraphicView* view, double& patternOffset);
+	void draw(RS_Painter* painter, RS_GraphicView* view, double& patternOffset) override;
 
     friend std::ostream& operator << (std::ostream& os, const RS_Point& p);
 
     /** Recalculates the borders of this entity. */
-    virtual void calculateBorders ();
+	void calculateBorders () override;
 
 protected:
     RS_PointData data;
