@@ -26,13 +26,11 @@
 
 #include <iostream>
 #include <cmath>
-
+#include <algorithm>
 #include "rs_vector.h"
-
-
 #include "rs_debug.h"
 #include "rs_math.h"
-#include "rs_constructionline.h"
+#include "lc_rect.h"
 
 #ifdef EMU_C99
 #include "emu_c99.h" /* remainder() */
@@ -41,14 +39,6 @@
 /**
  * Constructor for a point with given coordinates.
  */
-#ifdef  RS_VECTOR2D
-RS_Vector::RS_Vector(double vx, double vy):
-	x(vx)
-  ,y(vy)
-  ,valid(true)
-{
-}
-#else
 RS_Vector::RS_Vector(double vx, double vy, double vz):
 	x(vx)
   ,y(vy)
@@ -56,7 +46,6 @@ RS_Vector::RS_Vector(double vx, double vy, double vz):
   ,valid(true)
 {
 }
-#endif
 
 /**
  * Constructor for a unit vector with given angle
@@ -90,25 +79,17 @@ RS_Vector::operator bool() const
 void RS_Vector::set(double angle) {
     x = cos(angle);
     y = sin(angle);
-#ifndef RS_VECTOR2D
     z = 0.;
-#endif
     valid = true;
 }
 
 /**
  * Sets a new position for the vector.
  */
-#ifdef  RS_VECTOR2D
-void RS_Vector::set(double vx, double vy) {
-#else
 void RS_Vector::set(double vx, double vy, double vz) {
-#endif
     x = vx;
     y = vy;
-#ifndef RS_VECTOR2D
     z = vz;
-#endif
     valid = true;
 }
 
@@ -118,18 +99,12 @@ void RS_Vector::set(double vx, double vy, double vz) {
 void RS_Vector::setPolar(double radius, double angle) {
     x = radius * cos(angle);
     y = radius * sin(angle);
-#ifndef RS_VECTOR2D
     z = 0.0;
-#endif
     valid = true;
 }
 
 RS_Vector RS_Vector::polar(double rho, double theta){
-	return RS_Vector(rho*cos(theta), rho*sin(theta)
-				 #ifndef RS_VECTOR2D
-					 , 0.
-				 #endif
-					 );
+	return {rho*cos(theta), rho*sin(theta), 0.};
 }
 
 /**
@@ -153,8 +128,8 @@ double RS_Vector::angleTo(const RS_Vector& v) const {
  */
 double RS_Vector::angleBetween(const RS_Vector& v1, const RS_Vector& v2) const {
 	if (!valid || !v1.valid || !v2.valid) return 0.0;
-	RS_Vector const vStart(v1- (*this));
-	RS_Vector const vEnd(v2- (*this));
+	RS_Vector const vStart(v1 - (*this));
+	RS_Vector const vEnd(v2 - (*this));
 	return RS_Math::correctAngle( atan2( vStart.x*vEnd.y-vStart.y*vEnd.x, vStart.x*vEnd.x+vStart.y*vEnd.y));
 }
 
@@ -165,13 +140,8 @@ double RS_Vector::magnitude() const {
     double ret(0.0);
     // Note that the z coordinate is also needed for 2d
     //   (due to definition of crossP())
-    if (valid) {
-#ifdef  RS_VECTOR2D
-        ret = sqrt(x*x + y*y);
-#else
-        ret = sqrt(x*x + y*y + z*z);
-#endif
-    }
+	if (valid)
+		ret = hypot(hypot(x, y), z);
 
     return ret;
 }
@@ -182,13 +152,8 @@ double RS_Vector::magnitude() const {
 double RS_Vector::squared() const {
     // Note that the z coordinate is also needed for 2d
     //   (due to definition of crossP())
-    if (valid) {
-#ifdef  RS_VECTOR2D
-        return x*x + y*y;
-#else
+	if (valid)
         return x*x + y*y + z*z;
-#endif
-    }
     return RS_MAXDOUBLE;
 }
 
@@ -207,7 +172,7 @@ double RS_Vector::squaredTo(const RS_Vector& v1) const
  *
  */
 RS_Vector RS_Vector::lerp(const RS_Vector& v, double t) const {
-    return RS_Vector(x+(v.x-x)*t, y+(v.y-y)*t);
+	return {x+(v.x-x)*t, y+(v.y-y)*t};
 }
 
 /**
@@ -227,11 +192,8 @@ double RS_Vector::distanceTo(const RS_Vector& v) const {
  */
 bool RS_Vector::isInWindow(const RS_Vector& firstCorner,
 						   const RS_Vector& secondCorner) const {
-	RS_Vector vLow( std::min(firstCorner.x, secondCorner.x), std::min(firstCorner.y, secondCorner.y));
-	RS_Vector vHigh( std::max(firstCorner.x, secondCorner.x), std::max(firstCorner.y, secondCorner.y));
-
-	if(!valid) return false;
-	return isInWindowOrdered(vLow,vHigh);
+	if (!valid) return false;
+	return LC_Rect{firstCorner, secondCorner}.inArea(*this);
 }
 
 /**
@@ -264,8 +226,8 @@ RS_Vector RS_Vector::move(const RS_Vector& offset) {
 /**
  * Rotates this vector around 0/0 by the given angle.
  */
-RS_Vector RS_Vector::rotate(const double& ang) {
-    rotate(RS_Vector(ang));
+RS_Vector RS_Vector::rotate(double ang) {
+	rotate(RS_Vector{ang});
     return *this;
 }
 
@@ -285,7 +247,7 @@ RS_Vector RS_Vector::rotate(const RS_Vector& angleVector) {
 /**
  * Rotates this vector around the given center by the given angle.
  */
-RS_Vector RS_Vector::rotate(const RS_Vector& center, const double& ang) {
+RS_Vector RS_Vector::rotate(const RS_Vector& center, double ang) {
     *this = center + (*this-center).rotate(ang);
     return *this;
 }
@@ -297,7 +259,7 @@ RS_Vector RS_Vector::rotate(const RS_Vector& center, const RS_Vector& angleVecto
 /**
  * Scales this vector by the given factors with 0/0 as center.
  */
-RS_Vector RS_Vector::scale(const double& factor) {
+RS_Vector RS_Vector::scale(double factor) {
     x *= factor;
     y *= factor;
     return *this;
@@ -313,7 +275,7 @@ RS_Vector RS_Vector::scale(const RS_Vector& factor) {
 }
 
 RS_Vector RS_Vector::scale(const RS_Vector& factor) const{
-	return RS_Vector(x*factor.x, y*factor.y);
+	return {x*factor.x, y*factor.y};
 }
 
 /**
@@ -348,11 +310,7 @@ RS_Vector RS_Vector::mirror(const RS_Vector& axisPoint1, const RS_Vector& axisPo
  */
 std::ostream& operator << (std::ostream& os, const RS_Vector& v) {
     if(v.valid) {
-#ifdef  RS_VECTOR2D
-        os << v.x << "/" << v.y ;
-#else
         os << v.x << "/" << v.y << "/" << v.z;
-#endif
     } else {
         os << "invalid vector";
     }
@@ -365,11 +323,7 @@ std::ostream& operator << (std::ostream& os, const RS_Vector& v) {
  * binary + operator.
  */
 RS_Vector RS_Vector::operator + (const RS_Vector& v) const {
-#ifdef  RS_VECTOR2D
-    return RS_Vector(x + v.x, y + v.y);
-#else
-    return RS_Vector(x + v.x, y + v.y, z + v.z);
-#endif
+	return {x + v.x, y + v.y, z + v.z};
 }
 
 
@@ -378,74 +332,42 @@ RS_Vector RS_Vector::operator + (const RS_Vector& v) const {
  * binary - operator.
  */
 RS_Vector RS_Vector::operator - (const RS_Vector& v) const {
-#ifdef  RS_VECTOR2D
-    return RS_Vector(x - v.x, y - v.y);
-#else
-    return RS_Vector(x - v.x, y - v.y, z - v.z);
-#endif
+	return {x - v.x, y - v.y, z - v.z};
 }
 
 RS_Vector RS_Vector::operator + (double d) const {
-#ifdef  RS_VECTOR2D
-	return RS_Vector(x + d, y + d);
-#else
-	return RS_Vector(x + d, y + d, z + d);
-#endif
+	return {x + d, y + d, z + d};
 }
 
 RS_Vector RS_Vector::operator - (double d) const {
-#ifdef  RS_VECTOR2D
-	return RS_Vector(x - d, y - d);
-#else
-	return RS_Vector(x - d, y - d, z - d);
-#endif
+	return {x - d, y - d, z - d};
 }
 
 RS_Vector RS_Vector::operator * (const RS_Vector& v) const {
-#ifdef  RS_VECTOR2D
-	return RS_Vector(x * v.x, y * v.y);
-#else
-	return RS_Vector(x * v.x, y * v.y, z * v.z);
-#endif
+	return {x * v.x, y * v.y, z * v.z};
 }
 
 RS_Vector RS_Vector::operator / (const RS_Vector& v) const {
-	if(fabs(v.x)> RS_TOLERANCE && fabs(v.y)>RS_TOLERANCE
-#ifndef  RS_VECTOR2D
-			&& fabs(v.z)
-#endif
-			){
-#ifdef  RS_VECTOR2D
-	return RS_Vector(x / v.x, y / v.y);
-#else
-	return RS_Vector(x / v.x, y / v.y, z / v.z);
-#endif
-	}
+	if(fabs(v.x)> RS_TOLERANCE && fabs(v.y)>RS_TOLERANCE)
+		return {x / v.x, y / v.y, std::isnormal(v.z)?z / v.z:z};
+
 	return *this;
 }
 
 /**
  * binary * operator.
  */
-RS_Vector RS_Vector::operator * (const double& s) const {
-#ifdef  RS_VECTOR2D
-    return RS_Vector(x * s, y * s);
-#else
-    return RS_Vector(x * s, y * s, z * s);
-#endif
+RS_Vector RS_Vector::operator * (double s) const {
+	return {x * s, y * s, z * s};
 }
 
 /**
  * binary / operator.
  */
-RS_Vector RS_Vector::operator / (const double& s) const {
-	if(fabs(s)> RS_TOLERANCE){
-#ifdef  RS_VECTOR2D
-		return RS_Vector(x / s, y / s);
-#else
-		return RS_Vector(x / s, y / s, z / s);
-#endif
-	}
+RS_Vector RS_Vector::operator / (double s) const {
+	if(fabs(s)> RS_TOLERANCE)
+		return {x / s, y / s, z / s};
+
 	return *this;
 }
 
@@ -453,11 +375,7 @@ RS_Vector RS_Vector::operator / (const double& s) const {
  * unary - operator.
  */
 RS_Vector RS_Vector::operator - () const {
-#ifdef  RS_VECTOR2D
-    return RS_Vector(-x, -y);
-#else
-    return RS_Vector(-x, -y, -z);
-#endif
+	return {-x, -y, -z};
 }
 
 /**
@@ -469,16 +387,12 @@ double RS_Vector::dotP(const RS_Vector& v1) const
 }
 
 double RS_Vector::dotP(const RS_Vector& v1, const RS_Vector& v2) {
-#ifdef  RS_VECTOR2D
-    return v1.x * v2.x + v1.y * v2.y;
-#else
-    return v1.x * v2.x + v1.y * v2.y + v1.z * v2.z;
-#endif
+	return v1.x * v2.x + v1.y * v2.y + v1.z * v2.z;
 }
 
 /** switch x,y for all vectors */
 RS_Vector RS_Vector::flipXY(void) const{
-        return RS_Vector(y,x);
+	return {y, x};
 }
 
 /**
@@ -487,9 +401,7 @@ RS_Vector RS_Vector::flipXY(void) const{
 RS_Vector RS_Vector::operator += (const RS_Vector& v) {
     x += v.x;
     y += v.y;
-#ifndef RS_VECTOR2D
     z += v.z;
-#endif
 	return *this;
 }
 
@@ -499,32 +411,23 @@ RS_Vector RS_Vector::operator += (const RS_Vector& v) {
 RS_Vector RS_Vector::operator -= (const RS_Vector& v) {
     x -= v.x;
     y -= v.y;
-#ifndef RS_VECTOR2D
     z -= v.z;
-#endif
 	return *this;
 }
 
 RS_Vector RS_Vector::operator *= (const RS_Vector& v) {
 	x *= v.x;
 	y *= v.y;
-#ifndef RS_VECTOR2D
 	z *= v.z;
-#endif
 	return *this;
 }
 
 RS_Vector RS_Vector::operator /= (const RS_Vector& v) {
-	if(fabs(v.x)> RS_TOLERANCE && fabs(v.y)>RS_TOLERANCE
-#ifndef  RS_VECTOR2D
-			&& fabs(v.z)
-#endif
-			){
+	if (fabs(v.x)> RS_TOLERANCE && fabs(v.y)>RS_TOLERANCE){
 		x /= v.x;
 		y /= v.y;
-#ifndef RS_VECTOR2D
-		z /= v.z;
-#endif
+		if (std::isnormal(v.z))
+			z /= v.z;
 	}
 	return *this;
 }
@@ -532,25 +435,21 @@ RS_Vector RS_Vector::operator /= (const RS_Vector& v) {
 /**
  * *= operator
  */
-RS_Vector RS_Vector::operator *= (const double& s) {
+RS_Vector RS_Vector::operator *= (double s) {
     x *= s;
     y *= s;
-#ifndef RS_VECTOR2D
     z *= s;
-#endif
 	return *this;
 }
 /**
  * /= operator
  */
-RS_Vector RS_Vector::operator /= (const double& s) {
-    if(fabs(s)>RS_TOLERANCE) {
-    x /= s;
-    y /= s;
-#ifndef RS_VECTOR2D
-    z /= s;
-#endif
-    }
+RS_Vector RS_Vector::operator /= (double s) {
+	if(fabs(s)>RS_TOLERANCE) {
+		x /= s;
+		y /= s;
+		z /= s;
+	}
 	return *this;
 }
 
@@ -558,11 +457,7 @@ RS_Vector RS_Vector::operator /= (const double& s) {
  * == operator
  */
 bool RS_Vector::operator == (const RS_Vector& v) const {
-#ifdef  RS_VECTOR2D
-    return (x==v.x && y==v.y && valid==v.valid);
-#else
-    return (x==v.x && y==v.y && z==v.z && valid==v.valid);
-#endif
+	return (x==v.x && y==v.y && z==v.z && valid && v.valid);
 }
 
 bool RS_Vector::operator == (bool valid) const
@@ -580,37 +475,35 @@ bool RS_Vector::operator != (bool valid) const
  * These might be mixed components from both vectors.
  */
 RS_Vector RS_Vector::minimum (const RS_Vector& v1, const RS_Vector& v2) {
-    return RS_Vector (std::min(v1.x, v2.x),
-                      std::min(v1.y, v2.y)
-#ifndef RS_VECTOR2D
-                      , std::min(v1.z, v2.z)
-#endif
-                      );
+	if (!v2) return v1;
+	if (!v1) return v2;
+	return {std::min(v1.x, v2.x),
+				std::min(v1.y, v2.y),
+				std::min(v1.z, v2.z)
+	};
 }
 
 /**
  * @return A vector with the maximum values from the vectors v1 and v2
  */
 RS_Vector RS_Vector::maximum (const RS_Vector& v1, const RS_Vector& v2) {
-    return RS_Vector (std::max(v1.x, v2.x),
-                      std::max(v1.y, v2.y)
-#ifndef RS_VECTOR2D
-                      , std::max(v1.z, v2.z)
-#endif
-                      );
+	if (!v2) return v1;
+	if (!v1) return v2;
+	return {std::max(v1.x, v2.x),
+				std::max(v1.y, v2.y),
+				std::max(v1.z, v2.z)
+	};
 }
 
 /**
  * @return Cross product of two vectors.
  *  we don't need cross product for 2D vectors
  */
-#ifndef RS_VECTOR2D
 RS_Vector RS_Vector::crossP(const RS_Vector& v1, const RS_Vector& v2) {
-    return RS_Vector(v1.y*v2.z - v1.z*v2.y,
-                     v1.z*v2.x - v1.x*v2.z,
-                     v1.x*v2.y - v1.y*v2.x);
+	return {v1.y*v2.z - v1.z*v2.y,
+				v1.z*v2.x - v1.x*v2.z,
+				v1.x*v2.y - v1.y*v2.x};
 }
-#endif
 
 /**
  * Constructor for no solution.
@@ -649,22 +542,16 @@ void RS_VectorSolutions::alloc(size_t num) {
 	if(num<=vector.size()){
 		vector.resize(num);
 	}else{
-		const std::vector<RS_Vector> v(num - vector.size(), RS_Vector(false));
+		const std::vector<RS_Vector> v(num - vector.size());
 		vector.insert(vector.end(), v.begin(), v.end());
 	}
 }
 
-void RS_VectorSolutions::clean()
-{
-	vector.clear();
-	tangent = false;
-}
-
 RS_Vector RS_VectorSolutions::get(size_t i) const
 {
 	if(i<vector.size())
 		return vector.at(i);
-	return RS_Vector(false);
+	return {};
 }
 
 const RS_Vector&  RS_VectorSolutions::operator [] (const size_t i) const
@@ -752,7 +639,7 @@ void RS_VectorSolutions::removeAt(const size_t i){
 		vector.erase(vector.begin()+i);
 }
 
-RS_VectorSolutions RS_VectorSolutions::appendTo(const RS_VectorSolutions& v) {
+RS_VectorSolutions& RS_VectorSolutions::push_back(const RS_VectorSolutions& v) {
 	vector.insert(vector.end(), v.begin(), v.end());
     return *this;
 }
@@ -790,9 +677,9 @@ bool RS_VectorSolutions::isTangent() const {
 /**
  * Rotates all vectors around (0,0) by the given angle.
  */
-void RS_VectorSolutions::rotate(const double& ang) {
+void RS_VectorSolutions::rotate(double ang) {
     RS_Vector angleVector(ang);
-	for (RS_Vector& vp: vector) {
+	for (auto& vp: vector) {
 		if (vp.valid) {
 			vp.rotate(angleVector);
 		}
@@ -803,7 +690,7 @@ void RS_VectorSolutions::rotate(const double& ang) {
  * Rotates all vectors around (0,0) by the given angleVector.
  */
 void RS_VectorSolutions::rotate(const RS_Vector& angleVector) {
-	for (RS_Vector& vp: vector) {
+	for (auto& vp: vector) {
 		if (vp.valid) {
 			vp.rotate(angleVector);
 		}
@@ -813,9 +700,9 @@ void RS_VectorSolutions::rotate(const RS_Vector& angleVector) {
 /**
  * Rotates all vectors around the given center by the given angle.
  */
-void RS_VectorSolutions::rotate(const RS_Vector& center, const double& ang) {
+void RS_VectorSolutions::rotate(const RS_Vector& center, double ang) {
 	const RS_Vector angleVector(ang);
-	for (RS_Vector& vp: vector) {
+	for (auto& vp: vector) {
 		if (vp.valid) {
 			vp.rotate(center,angleVector);
 		}
@@ -823,9 +710,9 @@ void RS_VectorSolutions::rotate(const RS_Vector& center, const double& ang) {
 }
 
 void RS_VectorSolutions::rotate(const RS_Vector& center, const RS_Vector& angleVector) {
-	for (RS_Vector& vp: vector) {
+	for (auto& vp: vector) {
 		if (vp.valid) {
-			vp.rotate(center,angleVector);
+			vp.rotate(center, angleVector);
 		}
 	}
 }
@@ -845,7 +732,7 @@ void RS_VectorSolutions::move(const RS_Vector& vp) {
  * Scales all vectors by the given factors with the given center.
  */
 void RS_VectorSolutions::scale(const RS_Vector& center, const RS_Vector& factor) {
-	for (RS_Vector& vp: vector) {
+	for (auto& vp: vector) {
 		if (vp.valid) {
 			vp.scale(center, factor);
 		}
@@ -853,7 +740,7 @@ void RS_VectorSolutions::scale(const RS_Vector& center, const RS_Vector& factor)
 }
 
 void RS_VectorSolutions::scale( const RS_Vector& factor) {
-	for (RS_Vector& vp: vector) {
+	for (auto& vp: vector) {
 		if (vp.valid) {
 			vp.scale(factor);
         }
@@ -867,17 +754,17 @@ void RS_VectorSolutions::scale( const RS_Vector& factor) {
 RS_Vector RS_VectorSolutions::getClosest(const RS_Vector& coord,
 										 double* dist, size_t* index) const {
 
-    double curDist(0.);
+	double curDist{0.};
     double minDist = RS_MAXDOUBLE;
-    RS_Vector closestPoint(false);
+	RS_Vector closestPoint{false};
     int pos(0);
 
 	for (size_t i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            curDist = (coord - vector[i]).squared();
+		if (vector[i].valid) {
+			curDist = (coord - vector[i]).squared();
 
             if (curDist<minDist) {
-                closestPoint = vector[i];
+				closestPoint = vector[i];
                 minDist = curDist;
                 pos=i;
             }
@@ -898,7 +785,7 @@ RS_Vector RS_VectorSolutions::getClosest(const RS_Vector& coord,
   *@counts, only consider this many points within solution
   */
 double RS_VectorSolutions::getClosestDistance(const RS_Vector& coord,
-        int counts)
+											  int counts)
 {
     double ret=RS_MAXDOUBLE*RS_MAXDOUBLE;
     int i=vector.size();
@@ -919,7 +806,7 @@ double RS_VectorSolutions::getClosestDistance(const RS_Vector& coord,
 RS_VectorSolutions RS_VectorSolutions::flipXY(void) const
 {
         RS_VectorSolutions ret;
-		for(const RS_Vector& vp: vector)
+		for(const auto& vp: vector)
 			ret.push_back(vp.flipXY());
         return ret;
 }
