@@ -24,10 +24,9 @@
 **
 **********************************************************************/
 
-#include <QObject>
 #include <QRegExp>
+#include <QAction>
 #include <QMouseEvent>
-
 #include "rs_eventhandler.h"
 #include "rs_actioninterface.h"
 #include "rs_dialogfactory.h"
@@ -35,21 +34,18 @@
 #include "rs_coordinateevent.h"
 #include "rs_commands.h"
 #include "rs_math.h"
+#include "rs_snapper.h"
 #include "rs_debug.h"
 
-
 /**
  * Constructor.
  */
-RS_EventHandler::RS_EventHandler(RS_GraphicView* graphicView):
-    graphicView(graphicView)
-  ,defaultAction(nullptr)
-  ,coordinateInputEnabled(true)
+RS_EventHandler::RS_EventHandler(QObject* parent) : QObject(parent)
 {
+    connect(parent, SIGNAL(relative_zero_changed(const RS_Vector&)),
+            this, SLOT(setRelativeZero(const RS_Vector&)));
 }
 
-
-
 /**
  * Destructor.
  */
@@ -75,6 +71,11 @@ void RS_EventHandler::back() {
     QMouseEvent e(QEvent::MouseButtonRelease, QPoint(0,0),
                   Qt::RightButton, Qt::RightButton,Qt::NoModifier);
     mouseReleaseEvent(&e);
+    if (!hasAction() && q_action)
+    {
+        q_action->setChecked(false);
+        q_action = nullptr;
+    }
 }
 
 
@@ -89,7 +90,7 @@ void RS_EventHandler::enter() {
 
 
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
 void RS_EventHandler::mousePressEvent(QMouseEvent* e) {
     if(hasAction()){
@@ -109,7 +110,7 @@ void RS_EventHandler::mousePressEvent(QMouseEvent* e) {
 
 
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
 void RS_EventHandler::mouseReleaseEvent(QMouseEvent* e) {
     if(hasAction()){
@@ -135,27 +136,19 @@ void RS_EventHandler::mouseReleaseEvent(QMouseEvent* e) {
 
 
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
-void RS_EventHandler::mouseMoveEvent(QMouseEvent* e) {
-    if(hasAction()){
+void RS_EventHandler::mouseMoveEvent(QMouseEvent* e)
+{
+    if(hasAction())
         currentActions.last()->mouseMoveEvent(e);
-        e->accept();
-    } else {
-        if (defaultAction) {
-            defaultAction->mouseMoveEvent(e);
-            e->accept();
-        } else {
-            e->ignore();
-        }
-        //RS_DEBUG->print("currently no action defined");
-    }
+
+    else if (defaultAction)
+        defaultAction->mouseMoveEvent(e);
 }
 
-
-
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
 void RS_EventHandler::mouseLeaveEvent() {
 
@@ -172,7 +165,7 @@ void RS_EventHandler::mouseLeaveEvent() {
 
 
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
 void RS_EventHandler::mouseEnterEvent() {
 
@@ -188,7 +181,7 @@ void RS_EventHandler::mouseEnterEvent() {
 
 
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
 void RS_EventHandler::keyPressEvent(QKeyEvent* e) {
 
@@ -209,7 +202,7 @@ void RS_EventHandler::keyPressEvent(QKeyEvent* e) {
 
 
 /**
- * Called by RS_GraphicView
+ * Called by QG_GraphicView
  */
 void RS_EventHandler::keyReleaseEvent(QKeyEvent* e) {
 
@@ -283,14 +276,11 @@ void RS_EventHandler::commandEvent(RS_CommandEvent* e) {
                         RS_DEBUG->print("RS_EventHandler::commandEvent: 005");
                         RS_CoordinateEvent ce(RS_Vector(x,y));
                         RS_DEBUG->print("RS_EventHandler::commandEvent: 006");
-                        currentActions.last()->coordinateEvent(&ce);
-                    } else {
-                        if (RS_DIALOGFACTORY) {
-                            RS_DIALOGFACTORY->commandMessage(
-                                        "Expression Syntax Error");
-                        }
-                    }
-                    e->accept();
+						currentActions.last()->coordinateEvent(&ce);
+					} else
+						RS_DIALOGFACTORY->commandMessage(
+									"Expression Syntax Error");
+					e->accept();
                 }
 
                 // handle relative cartesian coordinate input:
@@ -302,18 +292,14 @@ void RS_EventHandler::commandEvent(RS_CommandEvent* e) {
                         double y = RS_Math::eval(cmd.mid(commaPos+1), &ok2);
 
                         if (ok1 && ok2) {
-                            RS_CoordinateEvent ce(RS_Vector(x,y) +
-                                                  graphicView->getRelativeZero());
+                            RS_CoordinateEvent ce(RS_Vector(x,y) + relative_zero);
 
                             currentActions.last()->coordinateEvent(&ce);
                             //                            currentActions[actionIndex]->coordinateEvent(&ce);
-                        } else {
-                            if (RS_DIALOGFACTORY) {
-                                RS_DIALOGFACTORY->commandMessage(
-                                            "Expression Syntax Error");
-                            }
-                        }
-                        e->accept();
+						} else
+							RS_DIALOGFACTORY->commandMessage(
+										"Expression Syntax Error");
+						e->accept();
                     }
                 }
 
@@ -330,12 +316,9 @@ void RS_EventHandler::commandEvent(RS_CommandEvent* e) {
 								RS_Vector::polar(r,RS_Math::deg2rad(a))};
                             RS_CoordinateEvent ce(pos);
                             currentActions.last()->coordinateEvent(&ce);
-                        } else {
-                            if (RS_DIALOGFACTORY) {
+						} else
                                 RS_DIALOGFACTORY->commandMessage(
                                             "Expression Syntax Error");
-                            }
-                        }
                         e->accept();
                     }
                 }
@@ -350,15 +333,11 @@ void RS_EventHandler::commandEvent(RS_CommandEvent* e) {
 
                         if (ok1 && ok2) {
 							RS_Vector pos = RS_Vector::polar(r,RS_Math::deg2rad(a));
-                            RS_CoordinateEvent ce(pos +
-                                                  graphicView->getRelativeZero());
+                            RS_CoordinateEvent ce(pos + relative_zero);
                             currentActions.last()->coordinateEvent(&ce);
-                        } else {
-                            if (RS_DIALOGFACTORY) {
+						} else
                                 RS_DIALOGFACTORY->commandMessage(
                                             "Expression Syntax Error");
-                            }
-                        }
                         e->accept();
                     }
                 }
@@ -503,6 +482,8 @@ void RS_EventHandler::setCurrentAction(RS_ActionInterface* action) {
     RS_DEBUG->print("RS_EventHandler::setCurrentAction: debugging actions");
     debugActions();
     RS_DEBUG->print("RS_GraphicView::setCurrentAction: OK");
+    if (q_action)
+        q_action->setChecked(true);
 }
 
 
@@ -535,10 +516,20 @@ void RS_EventHandler::killSelectActions() {
 /**
  * Kills all running actions. Called when a window is closed.
  */
-void RS_EventHandler::killAllActions() {
+void RS_EventHandler::killAllActions()
+{
 	RS_DEBUG->print(__FILE__ ": %s: line %d: begin\n", __func__, __LINE__);
-	for(auto p: currentActions){
-		if ( ! p->isFinished() ){
+
+    if (q_action)
+    {
+        q_action->setChecked(false);
+        q_action = nullptr;
+    }
+
+	for(auto p: currentActions)
+    {
+		if (!p->isFinished())
+        {
 			p->finish();
 		}
 	}
@@ -559,14 +550,12 @@ bool RS_EventHandler::isValid(RS_ActionInterface* action) const{
 /**
  * @return true if there is at least one action in the action stack.
  */
-bool RS_EventHandler::hasAction(){
-
-    while(currentActions.size()>0 ) {
-        if(! currentActions.last()->isFinished()){
+bool RS_EventHandler::hasAction()
+{
+    foreach (RS_ActionInterface* a, currentActions)
+    {
+        if(!a->isFinished())
             return true;
-        }
-        delete currentActions.last();
-        currentActions.pop_back();
     }
     return false;
 }
@@ -579,10 +568,10 @@ bool RS_EventHandler::hasAction(){
 void RS_EventHandler::cleanUp() {
     RS_DEBUG->print("RS_EventHandler::cleanUp");
 
-    for (auto it=currentActions.begin();it != currentActions.end();){
-
-        if( (*it)->isFinished()){
-//            (*it)->finish();
+    for (auto it=currentActions.begin(); it != currentActions.end();)
+    {
+        if( (*it)->isFinished())
+        {
             delete *it;
             it= currentActions.erase(it);
         }else{
@@ -650,4 +639,37 @@ void RS_EventHandler::debugActions() const{
     }
 }
 
+void RS_EventHandler::setQAction(QAction* action)
+{
+    if (q_action)
+    {
+        q_action->setChecked(false);
+        killAllActions();
+    }
+    q_action = action;
+}
+
+void RS_EventHandler::setRelativeZero(const RS_Vector& point)
+{
+    relative_zero = point;
+}
+
+bool RS_EventHandler::inSelectionMode()
+{
+    switch (getCurrentAction()->rtti())
+    {
+        case RS2::ActionDefault:
+        case RS2::ActionSelectSingle:
+        case RS2::ActionSelectWindow:
+        case RS2::ActionDeselectWindow:
+        case RS2::ActionSelectContour:
+        case RS2::ActionSelectIntersected:
+        case RS2::ActionDeselectIntersected:
+        case RS2::ActionSelectLayer:
+            return true;
+        default:
+            return false;
+    }
+}
+
 // EOF
