@@ -27,10 +27,13 @@
 
 #include<climits>
 #include<cmath>
+
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QAction>
-#include "qc_applicationwindow.h"
+#include <QMouseEvent>
+#include <QtAlgorithms>
+
 #include "rs_graphicview.h"
 
 #include "rs_line.h"
@@ -54,45 +57,35 @@
 /**
  * Constructor.
  */
-RS_GraphicView::RS_GraphicView()
-	:container(nullptr)
-	,eventHandler(new RS_EventHandler(this))
-	,background()
-	,foreground()
+RS_GraphicView::RS_GraphicView(QWidget* parent, Qt::WindowFlags f)
+    :QWidget(parent, f)
+	,eventHandler{new RS_EventHandler{this}}
 	,gridColor(Qt::gray)
-	,metaGridColor(RS_Color(64,64,64))
-	,grid(new RS_Grid(this))
+	,metaGridColor{64, 64, 64}
+	,grid{new RS_Grid{this}}
 	,drawingMode(RS2::ModeFull)
 	,savedViews(16)
 	,previousViewTime(QDateTime::currentDateTime())
 {
-	init();
-}
-
-RS_GraphicView::~RS_GraphicView() = default;
-
-/**
- * Destructor.
- */
-
-void RS_GraphicView::init()
-{
-    RS_SETTINGS->beginGroup("/Appearance");
-    setBackground(       QColor( RS_SETTINGS->readGraphicColor( RS_Settings::BackgroundColor)));
-    setGridColor(        QColor( RS_SETTINGS->readGraphicColor( RS_Settings::GridColor)));
-    setMetaGridColor(    QColor( RS_SETTINGS->readGraphicColor( RS_Settings::MetaGridColor)));
-    setSelectedColor(    QColor( RS_SETTINGS->readGraphicColor( RS_Settings::SelectedColor)));
-    setHighlightedColor( QColor( RS_SETTINGS->readGraphicColor( RS_Settings::HighlightedColor)));
-    setStartHandleColor( QColor( RS_SETTINGS->readGraphicColor( RS_Settings::StartHandleColor)));
-    setHandleColor(      QColor( RS_SETTINGS->readGraphicColor( RS_Settings::HandleColor)));
-    setEndHandleColor(   QColor( RS_SETTINGS->readGraphicColor( RS_Settings::EndHandleColor)));
-
+    RS_SETTINGS->beginGroup("Colors");
+    setBackground(QColor(RS_SETTINGS->readEntry("/background", Colors::background)));
+    setGridColor(QColor(RS_SETTINGS->readEntry("/grid", Colors::grid)));
+    setMetaGridColor(QColor(RS_SETTINGS->readEntry("/meta_grid", Colors::meta_grid)));
+    setSelectedColor(QColor(RS_SETTINGS->readEntry("/select", Colors::select)));
+    setHighlightedColor(QColor(RS_SETTINGS->readEntry("/highlight", Colors::highlight)));
+    setStartHandleColor(QColor(RS_SETTINGS->readEntry("/start_handle", Colors::start_handle)));
+    setHandleColor(QColor(RS_SETTINGS->readEntry("/handle", Colors::handle)));
+    setEndHandleColor(QColor(RS_SETTINGS->readEntry("/end_handle", Colors::end_handle)));
     RS_SETTINGS->endGroup();
-    QC_ApplicationWindow::getAppWindow()->setPreviousZoomEnable(false);
+}
+
+RS_GraphicView::~RS_GraphicView()
+{
+    qDeleteAll(overlayEntities);
 }
 
 /**
- * Must be called by any derrived class in the destructor.
+ * Must be called by any derived class in the destructor.
  */
 void RS_GraphicView::cleanUp() {
 	m_bIsCleanUp=true;
@@ -256,7 +249,7 @@ RS_ActionInterface* RS_GraphicView::getCurrentAction() {
  * Sets the current action of the event handler.
  */
 void RS_GraphicView::setCurrentAction(RS_ActionInterface* action) {
-	RS_DEBUG->print("RS_GraphicView::setCurrentAction");
+    RS_DEBUG->print("RS_GraphicView::setCurrentAction");
 	if (eventHandler) {
 		eventHandler->setCurrentAction(action);
 	}
@@ -290,18 +283,14 @@ void RS_GraphicView::killAllActions() {
 /**
  * Go back in menu or current action.
  */
-void RS_GraphicView::back() {
-	if (eventHandler && eventHandler->hasAction()) {
+void RS_GraphicView::back()
+{
+	if (eventHandler && eventHandler->hasAction())
+    {
 		eventHandler->back();
-	} else {
-		if (RS_DIALOGFACTORY) {
-			RS_DIALOGFACTORY->requestPreviousMenu();
-		}
-	}
+    }
 }
 
-
-
 /**
  * Go forward with the current action.
  */
@@ -311,147 +300,6 @@ void RS_GraphicView::enter() {
 	}
 }
 
-
-
-/**
- * Called by the actual GUI class which implements the RS_GraphicView
- * interface to notify LibreCAD about mouse events.
- */
-void RS_GraphicView::mousePressEvent(QMouseEvent* e) {
-	if (eventHandler) {
-		eventHandler->mousePressEvent(e);
-	}
-}
-
-
-
-/**
- * Called by the actual GUI class which implements the RS_GraphicView
- * interface to notify LibreCAD about mouse events.
- */
-void RS_GraphicView::mouseReleaseEvent(QMouseEvent* e) {
-	RS_DEBUG->print("RS_GraphicView::mouseReleaseEvent");
-	if (eventHandler) {
-		if (e->button()!=Qt::RightButton ||
-				eventHandler->hasAction()) {
-
-			eventHandler->mouseReleaseEvent(e);
-			//e->accept();
-		}
-		else {
-			back();
-
-			e->accept();
-		}
-	}
-	RS_DEBUG->print("RS_GraphicView::mouseReleaseEvent: OK");
-}
-
-
-/*	*
- *	Function name:
- *
- *	Description:		- Called by the actual GUI class which implements the
- *							  RS_GraphicView interface to notify LibreCAD about
- *							  mouse events.
- *
- *	Author(s):			..., Claude Sylvain
- *	Created:				?
- *	Last modified:		23 July 2011
- *
- *	Parameters:			QMouseEvent* e:
- *								...
- *
- *	Returns:				void
- *	*/
-
-void RS_GraphicView::mouseMoveEvent(QMouseEvent* e) {
-	RS_DEBUG->print("RS_GraphicView::mouseMoveEvent begin");
-
-    RS_Graphic* graphic = nullptr;
-
-	if (container->rtti()==RS2::EntityGraphic) {
-		graphic = (RS_Graphic*)container;
-	}
-
-	RS_DEBUG->print("RS_GraphicView::mouseMoveEvent 001");
-
-	if (e) {
-		mx = e->x();
-		my = e->y();
-	}
-
-	RS_DEBUG->print("RS_GraphicView::mouseMoveEvent 002");
-
-	if (eventHandler) {
-		eventHandler->mouseMoveEvent(e);
-	}
-
-	RS_DEBUG->print("RS_GraphicView::mouseMoveEvent 003");
-
-	if (	((!eventHandler) || !eventHandler->hasAction()) &&
-			(graphic))
-	{
-		RS_Vector	mouse		= toGraph(RS_Vector(mx, my));
-		RS_Vector	relMouse	= mouse - getRelativeZero();
-
-		if (RS_DIALOGFACTORY)
-			RS_DIALOGFACTORY->updateCoordinateWidget(mouse, relMouse);
-	}
-
-	RS_DEBUG->print("RS_GraphicView::mouseMoveEvent end");
-}
-
-
-
-/**
- * Called by the actual GUI class which implements the RS_GraphicView
- * interface to notify LibreCAD about mouse events.
- */
-void RS_GraphicView::mouseLeaveEvent() {
-	if (eventHandler) {
-		eventHandler->mouseLeaveEvent();
-	}
-}
-
-
-
-/**
- * Called by the actual GUI class which implements the RS_GraphicView
- * interface to notify LibreCAD about mouse events.
- */
-void RS_GraphicView::mouseEnterEvent() {
-	if (eventHandler) {
-		eventHandler->mouseEnterEvent();
-	}
-}
-
-
-
-/**
- * Called by the actual GUI class which implements the RS_GraphicView
- * interface to notify LibreCAD about key events.
- */
-void RS_GraphicView::keyPressEvent(QKeyEvent* e) {
-	if (eventHandler) {
-		eventHandler->keyPressEvent(e);
-	}
-}
-
-
-
-/**
- * Called by the actual GUI class which implements the RS_GraphicView
- * interface to notify LibreCAD about key events.
- */
-void RS_GraphicView::keyReleaseEvent(QKeyEvent* e) {
-	if (eventHandler) {
-		eventHandler->keyReleaseEvent(e);
-	}
-}
-
-
-
 /**
  * Called by the actual GUI class which implements a command line.
  */
@@ -461,8 +309,6 @@ void RS_GraphicView::commandEvent(RS_CommandEvent* e) {
 	}
 }
 
-
-
 /**
  * Enables coordinate input in the command line.
  */
@@ -503,9 +349,9 @@ void RS_GraphicView::zoomIn(double f, const RS_Vector& center) {
     }
 
 	zoomWindow(
-				toGraph(RS_Vector(0,0))
+				toGraph(0, 0)
 				.scale(c, RS_Vector(1.0/f,1.0/f)),
-				toGraph(RS_Vector(getWidth(),getHeight()))
+				toGraph(getWidth(), getHeight())
 				.scale(c, RS_Vector(1.0/f,1.0/f)));
 
 	//adjustOffsetControls();
@@ -601,25 +447,26 @@ void RS_GraphicView::zoomOutY(double f) {
  * @param keepAspectRatio true: keep aspect ratio 1:1
  *                        false: factors in x and y are stretched to the max
  */
+#include <iostream>
 void RS_GraphicView::zoomAuto(bool axis, bool keepAspectRatio) {
 
 	RS_DEBUG->print("RS_GraphicView::zoomAuto");
 
 
 	if (container) {
-		container->calculateBorders();
+        container->calculateBorders();
 
 		double sx, sy;
 		if (axis) {
-			sx = std::max(container->getMax().x, 0.0)
-					- std::min(container->getMin().x, 0.0);
-			sy = std::max(container->getMax().y, 0.0)
-					- std::min(container->getMin().y, 0.0);
+			auto const dV = container->getMax() - container->getMin();
+			sx = std::max(dV.x, 0.);
+			sy = std::max(dV.y, 0.);
 		} else {
 			sx = container->getSize().x;
 			sy = container->getSize().y;
 		}
-		//    std::cout<<" RS_GraphicView::zoomAuto("<<axis<<","<<keepAspectRatio<<")"<<std::endl;
+//		    std::cout<<" RS_GraphicView::zoomAuto("<<sx<<","<<sy<<")"<<std::endl;
+//			std::cout<<" RS_GraphicView::zoomAuto("<<axis<<","<<keepAspectRatio<<")"<<std::endl;
 
 		double fx=1., fy=1.;
 		unsigned short fFlags=0;
@@ -723,7 +570,7 @@ void RS_GraphicView::saveView() {
 	if(savedViewCount<savedViews.size()) savedViewCount++;
 
 	if(savedViewCount==1){
-		QC_ApplicationWindow::getAppWindow()->setPreviousZoomEnable(true);
+		emit previous_zoom_state(true);
 	}
 }
 
@@ -737,7 +584,7 @@ void RS_GraphicView::restoreView() {
 	if(savedViewCount == 0) return;
 	savedViewCount --;
 	if(savedViewCount==0){
-		QC_ApplicationWindow::getAppWindow()->setPreviousZoomEnable(false);
+		emit previous_zoom_state(false);
 	}
 	savedViewIndex = (savedViewIndex + savedViews.size() - 1)%savedViews.size();
 
@@ -1261,17 +1108,20 @@ void RS_GraphicView::drawEntity(RS_Painter *painter, RS_Entity* e, double& patte
 		// do not draw construction layer on print preview or print
 		if( ! e->isPrint()
 				||  e->isConstruction())
-			return;
+        return;
 	}
 
-	// test if the entity is in the viewport
-	/* temporary disabled so rs_overlaylien can be drawn
-	if (!e->isContainer() && !isPrinting() &&
-            (painter==nullptr || !painter->isPreviewMode()) &&
-			(toGuiX(e->getMax().x)<0 || toGuiX(e->getMin().x)>getWidth() ||
-			 toGuiY(e->getMin().y)<0 || toGuiY(e->getMax().y)>getHeight())) {
-		return;
-	} */
+    // test if the entity is in the viewport
+    if (!isPrinting()
+        && e->rtti() != RS2::EntityOverlayLine
+        && e->rtti() != RS2::EntityOverlayBox
+        && e->rtti() != RS2::EntityGraphic
+        && e->rtti() != RS2::EntityPreview
+        && e->rtti() != RS2::EntityLine &&
+       (toGuiX(e->getMax().x)<0 || toGuiX(e->getMin().x)>getWidth() ||
+        toGuiY(e->getMin().y)<0 || toGuiY(e->getMax().y)>getHeight())) {
+        return;
+    }
 
 	// set pen (color):
 	setPenForEntity(painter, e );
@@ -1358,7 +1208,6 @@ void RS_GraphicView::drawEntityPlain(RS_Painter *painter, RS_Entity* e) {
 	}
 	double patternOffset(0.);
 	e->draw(painter, this, patternOffset);
-
 }
 /**
  * Deletes an entity with the background color.
@@ -1853,6 +1702,7 @@ double RS_GraphicView::toGraphDY(int d) const{
 void RS_GraphicView::setRelativeZero(const RS_Vector& pos) {
 	if (relativeZeroLocked==false) {
 		relativeZero = pos;
+        emit relative_zero_changed(pos);
 	}
 }
 
@@ -1869,7 +1719,7 @@ void RS_GraphicView::moveRelativeZero(const RS_Vector& pos) {
 
 
 /**
- * Remove all overlay entities
+ * Gets the specified overlay container.
  */
 RS_EntityContainer* RS_GraphicView::getOverlayContainer(RS2::OverlayGraphics position)
 {
@@ -1887,7 +1737,7 @@ RS_Grid* RS_GraphicView::getGrid() const{
 }
 
 RS_EventHandler* RS_GraphicView::getEventHandler() const{
-	return eventHandler.get();
+    return eventHandler;
 }
 
 void RS_GraphicView::setBackground(const RS_Color& bg) {
@@ -1999,4 +1849,3 @@ bool RS_GraphicView::isCleanUp(void) const
 {
 	return m_bIsCleanUp;
 }
-
