@@ -46,10 +46,11 @@ using LC_Rect = lc::geo::Area;
  *
  * @author Andrew Mustun
  */
-class RS_Grid {
+class RS_Grid
+{
+
 public:
 	RS_Grid(RS_GraphicView* graphicView);
-	~RS_Grid()=default;
 
 	void updatePointArray();
 
