@@ -23,12 +23,10 @@
 ** This copyright notice MUST APPEAR in all copies of the script!
 **
 **********************************************************************/
-#ifdef HAS_BOOST
 #include <boost/numeric/ublas/matrix.hpp>
 #include <boost/numeric/ublas/io.hpp>
 #include <boost/numeric/ublas/lu.hpp>
 #include <boost/math/special_functions/ellint_2.hpp>
-#endif
 
 #include <cmath>
 #include <muParser.h>
@@ -43,7 +41,10 @@
 #include "emu_c99.h"
 #endif
 
-const double m_piX2 = M_PI*2; //2*PI
+
+namespace {
+constexpr double m_piX2 = M_PI*2; //2*PI
+}
 
 /**
  * Rounds the given double to the closest int.
@@ -330,7 +331,49 @@ QString RS_Math::doubleToString(double value, int prec) {
  * Performs some testing for the math class.
  */
 void RS_Math::test() {
-    QString s;
+	{
+		std::cout<<"testing quadratic solver"<<std::endl;
+		//equations x^2 + v[0] x + v[1] = 0
+		std::vector<std::vector<double>> const eqns{
+			{-1., -1.},
+			{-101., -1.},
+			{-1., -100.},
+			{2., 1.},
+			{-2., 1.}
+		};
+		//expected roots
+		std::vector<std::vector<double>> roots{
+			{-0.6180339887498948, 1.6180339887498948},
+			{-0.0099000196991084878, 101.009900019699108},
+			{-9.5124921972503929, 10.5124921972503929},
+			{-1.},
+			{1.}
+		};
+
+		for(size_t i=0; i < eqns.size(); i++) {
+			std::cout<<"Test quadratic solver, test case: x^2 + ("
+					<<eqns[i].front()<<") x + ("
+				   <<eqns[i].back()<<") = 0"<<std::endl;
+			auto sol = quadraticSolver(eqns[i]);
+			assert(sol.size()==roots[i].size());
+			if (sol.front() > sol.back())
+				std::swap(sol[0], sol[1]);
+			auto expected=roots[i];
+			if (expected.front() > expected.back())
+				std::swap(expected[0], expected[1]);
+			for (size_t j=0; j < sol.size(); j++) {
+				double x0 = sol[j];
+				double x1 = expected[j];
+				double const prec = (x0 - x1)/(fabs(x0 + x1) + RS_TOLERANCE2);
+				std::cout<<"root "<<j<<" : precision level = "<<prec<<std::endl;
+				std::cout<<std::setprecision(17)<<"found: "<<x0<<"\texpected: "<<x1<<std::endl;
+				assert(prec < RS_TOLERANCE);
+			}
+			std::cout<<std::endl;
+		}
+		return;
+	}
+	QString s;
     double v;
 
     std::cout << "RS_Math::test: doubleToString:\n";
@@ -371,32 +414,59 @@ void RS_Math::test() {
 // solvers assume arguments are valid, and there's no attempt to verify validity of the argument pointers
 //
 // @author Dongxu Li <dongxuli2011@gmail.com>
-
 std::vector<double> RS_Math::quadraticSolver(const std::vector<double>& ce)
 //quadratic solver for
 // x^2 + ce[0] x + ce[1] =0
 {
     std::vector<double> ans(0,0.);
 	if (ce.size() != 2) return ans;
-    double const a=-0.5*ce[0];
-    double b=a*a;
-    double const discriminant=b-ce[1];
-    if (discriminant >= - RS_TOLERANCE15*std::max(fabs(b), fabs(ce[1])) ){
-		b = sqrt(fabs(discriminant));
-		if (b >= RS_TOLERANCE*fabs(a)) {
-            if(a>0.){
-                ans.push_back(a + b);
-                ans.push_back(ce[1]/ans[0]);
-            }else{
-                ans.push_back(a - b);
-                ans.push_back(ce[1]/ans[0]);
-            }
-        }else
-            ans.push_back(a);
-    }
-    return ans;
+	using LDouble = long double;
+	LDouble const b = -0.5L * ce[0];
+	LDouble const c = ce[1];
+	// x^2 -2 b x + c=0
+	// (x - b)^2 = b^2 - c
+	// b^2 >= fabs(c)
+	// x = b \pm b sqrt(1. - c/(b^2))
+	LDouble const b2= b * b;
+	LDouble const discriminant= b2 - c;
+	LDouble const fc = std::abs(c);
+
+	//TODO, fine tune to tolerance level
+	LDouble const TOL = 1e-24L;
+
+	if (discriminant < 0.L)
+		//negative discriminant, no real root
+		return ans;
+
+	//find the radical
+	LDouble r;
+
+	// given |p| >= |q|
+	// sqrt(p^2 \pm q^2) = p sqrt(1 \pm q^2/p^2)
+	if (b2 >= fc)
+		r = std::abs(b) * std::sqrt(1.L - c/b2);
+	else
+		// c is negative, because b2 - c is non-negative
+		r = std::sqrt(fc) * std::sqrt(1.L + b2/fc);
+
+	if (r >= TOL*std::abs(b)) {
+		//two roots
+		if (b >= 0.L)
+			//since both (b,r)>=0, avoid (b - r) loss of significance
+			ans.push_back(b + r);
+		else
+			//since b<0, r>=0, avoid (b + r) loss of significance
+			ans.push_back(b - r);
+
+		//Vieta's formulas for the second root
+		ans.push_back(c/ans.front());
+	} else
+		//multiple roots
+		ans.push_back(b);
+	return ans;
 }
 
+
 std::vector<double> RS_Math::cubicSolver(const std::vector<double>& ce)
 //cubic equation solver
 // x^3 + ce[0] x^2 + ce[1] x + ce[2] = 0
@@ -705,7 +775,6 @@ bool RS_Math::linearSolver(const std::vector<std::vector<double> >& mt, std::vec
 }))
 		return false;
     sn.resize(mSize);//to hold the solution
-    //#ifdef	HAS_BOOST
 #if false
     boost::numeric::ublas::matrix<double> bm (mSize, mSize);
     boost::numeric::ublas::vector<double> bs(mSize);
