@@ -52,15 +52,15 @@ public:
 public:
     QC_ActionGetSelect(RS_EntityContainer& container,
                         RS_GraphicView& graphicView);
-	~QC_ActionGetSelect() = default;
+	~QC_ActionGetSelect();
 
     virtual void init(int status=0);
 	
     virtual void mouseReleaseEvent(QMouseEvent* e);
+    virtual void keyPressEvent(QKeyEvent* e);
 	
     virtual void updateMouseButtonHints();
     virtual void updateMouseCursor();
-	virtual void updateToolBar();
 
     void setMesage(QString msg);
 	bool isCompleted() const{return completed;}
