@@ -412,11 +412,7 @@ void QG_DlgOptionsDrawing::validate() {
         // grid:
         //graphic->addVariable("$GRIDMODE", (int)cbGridOn->isChecked() , 70);
         graphic->setGridOn(cbGridOn->isChecked());
-#ifdef  RS_VECTOR2D
-		*spacing=RS_Vector{0.0,0.0};
-#else
 		*spacing=RS_Vector{0.0,0.0,0.0};
-#endif
         if (cbXSpacing->currentText()==tr("auto")) {
 			spacing->x = 0.0;
         } else {
@@ -500,7 +496,8 @@ void QG_DlgOptionsDrawing::validate() {
         graphic->addVariable("$DIMCLRE", colNum, 70);
         colNum = RS_FilterDXFRW::colorToNumber(cbDimClrT->getColor(), &colRGB);
         graphic->addVariable("$DIMCLRT", colNum, 70);
-        graphic->addVariable("$DIMTXSTY", cbDimTxSty->getFont()->getFileName() , 2);
+		if (cbDimTxSty->getFont())
+			graphic->addVariable("$DIMTXSTY", cbDimTxSty->getFont()->getFileName() , 2);
         graphic->addVariable("$DIMDSEP", (cbDimDSep->currentIndex()==1)? 44 : 0, 70);
 
         // splines:
