@@ -30,6 +30,7 @@
 #include "rs_settings.h"
 #include "rs_math.h"
 #include "rs_debug.h"
+#include "ui_qg_lineangleoptions.h"
 
 /*
  *  Constructs a QG_LineAngleOptions as a child of 'parent', with the
@@ -37,9 +38,9 @@
  */
 QG_LineAngleOptions::QG_LineAngleOptions(QWidget* parent, Qt::WindowFlags fl)
     : QWidget(parent, fl)
+	, ui(new Ui::Ui_LineAngleOptions{})
 {
-    setupUi(this);
-
+	ui->setupUi(this);
 }
 
 /*
@@ -47,8 +48,7 @@ QG_LineAngleOptions::QG_LineAngleOptions(QWidget* parent, Qt::WindowFlags fl)
  */
 QG_LineAngleOptions::~QG_LineAngleOptions()
 {
-    destroy();
-    // no need to delete child widgets, Qt does it all for us
+	saveSettings();
 }
 
 /*
@@ -57,7 +57,7 @@ QG_LineAngleOptions::~QG_LineAngleOptions()
  */
 void QG_LineAngleOptions::languageChange()
 {
-    retranslateUi(this);
+	ui->retranslateUi(this);
 }
 
 void QG_LineAngleOptions::setAction(RS_ActionInterface* a, bool update) {
@@ -67,12 +67,12 @@ void QG_LineAngleOptions::setAction(RS_ActionInterface* a, bool update) {
                 ||a->rtti()==RS2::ActionDrawLineVertical
                 )
     ){
-        action = (RS_ActionDrawLineAngle*)a;
+		action = static_cast<RS_ActionDrawLineAngle*>(a);
         m_bFixedAngle=action->hasFixedAngle();
-        leLength->show();
-        lLength->show();
-        leAngle->setVisible(!action->hasFixedAngle());
-        lAngle->setVisible(!action->hasFixedAngle());
+		ui->leLength->show();
+		ui->lLength->show();
+		ui->leAngle->setVisible(!action->hasFixedAngle());
+		ui->lAngle->setVisible(!action->hasFixedAngle());
 
         QString sa;
         QString sl;
@@ -98,20 +98,20 @@ void QG_LineAngleOptions::setAction(RS_ActionInterface* a, bool update) {
 			action->setSnapPoint(sp);
         }
 
-        leAngle->setText(sa);
-        leLength->setText(sl);
-                cbSnapPoint->setCurrentIndex(sp);
+		ui->leAngle->setText(sa);
+		ui->leLength->setText(sl);
+				ui->cbSnapPoint->setCurrentIndex(sp);
     } else {
         RS_DEBUG->print(RS_Debug::D_ERROR, 
 			"QG_LineAngleOptions::setAction: wrong action type");
-        this->action = NULL;
+		this->action = nullptr;
     }
 }
 
 /** fixme, action could be deleted already, moved the saving into the action
   class
   need to implement in shared_ptr*/
-void QG_LineAngleOptions::destroy() {
+void QG_LineAngleOptions::saveSettings() {
 //    if (action) {
 //        RS_SETTINGS->beginGroup("/Draw");
 //        if (!action->hasFixedAngle()) {
