@@ -28,6 +28,7 @@
 
 #include <QGridLayout>
 #include <QLabel>
+#include <QMenu>
 #include <QDebug>
 #if QT_VERSION >= 0x050200
 #include <QNativeGestureEvent>
@@ -42,8 +43,10 @@
 #include "rs_settings.h"
 #include "rs_painterqt.h"
 #include "rs_dialogfactory.h"
-#include "qg_cadtoolbar.h"
 #include "qg_dialogfactory.h"
+#include "rs_eventhandler.h"
+#include "rs_actiondefault.h"
+#include "lc_options.h"
 
 
 #include "qg_scrollbar.h"
@@ -61,63 +64,36 @@
 /**
  * Constructor.
  */
-QG_GraphicView::QG_GraphicView(QWidget* parent, const char* name, Qt::WindowFlags f)
-        :QWidget(parent, f)
-        ,RS_GraphicView()
-        ,hScrollBar(new QG_ScrollBar(Qt::Horizontal, this))
-        ,vScrollBar(new QG_ScrollBar(Qt::Vertical, this))
-        ,layout(new QGridLayout(this))
-        ,gridStatus(new QLabel("-", this))
-        ,curCad(new QCursor(QPixmap(":ui/cur_cad_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
-        ,curDel(new QCursor(QPixmap(":ui/cur_del_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
-        ,curSelect(new QCursor(QPixmap(":ui/cur_select_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
-        ,curMagnifier(new QCursor(QPixmap(":ui/cur_glass_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
-        ,curHand(new QCursor(QPixmap(":ui/cur_hand_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
-        ,redrawMethod(RS2::RedrawAll)
-        ,isSmoothScrolling(false)
+QG_GraphicView::QG_GraphicView(QWidget* parent, Qt::WindowFlags f, RS_Document* doc)
+    :RS_GraphicView(parent, f)
+    ,curCad(new QCursor(QPixmap(":ui/cur_cad_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+    ,curDel(new QCursor(QPixmap(":ui/cur_del_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+    ,curSelect(new QCursor(QPixmap(":ui/cur_select_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+    ,curMagnifier(new QCursor(QPixmap(":ui/cur_glass_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+    ,curHand(new QCursor(QPixmap(":ui/cur_hand_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+    ,redrawMethod(RS2::RedrawAll)
+    ,isSmoothScrolling(false)
 {
-    setObjectName(name);
-    setBackground(background);
+    RS_DEBUG->print("QG_GraphicView::QG_GraphicView()..");
 
-    layout->setMargin(0);
-    layout->setSpacing(0);
-    layout->setColumnStretch(0, 1);
-    layout->setColumnStretch(1, 0);
-    layout->setColumnStretch(2, 0);
-    layout->setRowStretch(0, 1);
-    layout->setRowStretch(1, 0);
+    if (doc)
+    {
+        setContainer(doc);
+        doc->setGraphicView(this);
+        setDefaultAction(new RS_ActionDefault(*doc, *this));
+    }
 
-    hScrollBar->setSingleStep(50);
-    hScrollBar->setCursor(Qt::ArrowCursor);
-    layout->addWidget(hScrollBar, 1, 0);
-    layout->addItem(new QSpacerItem(0, hScrollBar->sizeHint().height()), 1, 0);
-    connect(hScrollBar, SIGNAL(valueChanged(int)),
-            this, SLOT(slotHScrolled(int)));
-
-    vScrollBar->setSingleStep(50);
-    vScrollBar->setCursor(Qt::ArrowCursor);
-    layout->addWidget(vScrollBar, 0, 2);
-    layout->addItem(new QSpacerItem(vScrollBar->sizeHint().width(), 0), 0, 2);
-    connect(vScrollBar, SIGNAL(valueChanged(int)),
-            this, SLOT(slotVScrolled(int)));
-
-    // Dummy widgets for scrollbar corners:
-    //layout->addWidget(new QWidget(this), 1, 1);
-    //QWidget* w = new QWidget(this);
-    //w->setEraseColor(QColor(255,0,0));
-
-    gridStatus->setAlignment(Qt::AlignRight);
-    layout->addWidget(gridStatus, 1, 1, 1, 2);
-    layout->addItem(new QSpacerItem(50, 0), 0, 1);
+    setFactorX(4.0);
+    setFactorY(4.0);
+    setBorders(10, 10, 10, 10);
 
     setMouseTracking(true);
-        // flickering under win:
-    //setFocusPolicy(WheelFocus);
-
     setFocusPolicy(Qt::NoFocus);
 
-    // See https://sourceforge.net/tracker/?func=detail&aid=3289298&group_id=342582&atid=1433844 (Left-mouse drag shrinks window)
+    // SourceForge issue 45 (Left-mouse drag shrinks window)
     setAttribute(Qt::WA_NoMousePropagation);
+
+    view_rect = LC_Rect(toGraph(0, 0), toGraph(getWidth(), getHeight()));
 }
 
 
@@ -134,8 +110,12 @@ QG_GraphicView::~QG_GraphicView() {
 /**
  * @return width of widget.
  */
-int QG_GraphicView::getWidth() const{
-    return width() - vScrollBar->sizeHint().width();
+int QG_GraphicView::getWidth() const
+{
+    if (scrollbars)
+        return width() - vScrollBar->sizeHint().width();
+    else
+        return width();
 }
 
 
@@ -143,8 +123,12 @@ int QG_GraphicView::getWidth() const{
 /**
  * @return height of widget.
  */
-int QG_GraphicView::getHeight() const{
-    return height() - hScrollBar->sizeHint().height();
+int QG_GraphicView::getHeight() const
+{
+    if (scrollbars)
+        return height() - hScrollBar->sizeHint().height();
+    else
+        return height();
 }
 
 
@@ -160,7 +144,6 @@ void QG_GraphicView::setBackground(const RS_Color& bg) {
 }
 
 
-
 /**
  * Sets the mouse cursor to the given type.
  */
@@ -223,7 +206,9 @@ void QG_GraphicView::setMouseCursor(RS2::CursorType c) {
         setCursor(Qt::ClosedHandCursor);
         break;
     case RS2::CadCursor:
-        setCursor(*curCad);
+        cursor_hiding
+            ? setCursor(Qt::BlankCursor)
+            : setCursor(*curCad);
         break;
     case RS2::DelCursor:
         setCursor(*curDel);
@@ -239,20 +224,18 @@ void QG_GraphicView::setMouseCursor(RS2::CursorType c) {
         break;
 
     }
-
 }
 
 
-
 /**
  * Sets the text for the grid status widget in the left bottom corner.
  */
-void QG_GraphicView::updateGridStatusWidget(const QString& text) {
-    gridStatus->setText(text);
+void QG_GraphicView::updateGridStatusWidget(const QString& text)
+{
+   emit gridStatusChanged(text);
 }
 
 
-
 /**
  * Redraws the widget.
  */
@@ -263,7 +246,6 @@ void QG_GraphicView::redraw(RS2::RedrawMethod method) {
 }
 
 
-
 void QG_GraphicView::resizeEvent(QResizeEvent* /*e*/) {
     RS_DEBUG->print("QG_GraphicView::resizeEvent begin");
     adjustOffsetControls();
@@ -275,77 +257,101 @@ void QG_GraphicView::resizeEvent(QResizeEvent* /*e*/) {
     RS_DEBUG->print("QG_GraphicView::resizeEvent end");
 }
 
-
-
-void QG_GraphicView::emulateMouseMoveEvent() {
-    QMouseEvent e(QEvent::MouseMove, QPoint(mx, my),
-                    Qt::NoButton, Qt::NoButton, Qt::NoModifier);//RLZ
-    //mouseMoveEvent(&e);
-}
-
-
-
-void QG_GraphicView::mousePressEvent(QMouseEvent* e) {
+void QG_GraphicView::mousePressEvent(QMouseEvent* event)
+{
     // pan zoom with middle mouse button
-#if QT_VERSION < 0x040700
-    if (e->button()==Qt::MidButton /*|| (e->state()==Qt::LeftButton|Qt::AltButton)*/) {
-#else
-    if (e->button()==Qt::MiddleButton /*|| (e->state()==Qt::LeftButton|Qt::AltButton)*/) {
-#endif
+    if (event->button()==Qt::MiddleButton)
+    {
         setCurrentAction(new RS_ActionZoomPan(*container, *this));
     }
-
-    RS_GraphicView::mousePressEvent(e);
-    QWidget::mousePressEvent(e);
+    eventHandler->mousePressEvent(event);
 }
 
-void QG_GraphicView::mouseDoubleClickEvent(QMouseEvent* e) {
-    // zoom auto with double click middle mouse button
-#if QT_VERSION < 0x040700
-    if (e->button()==Qt::MidButton) {
-#else
-    if (e->button()==Qt::MiddleButton) {
-#endif
-        setCurrentAction(new RS_ActionZoomAuto(*container, *this));
-        e->accept();
+void QG_GraphicView::mouseDoubleClickEvent(QMouseEvent* e)
+{
+    switch(e->button())
+    {
+        default:
+            break;
+        case Qt::MiddleButton:
+            setCurrentAction(new RS_ActionZoomAuto(*container, *this));
+            break;
+        case Qt::LeftButton:
+            if (menus.contains("Double-Click"))
+            {
+                killAllActions();
+                menus["Double-Click"]->popup(mapToGlobal(e->pos()));
+            }
+            break;
     }
+    e->accept();
 }
 
 
-void QG_GraphicView::mouseReleaseEvent(QMouseEvent* e) {
-        RS_DEBUG->print("QG_GraphicView::mouseReleaseEvent");
-    RS_GraphicView::mouseReleaseEvent(e);
-    //QWidget::mouseReleaseEvent(e);
+void QG_GraphicView::mouseReleaseEvent(QMouseEvent* event)
+{
+    RS_DEBUG->print("QG_GraphicView::mouseReleaseEvent");
 
-    if (!e->isAccepted()) {
-        if (QG_DIALOGFACTORY && QG_DIALOGFACTORY->getCadToolBar()) {
-                        RS_DEBUG->print("QG_GraphicView::mouseReleaseEvent: "
-                                "fwd to cadtoolbar");
-            QG_DIALOGFACTORY->getCadToolBar()->mouseReleaseEvent(e);
+    event->accept();
+
+    switch (event->button())
+    {
+    case Qt::RightButton:
+        if (event->modifiers()==Qt::ControlModifier)
+        {
+            if (menus.contains("Ctrl+Right-Click"))
+            {
+                menus["Ctrl+Right-Click"]->popup(mapToGlobal(event->pos()));
+                break;
+            }
         }
+        if (event->modifiers()==Qt::ShiftModifier)
+        {
+            if (menus.contains("Shift+Right-Click"))
+            {
+                menus["Shift+Right-Click"]->popup(mapToGlobal(event->pos()));
+                break;
+            }
+        }
+
+        if (!eventHandler->hasAction())
+        {
+            if (menus.contains("Right-Click"))
+            {
+                menus["Right-Click"]->popup(mapToGlobal(event->pos()));
+            }
+            else if (!recent_actions.isEmpty())
+            {
+                QMenu* context_menu = new QMenu(this);
+                context_menu->setAttribute(Qt::WA_DeleteOnClose);
+                context_menu->addActions(recent_actions);
+                context_menu->exec(mapToGlobal(event->pos()));
+            }
+        }
+        else back();
+        break;
+
+    case Qt::XButton1:
+        enter();
+        emit xbutton1_released();
+        break;
+
+    default:
+        eventHandler->mouseReleaseEvent(event);
+        break;
     }
-        RS_DEBUG->print("QG_GraphicView::mouseReleaseEvent: OK");
+    RS_DEBUG->print("QG_GraphicView::mouseReleaseEvent: OK");
 }
 
 
-void QG_GraphicView::mouseMoveEvent(QMouseEvent* e) {
-    //RS_DEBUG->print("QG_GraphicView::mouseMoveEvent begin");
-    //QMouseEvent rsm = QG_Qt2Rs::mouseEvent(e);
-
-    RS_GraphicView::mouseMoveEvent(e);
-    QWidget::mouseMoveEvent(e);
-
-#ifdef Q_OS_WIN32
-        // make sure that we can still use hotkeys and the mouse wheel
-        if (parent()) {
-                ((QWidget*)parent())->setFocus();
-        }
-#endif
-
-    //RS_DEBUG->print("QG_GraphicView::mouseMoveEvent end");
+void QG_GraphicView::mouseMoveEvent(QMouseEvent* event)
+{
+    event->accept();
+    eventHandler->mouseMoveEvent(event);
 }
 
-bool QG_GraphicView::event(QEvent *event) {
+bool QG_GraphicView::event(QEvent *event)
+{
 #if QT_VERSION >= 0x050200
     if (event->type() == QEvent::NativeGesture) {
         QNativeGestureEvent *nge = static_cast<QNativeGestureEvent *>(event);
@@ -365,9 +371,9 @@ bool QG_GraphicView::event(QEvent *event) {
 
             // It seems the NativeGestureEvent::pos() incorrectly reports global coordinates
             QPoint g = mapFromGlobal(nge->globalPos());
-            RS_Vector mouse = toGraph(RS_Vector(g.x(), g.y()));
+            RS_Vector mouse = toGraph(g.x(), g.y());
             setCurrentAction(new RS_ActionZoomIn(*container, *this, direction,
-                                                 RS2::Both, mouse, factor));
+												 RS2::Both, &mouse, factor));
         }
 
         return true;
@@ -446,13 +452,13 @@ void QG_GraphicView::tabletEvent(QTabletEvent* e) {
 }
 
 void QG_GraphicView::leaveEvent(QEvent* e) {
-    RS_GraphicView::mouseLeaveEvent();
+    eventHandler->mouseLeaveEvent();
     QWidget::leaveEvent(e);
 }
 
 
 void QG_GraphicView::enterEvent(QEvent* e) {
-    RS_GraphicView::mouseEnterEvent();
+    eventHandler->mouseEnterEvent();
     QWidget::enterEvent(e);
 }
 
@@ -463,7 +469,7 @@ void QG_GraphicView::focusOutEvent(QFocusEvent* e) {
 
 
 void QG_GraphicView::focusInEvent(QFocusEvent* e) {
-    RS_GraphicView::mouseEnterEvent();
+    eventHandler->mouseEnterEvent();
     QWidget::focusInEvent(e);
 }
 
@@ -482,47 +488,53 @@ void QG_GraphicView::wheelEvent(QWheelEvent *e) {
         return;
     }
 
-    RS_Vector mouse = toGraph(RS_Vector(e->x(), e->y()));
+    RS_Vector mouse = toGraph(e->x(), e->y());
 
-#if QT_VERSION >= 0x050200
-    QPoint numPixels = e->pixelDelta();
+    #if QT_VERSION >= 0x050200
 
-    // high-resolution scrolling triggers Pan instead of Zoom logic
-    isSmoothScrolling |= !numPixels.isNull();
+        if (options && options->device == "Trackpad")
+        {
+            QPoint numPixels = e->pixelDelta();
 
-    if (isSmoothScrolling) {
-        if (e->phase() == Qt::ScrollEnd) isSmoothScrolling = false;
+            // high-resolution scrolling triggers Pan instead of Zoom logic
+            isSmoothScrolling |= !numPixels.isNull();
 
-        if (!numPixels.isNull()) {
-            if (e->modifiers()==Qt::ControlModifier) {
-                // Hold ctrl to zoom. 1 % per pixel
-                double v = -numPixels.y() / 100.;
-                RS2::ZoomDirection direction;
-                double factor;
+            if (isSmoothScrolling)
+            {
+                if (e->phase() == Qt::ScrollEnd) isSmoothScrolling = false;
 
-                if (v < 0) {
-                    direction = RS2::Out; factor = 1-v;
-                } else {
-                    direction = RS2::In;  factor = 1+v;
+                if (!numPixels.isNull())
+                {
+                    if (e->modifiers()==Qt::ControlModifier)
+                    {
+                        // Hold ctrl to zoom. 1 % per pixel
+                        double v = -numPixels.y() / 100.;
+                        RS2::ZoomDirection direction;
+                        double factor;
+
+                        if (v < 0) {
+                            direction = RS2::Out; factor = 1-v;
+                        } else {
+                            direction = RS2::In;  factor = 1+v;
+                        }
+
+                        setCurrentAction(new RS_ActionZoomIn(*container, *this, direction,
+                                                             RS2::Both, &mouse, factor));
+                    }
+                    else if (scrollbars)
+                    {
+                        // otherwise, scroll
+                        //scroll by scrollbars: issue #479
+                        hScrollBar->setValue(hScrollBar->value() - numPixels.x());
+                        vScrollBar->setValue(vScrollBar->value() - numPixels.y());
+                    }
+                    redraw();
                 }
-
-                setCurrentAction(new RS_ActionZoomIn(*container, *this, direction,
-                                                     RS2::Both, mouse, factor));
-            } else {
-                // otherwise, scroll
-				//scroll by scrollbars: issue #479
-				hScrollBar->setValue(hScrollBar->value() - numPixels.x());
-				vScrollBar->setValue(vScrollBar->value() - numPixels.y());
-
-//                setCurrentAction(new RS_ActionZoomScroll(numPixels.x(), numPixels.y(),
-//                                                         *container, *this));
+                e->accept();
+                return;
             }
-            redraw();
         }
-        e->accept();
-        return;
-    }
-#endif
+    #endif
 
     if (e->delta() == 0) {
         // A zero delta event occurs when smooth scrolling is ended. Ignore this
@@ -559,7 +571,7 @@ void QG_GraphicView::wheelEvent(QWheelEvent *e) {
         }
     }
 
-    if (scroll) {
+    if (scroll && scrollbars) {
 		//scroll by scrollbars: issue #479
 		switch(direction){
 		case RS2::Left:
@@ -576,29 +588,70 @@ void QG_GraphicView::wheelEvent(QWheelEvent *e) {
 
     // zoom in / out:
     else if (e->modifiers()==0) {
-        if (e->delta()>0) {
-            setCurrentAction(new RS_ActionZoomIn(*container, *this,
-                                                 RS2::In, RS2::Both,
-                                                                                                 mouse));
-        } else {
-            setCurrentAction(new RS_ActionZoomIn(*container, *this,
-                                                 RS2::Out, RS2::Both,
-                                                                                                 mouse));
-        }
-    }
 
-        redraw();
+        /*
+         * The zoomFactor effects how quickly the scroll wheel will zoom in & out.
+         *
+         * Benchmarks:
+         * 1.250 - the original; fast & usable, but seems a choppy & a bit 'jarring'
+         * 1.175 - still a bit choppy
+         * 1.150 - smoother than the original, but still 'quick' enough for good navigation.
+         * 1.137 - seems to work well for me
+         * 1.125 - about the lowest that would be acceptable and useful, a tad on the slow side for me
+         * 1.100 - a very slow & deliberate zooming, but feels very "cautious", "controlled", "safe", and "precise".
+         * 1.000 - goes nowhere. :)
+         */
+		const double zoomFactor=1.137;
+
+		RS_Vector mainViewCenter = toGraph(getWidth()/2, getHeight()/2);
+
+		if (e->delta()>0) {
+			const double zoomInOvershoot=1.20;
+
+			RS_Vector effect{mouse};
+			{
+				effect-=mainViewCenter;
+				effect.scale(zoomInOvershoot);
+				effect+=mainViewCenter;
+			}
+
+			setCurrentAction(new RS_ActionZoomIn(*container, *this,
+												 RS2::In, RS2::Both,
+												 &effect,
+												 zoomFactor
+												));
+		} else {
+			const double zoomOutUndershoot=0.30;
+
+			RS_Vector effect{mouse};
+			{
+				effect-=mainViewCenter;
+				effect.scale(zoomOutUndershoot);
+				effect+=mainViewCenter;
+			}
+
+			setCurrentAction(new RS_ActionZoomIn(*container, *this,
+												 RS2::Out, RS2::Both,
+												 &effect,
+												 zoomFactor
+												));
+		}
+    }
+    redraw();
+
+    QMouseEvent* event = new QMouseEvent(QEvent::MouseMove,
+                                         QPoint(e->x(), e->y()),
+                                         Qt::NoButton, Qt::NoButton,
+                                         Qt::NoModifier);
+    eventHandler->mouseMoveEvent(event);
+    delete event;
 
     e->accept();
 }
 
 
-void QG_GraphicView::keyPressEvent(QKeyEvent* e) {
-    //if (e->key()==Qt::Key_Control) {
-    //	setCtrlPressed(true);
-    //}
-
-
+void QG_GraphicView::keyPressEvent(QKeyEvent* e)
+{
     if (container==NULL) {
         return;
     }
@@ -632,16 +685,13 @@ void QG_GraphicView::keyPressEvent(QKeyEvent* e) {
         setCurrentAction(new RS_ActionZoomScroll(direction,
                          *container, *this));
     }
-
-    RS_GraphicView::keyPressEvent(e);
+    eventHandler->keyPressEvent(e);
 }
 
 
-void QG_GraphicView::keyReleaseEvent(QKeyEvent* e) {
-    //if (e->key()==Qt::Key_Control) {
-    //	setCtrlPressed(false);
-    //}
-    RS_GraphicView::keyReleaseEvent(e);
+void QG_GraphicView::keyReleaseEvent(QKeyEvent* e)
+{
+    eventHandler->keyReleaseEvent(e);
 }
 
 
@@ -649,7 +699,10 @@ void QG_GraphicView::keyReleaseEvent(QKeyEvent* e) {
  * Called whenever the graphic view has changed.
  * Adjusts the scrollbar ranges / steps.
  */
-void QG_GraphicView::adjustOffsetControls() {
+void QG_GraphicView::adjustOffsetControls()
+{
+    if (scrollbars)
+    {
         static bool running = false;
 
         if (running) {
@@ -658,74 +711,72 @@ void QG_GraphicView::adjustOffsetControls() {
 
         running = true;
 
-    RS_DEBUG->print("QG_GraphicView::adjustOffsetControls() begin");
+        if (container==NULL || hScrollBar==NULL || vScrollBar==NULL) {
+            return;
+        }
 
-    if (container==NULL || hScrollBar==NULL || vScrollBar==NULL) {
-        return;
-    }
+        int ox = getOffsetX();
+        int oy = getOffsetY();
 
-    int ox = getOffsetX();
-    int oy = getOffsetY();
+        RS_Vector min = container->getMin();
+        RS_Vector max = container->getMax();
 
-    RS_Vector min = container->getMin();
-    RS_Vector max = container->getMax();
-
-    // no drawing yet - still allow to scroll
-    if (max.x < min.x+1.0e-6 ||
-            max.y < min.y+1.0e-6 ||
-                max.x > RS_MAXDOUBLE ||
-                max.x < RS_MINDOUBLE ||
-                min.x > RS_MAXDOUBLE ||
-                min.x < RS_MINDOUBLE ||
-                max.y > RS_MAXDOUBLE ||
-                max.y < RS_MINDOUBLE ||
-                min.y > RS_MAXDOUBLE ||
-                min.y < RS_MINDOUBLE ) {
-        min = RS_Vector(-10,-10);
-        max = RS_Vector(100,100);
-	}
+        // no drawing yet - still allow to scroll
+        if (max.x < min.x+1.0e-6 ||
+                max.y < min.y+1.0e-6 ||
+                    max.x > RS_MAXDOUBLE ||
+                    max.x < RS_MINDOUBLE ||
+                    min.x > RS_MAXDOUBLE ||
+                    min.x < RS_MINDOUBLE ||
+                    max.y > RS_MAXDOUBLE ||
+                    max.y < RS_MINDOUBLE ||
+                    min.y > RS_MAXDOUBLE ||
+                    min.y < RS_MINDOUBLE ) {
+            min = RS_Vector(-10,-10);
+            max = RS_Vector(100,100);
+        }
 
 
-	int minVal = (int)(-ox-getWidth()*0.5
-					   - QG_SCROLLMARGIN - getBorderLeft());
-	int maxVal = (int)(-ox+getWidth()*0.5
-					   + QG_SCROLLMARGIN + getBorderRight());
+        int minVal = (int)(-ox-getWidth()*0.5
+                           - QG_SCROLLMARGIN - getBorderLeft());
+        int maxVal = (int)(-ox+getWidth()*0.5
+                           + QG_SCROLLMARGIN + getBorderRight());
 
-	if (minVal<=maxVal) {
-		hScrollBar->setRange(minVal, maxVal);
-	}
+        if (minVal<=maxVal) {
+            hScrollBar->setRange(minVal, maxVal);
+        }
 
-	minVal = (int)(oy-getHeight()*0.5
-				   - QG_SCROLLMARGIN - getBorderTop());
-	maxVal = (int)(oy+getHeight()*0.5
-				   +QG_SCROLLMARGIN + getBorderBottom());
+        minVal = (int)(oy-getHeight()*0.5
+                       - QG_SCROLLMARGIN - getBorderTop());
+        maxVal = (int)(oy+getHeight()*0.5
+                       +QG_SCROLLMARGIN + getBorderBottom());
 
-	if (minVal<=maxVal) {
-		vScrollBar->setRange(minVal, maxVal);
-	}
+        if (minVal<=maxVal) {
+            vScrollBar->setRange(minVal, maxVal);
+        }
 
-	hScrollBar->setPageStep(getWidth());
-	vScrollBar->setPageStep(getHeight());
+        hScrollBar->setPageStep(getWidth());
+        vScrollBar->setPageStep(getHeight());
 
-	hScrollBar->setValue(-ox);
-	vScrollBar->setValue(oy);
+        hScrollBar->setValue(-ox);
+        vScrollBar->setValue(oy);
 
 
-    slotHScrolled(-ox);
-    slotVScrolled(oy);
+        slotHScrolled(-ox);
+        slotVScrolled(oy);
 
 
-    RS_DEBUG->print("H min: %d / max: %d / step: %d / value: %d\n",
-                    hScrollBar->minimum(), hScrollBar->maximum(),
-                    hScrollBar->pageStep(), ox);
-//    DEBUG_HEADER
-    RS_DEBUG->print(/*RS_Debug::D_WARNING, */"V min: %d / max: %d / step: %d / value: %d\n",
-                    vScrollBar->minimum(), vScrollBar->maximum(),
-                    vScrollBar->pageStep(), oy);
+//        RS_DEBUG->print("H min: %d / max: %d / step: %d / value: %d\n",
+//                        hScrollBar->minimum(), hScrollBar->maximum(),
+//                        hScrollBar->pageStep(), ox);
+
+//        RS_DEBUG->print(/*RS_Debug::D_WARNING, */"V min: %d / max: %d / step: %d / value: %d\n",
+//                        vScrollBar->minimum(), vScrollBar->maximum(),
+//                        vScrollBar->pageStep(), oy);
 
-    RS_DEBUG->print("QG_GraphicView::adjustOffsetControls() end");
 
         running = false;
+    }
 }
 
 
@@ -769,7 +820,8 @@ void QG_GraphicView::slotVScrolled(int value) {
     //if (!running) {
     //running = true;
 //    DEBUG_HEADER
-	RS_DEBUG->print(/*RS_Debug::D_WARNING,*/ "%s %s(): set vertical offset from %d to %d\n", __FILE__, __func__, getOffsetY(), value);
+//	RS_DEBUG->print(/*RS_Debug::D_WARNING,*/ "%s %s(): set vertical offset from %d to %d\n",
+//                    __FILE__, __func__, getOffsetY(), value);
     if (vScrollBar->maximum()==vScrollBar->minimum()) {
         centerOffsetY();
     } else {
@@ -799,7 +851,7 @@ RS_Vector QG_GraphicView::getMousePosition() const
     //if cursor is not on widget, return the widget center position
     if(!rect().contains(vp))
         vp=QPoint(width()/2, height()/2);
-    return toGraph(RS_Vector(vp.x(), vp.y()));
+    return toGraph(vp.x(), vp.y());
 }
 
 void QG_GraphicView::getPixmapForView(std::unique_ptr<QPixmap>& pm)
@@ -841,11 +893,6 @@ void QG_GraphicView::layerActivated(RS_Layer *layer) {
  */
 void QG_GraphicView::paintEvent(QPaintEvent *)
 {
-    RS_DEBUG->print("QG_GraphicView::paintEvent begin");
-
-    RS_SETTINGS->beginGroup("/Appearance");
-    bool draftMode = (bool)RS_SETTINGS->readNumEntry("/DraftMode", 0);
-    RS_SETTINGS->endGroup();
 
     // Re-Create or get the layering pixmaps
     getPixmapForView(PixmapLayer1);
@@ -863,11 +910,16 @@ void QG_GraphicView::paintEvent(QPaintEvent *)
 
     if (redrawMethod & RS2::RedrawDrawing)
     {
+        view_rect = LC_Rect(toGraph(0, 0),
+                            toGraph(getWidth(), getHeight()));
         // DRaw layer 2
         PixmapLayer2->fill(Qt::transparent);
         RS_PainterQt painter2(PixmapLayer2.get());
+        if (antialiasing)
+        {
+            painter2.setRenderHint(QPainter::Antialiasing);
+        }
         painter2.setDrawingMode(drawingMode);
-        setDraftMode(draftMode);
         painter2.setDrawSelectedOnly(false);
         drawLayer2((RS_Painter*)&painter2);
         painter2.setDrawSelectedOnly(true);
@@ -879,6 +931,10 @@ void QG_GraphicView::paintEvent(QPaintEvent *)
     {
         PixmapLayer3->fill(Qt::transparent);
         RS_PainterQt painter3(PixmapLayer3.get());
+        if (antialiasing)
+        {
+            painter3.setRenderHint(QPainter::Antialiasing);
+        }
         drawLayer3((RS_Painter*)&painter3);
         painter3.end();
     }
@@ -891,6 +947,76 @@ void QG_GraphicView::paintEvent(QPaintEvent *)
     wPainter.end();
 
     redrawMethod=RS2::RedrawNone;
-    RS_DEBUG->print("QG_GraphicView::paintEvent end");
 }
 
+void QG_GraphicView::setAntialiasing(bool state)
+{
+	antialiasing = state;
+}
+
+void QG_GraphicView::addScrollbars()
+{
+    scrollbars = true;
+
+    hScrollBar = new QG_ScrollBar(Qt::Horizontal, this);
+    vScrollBar = new QG_ScrollBar(Qt::Vertical, this);
+    layout = new QGridLayout(this);
+
+    setOffset(50, 50);
+
+    layout->setMargin(0);
+    layout->setSpacing(0);
+    layout->setColumnStretch(0, 1);
+    layout->setColumnStretch(1, 0);
+    layout->setColumnStretch(2, 0);
+    layout->setRowStretch(0, 1);
+    layout->setRowStretch(1, 0);
+
+    hScrollBar->setSingleStep(50);
+    hScrollBar->setCursor(Qt::ArrowCursor);
+    layout->addWidget(hScrollBar, 1, 0);
+    connect(hScrollBar, SIGNAL(valueChanged(int)),
+            this, SLOT(slotHScrolled(int)));
+
+    vScrollBar->setSingleStep(50);
+    vScrollBar->setCursor(Qt::ArrowCursor);
+    layout->addWidget(vScrollBar, 0, 1);
+    connect(vScrollBar, SIGNAL(valueChanged(int)),
+            this, SLOT(slotVScrolled(int)));
+}
+
+bool QG_GraphicView::hasScrollbars()
+{
+    return scrollbars;
+}
+
+void QG_GraphicView::setCursorHiding(bool state)
+{
+    cursor_hiding = state;
+}
+
+void QG_GraphicView::setCurrentQAction(QAction* q_action)
+{
+    eventHandler->setQAction(q_action);
+
+    if (recent_actions.contains(q_action))
+    {
+        recent_actions.removeOne(q_action);
+    }
+    recent_actions.prepend(q_action);
+}
+
+void QG_GraphicView::destroyMenu(const QString& activator)
+{
+    if (menus.contains(activator))
+    {
+        auto menu = menus.take(activator);
+        delete menu;
+    }
+}
+
+void QG_GraphicView::setMenu(const QString& activator, QMenu* menu)
+{
+    destroyMenu(activator);
+    menus[activator] = menu;
+}
