@@ -359,12 +359,12 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="38"/>
         <source>Read PIC file</source>
-        <translation>Ανάγνωση αρχείου PIC</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="44"/>
         <source>import PIC file</source>
-        <translation>εισαγωγή αρχείου PIC</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -797,42 +797,42 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="67"/>
         <source>File...</source>
-        <translation>Αρχείο...</translation>
+        <translation type="unfinished">Αρχείο...</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="77"/>
         <source>Scale:</source>
-        <translation>Κλίμακα:</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="81"/>
         <source>Accept</source>
-        <translation>Αποδοχή</translation>
+        <translation type="unfinished">Αποδοχή</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="85"/>
         <source>Cancel</source>
-        <translation>Ακύρωση</translation>
+        <translation type="unfinished">Ακύρωση</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="113"/>
         <source>Select file</source>
-        <translation>Επιλογή αρχείου</translation>
+        <translation type="unfinished">Επιλογή αρχείου</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="121"/>
         <source>Scale Factor is empty or invalid</source>
-        <translation>Ο συντελεστής κλίμακας είναι άδειος ή μη έγκυρος</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="134"/>
         <source>The file %1 not exist</source>
-        <translation>Το αρχείο %1 δεν υπάρχει</translation>
+        <translation type="unfinished">Το αρχείο %1 δεν υπάρχει</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="139"/>
         <source>Can&apos;t open the file %1</source>
-        <translation>Δεν είναι δυνατό το άνοιγμα του αρχείου %1</translation>
+        <translation type="unfinished">Δεν είναι δυνατό το άνοιγμα του αρχείου %1</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="146"/>
@@ -862,12 +862,11 @@
         <location filename="../plotequation/plot.cpp" line="21"/>
         <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Plot plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Πρόσθετο σχεδιογράφησης</translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Draw</source>
-        <translation>Σχεδίαση</translation>
+        <translation type="obsolete">Σχεδίαση</translation>
     </message>
 </context>
 <context>
@@ -875,7 +874,7 @@
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="15"/>
         <source>Plot equation</source>
-        <translation type="unfinished"></translation>
+        <translation>Σχεδιογράφηση εξίσωσης</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="18"/>
@@ -884,7 +883,10 @@ If you don&apos;t want to use the parametric form, just leave out &quot;Equation
 You can use pi when you need the value of pi (i.e. (3*pi)).
 Use t or x in your equation as a variable/parameter.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Το συγκεκριμένο πρόσθετο επιτρέπει τη σχεδιογράφηση μαθηματικών εξισώσεων.
+Σε περίπτωση που δεν επιθυμείτε τη χρήση της παραμετρικής μορφής, απλά αγνοήστε το &quot;Εξίσωση 2&quot;.
+Μπορείτε να χρησιμοποιήσετε το pi σε περίπτωση που χρειάζεστε την τιμή του π (π.χ. (3*pi)).
+Χρησιμοποιήστε το t ή το x στην εξίσωσή σας ως μεταβλητή/παράμετρο.</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="22"/>
