@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fi_FI">
+<TS version="2.0" language="fi">
 <context>
     <name>AsciiFile</name>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="37"/>
         <location filename="../asciifile/asciifile.cpp" line="43"/>
         <source>Read ascii points</source>
-        <translation type="unfinished"></translation>
+        <translation>Lue ASCII-pisteet</translation>
     </message>
 </context>
 <context>
@@ -15,7 +15,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="40"/>
         <source>Import ESRI Shapefile</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tuo ESRI-Shapefile</translation>
     </message>
 </context>
 <context>
@@ -34,7 +34,7 @@
     <message>
         <location filename="../align/align.cpp" line="42"/>
         <source>first target point:</source>
-        <translation type="unfinished"></translation>
+        <translation>ensimmäinen kohdepiste:</translation>
     </message>
     <message>
         <location filename="../align/align.cpp" line="44"/>
@@ -44,7 +44,7 @@
     <message>
         <location filename="../align/align.cpp" line="46"/>
         <source>second target point:</source>
-        <translation type="unfinished"></translation>
+        <translation>toinen kohdepiste:</translation>
     </message>
 </context>
 <context>
@@ -78,7 +78,7 @@
     <message>
         <location filename="../list/list.cpp" line="73"/>
         <source>Layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Taso</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="75"/>
@@ -159,12 +159,12 @@
         <location filename="../list/list.cpp" line="135"/>
         <location filename="../list/list.cpp" line="199"/>
         <source>radius</source>
-        <translation type="unfinished"></translation>
+        <translation>säde</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="122"/>
         <source>initial angle</source>
-        <translation type="unfinished"></translation>
+        <translation>lähtökulma</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="123"/>
@@ -249,12 +249,12 @@
     <message>
         <location filename="../list/list.cpp" line="189"/>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="189"/>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Kyllä</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="190"/>
@@ -264,7 +264,7 @@
     <message>
         <location filename="../list/list.cpp" line="204"/>
         <source>IMAGE</source>
-        <translation type="unfinished"></translation>
+        <translation>KUVA</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="207"/>
@@ -342,7 +342,7 @@
         <location filename="../sample/sample.cpp" line="26"/>
         <location filename="../sample/sample.cpp" line="33"/>
         <source>Sample plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Esimerkkiliitännäinen</translation>
     </message>
 </context>
 <context>
@@ -350,12 +350,12 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="38"/>
         <source>Read PIC file</source>
-        <translation type="unfinished"></translation>
+        <translation>Lue PIC-tiedosto</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="44"/>
         <source>import PIC file</source>
-        <translation type="unfinished"></translation>
+        <translation>tuo PIC-tiedosto</translation>
     </message>
 </context>
 <context>
@@ -363,132 +363,132 @@
     <message>
         <location filename="../asciifile/asciifile.cpp" line="235"/>
         <source>Read ascii points</source>
-        <translation type="unfinished"></translation>
+        <translation>Lue ascii-pisteet</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="241"/>
         <source>File...</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiedosto...</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="248"/>
         <source>Format:</source>
-        <translation type="unfinished"></translation>
+        <translation>Muoto:</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="250"/>
         <source>Space Separator</source>
-        <translation type="unfinished"></translation>
+        <translation>Välilyöntierotin</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="250"/>
         <source>Tab Separator</source>
-        <translation type="unfinished"></translation>
+        <translation>Sarkainerotin</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="250"/>
         <source>Comma Separator</source>
-        <translation type="unfinished"></translation>
+        <translation>Pilkkuerotin</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="250"/>
         <source>Space in Columns</source>
-        <translation type="unfinished"></translation>
+        <translation>Välilyönti Sarakkeissa</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="250"/>
         <source>*.odb for Psion 2</source>
-        <translation type="unfinished"></translation>
+        <translation>*.odb Psion 2:lle</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="252"/>
         <source>Connect points</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistä pisteet</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="260"/>
         <source>2D Point</source>
-        <translation type="unfinished"></translation>
+        <translation>2D-piste</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="260"/>
         <source>Draw 2D Point</source>
-        <translation type="unfinished"></translation>
+        <translation>Piirrä 2D-piste</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="261"/>
         <source>3D Point</source>
-        <translation type="unfinished"></translation>
+        <translation>3D-piste</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="261"/>
         <source>Draw 3D Point</source>
-        <translation type="unfinished"></translation>
+        <translation>Piirrä 3D-piste</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="262"/>
         <source>Point Number</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistenumero</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="262"/>
         <source>Draw point number</source>
-        <translation type="unfinished"></translation>
+        <translation>Piirrä pistenumero</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="263"/>
         <source>Point Elevation</source>
-        <translation type="unfinished"></translation>
+        <translation>Pisteen Korkeus</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="263"/>
         <source>Draw point elevation</source>
-        <translation type="unfinished"></translation>
+        <translation>Piirrä pisteen korkeus</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="264"/>
         <source>Point Code</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistekoodi</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="264"/>
         <source>Draw point code</source>
-        <translation type="unfinished"></translation>
+        <translation>Piirrä pistekoodi</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="278"/>
         <source>Accept</source>
-        <translation type="unfinished"></translation>
+        <translation>Hyväksy</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="283"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="313"/>
         <source>Select file</source>
-        <translation type="unfinished"></translation>
+        <translation>Valitse tiedosto</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="320"/>
         <source>Point 2D layer is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Piste 2D, taso on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="323"/>
         <source>Point 3D layer is empty</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Piste 2D, taso on tyhjä {3D?}</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="326"/>
         <source>Point elevation layer is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistekorkeustaso on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="327"/>
         <source>Point elevation height is empty</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Pistekorkeuden korkeus on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="328"/>
@@ -498,42 +498,42 @@
     <message>
         <location filename="../asciifile/asciifile.cpp" line="331"/>
         <source>Point number layer is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistenumerotaso on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="332"/>
         <source>Point number height is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistenumerokorkeus on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="333"/>
         <source>Point number separation is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistenumeroerotus on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="336"/>
         <source>Point code layer is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistekooditaso on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="337"/>
         <source>Point code height is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistekoodikorkeus on tyhä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="338"/>
         <source>Point code separation is empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistekoodierotus on tyhjä</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="366"/>
         <source>The file %1 not exist</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiedostoa %1 ei löydy</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="371"/>
         <source>Can&apos;t open the file %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiedostoa %1 ei voida avata</translation>
     </message>
 </context>
 <context>
@@ -541,28 +541,28 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="59"/>
         <source>File...</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiedosto...</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="67"/>
         <source>File type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiedostotyyppi:</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="75"/>
         <source>Layer</source>
-        <translation type="unfinished"></translation>
+        <translation>Taso</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="56"/>
         <source>Import ESRI Shapefile</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tuo ESRI-Shapefile</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="68"/>
         <location filename="../importshp/importshp.cpp" line="266"/>
         <source>Unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>Tuntematon</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="76"/>
@@ -570,7 +570,7 @@
         <location filename="../importshp/importshp.cpp" line="102"/>
         <location filename="../importshp/importshp.cpp" line="115"/>
         <source>Current</source>
-        <translation type="unfinished"></translation>
+        <translation>Nykyinen</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="77"/>
@@ -578,7 +578,7 @@
         <location filename="../importshp/importshp.cpp" line="103"/>
         <location filename="../importshp/importshp.cpp" line="116"/>
         <source>From data:</source>
-        <translation type="unfinished"></translation>
+        <translation>Datasta:</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="88"/>
@@ -614,17 +614,17 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="141"/>
         <source>Accept</source>
-        <translation type="unfinished"></translation>
+        <translation>Hyväksy</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="142"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="167"/>
         <source>Select file</source>
-        <translation type="unfinished"></translation>
+        <translation>Valitse tiedosto</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="217"/>
@@ -634,7 +634,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="221"/>
         <source>3D Point</source>
-        <translation type="unfinished"></translation>
+        <translation>3D-piste</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="225"/>
@@ -664,7 +664,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="245"/>
         <source>3D Arc</source>
-        <translation type="unfinished"></translation>
+        <translation>3D-kaari</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="249"/>
@@ -694,7 +694,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="286"/>
         <source>The file %1 not exist</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tiedostoa %1 ei löydy</translation>
     </message>
 </context>
 <context>
@@ -735,12 +735,12 @@
     <message>
         <location filename="../sample/sample.cpp" line="86"/>
         <source>Accept</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Hyväksy</translation>
     </message>
     <message>
         <location filename="../sample/sample.cpp" line="91"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Peru</translation>
     </message>
     <message>
         <location filename="../sample/sample.cpp" line="107"/>
@@ -765,7 +765,7 @@
     <message>
         <location filename="../sample/sample.cpp" line="132"/>
         <source>Sample plugin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Esimerkkiliitännäinen</translation>
     </message>
 </context>
 <context>
@@ -773,7 +773,7 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="67"/>
         <source>File...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tiedosto...</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="77"/>
@@ -783,17 +783,17 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="81"/>
         <source>Accept</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Hyväksy</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="85"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Peru</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="113"/>
         <source>Select file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Valitse tiedosto</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="121"/>
@@ -803,12 +803,12 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="134"/>
         <source>The file %1 not exist</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tiedostoa %1 ei löydy</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="139"/>
         <source>Can&apos;t open the file %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tiedostoa %1 ei voida avata</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="146"/>
@@ -840,11 +840,6 @@
         <source>Plot plugin</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
-        <source>Draw</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>plotDialog</name>
@@ -895,7 +890,7 @@ Use t or x in your equation as a variable/parameter.
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="33"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Peru</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="59"/>
