@@ -24,7 +24,7 @@
         <location filename="../align/align.cpp" line="20"/>
         <location filename="../align/align.cpp" line="27"/>
         <source>Align</source>
-        <translation>Ali&amp;ñar</translation>
+        <translation>Aliñar</translation>
     </message>
     <message>
         <location filename="../align/align.cpp" line="40"/>
@@ -53,7 +53,7 @@
         <location filename="../list/list.cpp" line="23"/>
         <location filename="../list/list.cpp" line="30"/>
         <source>List entities</source>
-        <translation>Li&amp;stado de entidades</translation>
+        <translation>Listado de entidades</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="46"/>
@@ -130,7 +130,7 @@
         <location filename="../list/list.cpp" line="103"/>
         <location filename="../list/list.cpp" line="127"/>
         <source>length</source>
-        <translation>largura</translation>
+        <translation>lonxitude</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="108"/>
@@ -199,7 +199,7 @@
     <message>
         <location filename="../list/list.cpp" line="162"/>
         <source>CONSTRUCTIONLINE</source>
-        <translation>LIÑA DE CONSTRUCCIÓN</translation>
+        <translation>LIÑA DE CONSTRUCIÓN</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="165"/>
@@ -274,7 +274,7 @@
     <message>
         <location filename="../list/list.cpp" line="210"/>
         <source>SPLINEPOINTS</source>
-        <translation type="unfinished"></translation>
+        <translation>SPLINENODOS</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="213"/>
@@ -350,12 +350,12 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="38"/>
         <source>Read PIC file</source>
-        <translation type="unfinished"></translation>
+        <translation>Ler ficheiro PIC</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="44"/>
         <source>import PIC file</source>
-        <translation type="unfinished"></translation>
+        <translation>Importar ficheiro PIC</translation>
     </message>
 </context>
 <context>
@@ -773,63 +773,63 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="67"/>
         <source>File...</source>
-        <translation type="unfinished">Ficheiro...</translation>
+        <translation>Ficheiro...</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="77"/>
         <source>Scale:</source>
-        <translation type="unfinished"></translation>
+        <translation>Escala:</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="81"/>
         <source>Accept</source>
-        <translation type="unfinished">Aceptar</translation>
+        <translation>Aceptar</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="85"/>
         <source>Cancel</source>
-        <translation type="unfinished">Cancelar</translation>
+        <translation>Cancelar</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="113"/>
         <source>Select file</source>
-        <translation type="unfinished">Seleccionar ficheiro</translation>
+        <translation>Seleccionar ficheiro</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="121"/>
         <source>Scale Factor is empty or invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>Factor de Escala está baleiro ou non é válido</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="134"/>
         <source>The file %1 not exist</source>
-        <translation type="unfinished">O ficheiro %1 non existe</translation>
+        <translation>O ficheiro %1 non existe</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="139"/>
         <source>Can&apos;t open the file %1</source>
-        <translation type="unfinished">Non se pode abrir o ficheiro %1</translation>
+        <translation>Non se pode abrir o ficheiro %1</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="146"/>
         <source>%1 objects imported</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 obxectos importados</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="168"/>
         <source>picPunto drawLine: first point is empty %1</source>
-        <translation type="unfinished"></translation>
+        <translation>picPunto drawLine: o primeiro punto está baleiro %1</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="181"/>
         <source>picPunto drawLine: next point is empty %1</source>
-        <translation type="unfinished"></translation>
+        <translation>picPunto drawLine: o segundo punto está baleiro %1</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="260"/>
         <location filename="../picfile/picfile.cpp" line="269"/>
         <source>format error in %1</source>
-        <translation type="unfinished"></translation>
+        <translation>erro de formato en %1</translation>
     </message>
 </context>
 <context>
@@ -841,9 +841,8 @@
         <translation>Plugin de trazado</translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Draw</source>
-        <translation>Debuxar</translation>
+        <translation type="obsolete">Debuxar</translation>
     </message>
 </context>
 <context>
@@ -905,19 +904,19 @@ Use t ou x na súa ecuación como unha variable/parámetro.
         <location filename="../plotequation/plotdialog.cpp" line="59"/>
         <source>Line Segments</source>
         <comment>Plot Equation to generate RS_Line segments</comment>
-        <translation type="unfinished"></translation>
+        <translation>Segmentos de liña</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="60"/>
         <source>Polyline</source>
         <comment>Plot Equation to generate RS_Polyline</comment>
-        <translation type="unfinished"></translation>
+        <translation>Poliliña</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="61"/>
         <source>SplinePoints</source>
         <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
-        <translation type="unfinished"></translation>
+        <translation>Spline por Puntos</translation>
     </message>
 </context>
 <context>
