@@ -7,7 +7,7 @@
         <location filename="../asciifile/asciifile.cpp" line="37"/>
         <location filename="../asciifile/asciifile.cpp" line="43"/>
         <source>Read ascii points</source>
-        <translation>ascii ポイントを読む</translation>
+        <translation>asciiポイントを読む</translation>
     </message>
 </context>
 <context>
@@ -24,7 +24,7 @@
         <location filename="../align/align.cpp" line="20"/>
         <location filename="../align/align.cpp" line="27"/>
         <source>Align</source>
-        <translation>合わせる</translation>
+        <translation>整列</translation>
     </message>
     <message>
         <location filename="../align/align.cpp" line="40"/>
@@ -53,7 +53,7 @@
         <location filename="../list/list.cpp" line="23"/>
         <location filename="../list/list.cpp" line="30"/>
         <source>List entities</source>
-        <translation>要素一覧</translation>
+        <translation>要素の一覧</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="46"/>
@@ -114,7 +114,7 @@
     <message>
         <location filename="../list/list.cpp" line="90"/>
         <source>LINE</source>
-        <translation>線</translation>
+        <translation>直線</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="95"/>
@@ -130,7 +130,7 @@
         <location filename="../list/list.cpp" line="103"/>
         <location filename="../list/list.cpp" line="127"/>
         <source>length</source>
-        <translation>長さ３D </translation>
+        <translation>長さ</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="108"/>
@@ -244,7 +244,7 @@
     <message>
         <location filename="../list/list.cpp" line="188"/>
         <source>Closed</source>
-        <translation>閉じる</translation>
+        <translation>閉じている</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="189"/>
@@ -664,7 +664,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="245"/>
         <source>3D Arc</source>
-        <translation>3D 弧</translation>
+        <translation>弧</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="249"/>
@@ -818,12 +818,12 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="168"/>
         <source>picPunto drawLine: first point is empty %1</source>
-        <translation>picPunto 線を引く:最初のポイントが未記入 %1</translation>
+        <translation>picPunto 線を引く: 最初のポイントが未記入 %1</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="181"/>
         <source>picPunto drawLine: next point is empty %1</source>
-        <translation>picPunto 線を引く:次のポイントが未記入 %1</translation>
+        <translation>picPunto 線を引く: 次のポイントが未記入 %1</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="260"/>
@@ -841,9 +841,8 @@
         <translation>式を入力して書くためのプラグイン</translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Draw</source>
-        <translation>書く</translation>
+        <translation type="obsolete">書く</translation>
     </message>
 </context>
 <context>
