@@ -682,7 +682,7 @@
     </message>
     <message>
         <source>Draw</source>
-        <translation>Zīmēt</translation>
+        <translation type="obsolete">Zīmēt</translation>
     </message>
 </context>
 <context>
@@ -697,35 +697,39 @@ If you don&apos;t want to use the parametric form, just leave out &quot;Equation
 You can use pi when you need the value of pi (i.e. (3*pi)).
 Use t or x in your equation as a variable/parameter.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Šis spraudnis ļauj attēlot matemātiskos vienādojumus.
+Ja nevēlaties izmantot parametrisko formu, vienkārši izlaidiet “Vienādojums 2”.
+Varat izmanto “pi”, ja ir vajadzīga π vērtība (piemēram, 3*pi).
+Izmantojiet savos vienādojums t vai x kā mainīgos/parametrus.
+</translation>
     </message>
     <message>
         <source>Equation 1:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vienādojums 1:</translation>
     </message>
     <message>
         <source>Equation 2:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vienādojums 2:</translation>
     </message>
     <message>
         <source>start value:</source>
-        <translation type="unfinished"></translation>
+        <translation>sākuma vērtība:</translation>
     </message>
     <message>
         <source>end value:</source>
-        <translation type="unfinished"></translation>
+        <translation>beigu vērtība:</translation>
     </message>
     <message>
         <source>step size:</source>
-        <translation type="unfinished"></translation>
+        <translation>soļa vērtība:</translation>
     </message>
     <message>
         <source>Draw</source>
-        <translation type="unfinished">Zīmēt</translation>
+        <translation>Zīmēt</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished">Atcelt</translation>
+        <translation>Atcelt</translation>
     </message>
     <message>
         <source>Line Segments</source>
