@@ -368,7 +368,7 @@
     <message>
         <location filename="../asciifile/asciifile.cpp" line="241"/>
         <source>File...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Bestand</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="248"/>
@@ -541,7 +541,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="59"/>
         <source>File...</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestand</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="67"/>
@@ -689,7 +689,7 @@
     <message>
         <location filename="../importshp/importshp.cpp" line="281"/>
         <source>The file %1 not have extension .shp</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestand %1 heeft geen bestandstype .shp</translation>
     </message>
     <message>
         <location filename="../importshp/importshp.cpp" line="286"/>
@@ -773,7 +773,7 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="67"/>
         <source>File...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Bestand</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="77"/>
@@ -840,11 +840,6 @@
         <source>Plot plugin</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
-        <source>Draw</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>plotDialog</name>
