@@ -103,7 +103,7 @@
     <message>
         <location filename="../list/list.cpp" line="84"/>
         <source>POINT</source>
-        <translation>POINT</translation>
+        <translation>PONTO</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="85"/>
@@ -114,7 +114,7 @@
     <message>
         <location filename="../list/list.cpp" line="90"/>
         <source>LINE</source>
-        <translation>LINE</translation>
+        <translation>LINHA</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="95"/>
@@ -145,7 +145,7 @@
     <message>
         <location filename="../list/list.cpp" line="114"/>
         <source>ARC</source>
-        <translation>ARC</translation>
+        <translation>ARCO</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="115"/>
@@ -174,7 +174,7 @@
     <message>
         <location filename="../list/list.cpp" line="130"/>
         <source>CIRCLE</source>
-        <translation>CIRCLE</translation>
+        <translation>CÍRCULO</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="136"/>
@@ -189,7 +189,7 @@
     <message>
         <location filename="../list/list.cpp" line="140"/>
         <source>ELLIPSE</source>
-        <translation>ELLIPSE</translation>
+        <translation>ELIPSE</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="144"/>
@@ -199,7 +199,7 @@
     <message>
         <location filename="../list/list.cpp" line="162"/>
         <source>CONSTRUCTIONLINE</source>
-        <translation>CONSTRUCTIONLINE</translation>
+        <translation>CONSTRUÇÃO DE LINHA</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="165"/>
@@ -209,7 +209,7 @@
     <message>
         <location filename="../list/list.cpp" line="168"/>
         <source>SOLID</source>
-        <translation>SOLID</translation>
+        <translation>SÓLIDO</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="172"/>
@@ -219,12 +219,12 @@
     <message>
         <location filename="../list/list.cpp" line="175"/>
         <source>TEXT</source>
-        <translation>TEXT</translation>
+        <translation>TEXTO</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="178"/>
         <source>INSERT</source>
-        <translation>INSERT</translation>
+        <translation>INSERIR</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="181"/>
@@ -239,7 +239,7 @@
     <message>
         <location filename="../list/list.cpp" line="187"/>
         <source>POLYLINE</source>
-        <translation>POLYLINE</translation>
+        <translation>POLILINHA</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="188"/>
@@ -268,22 +268,22 @@
     <message>
         <location filename="../list/list.cpp" line="204"/>
         <source>IMAGE</source>
-        <translation>IMAGE</translation>
+        <translation>IMAGEM</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="207"/>
         <source>SPLINE</source>
-        <translation>SPLINE</translation>
+        <translation>LINHA SUAVE</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="210"/>
         <source>SPLINEPOINTS</source>
-        <translation type="unfinished"></translation>
+        <translation>PONTOS DA LINHA SUAVE</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="213"/>
         <source>HATCH</source>
-        <translation>HATCH</translation>
+        <translation>HACHURA</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="216"/>
@@ -318,7 +318,7 @@
     <message>
         <location filename="../list/list.cpp" line="234"/>
         <source>UNKNOWN</source>
-        <translation>UNKNOWN</translation>
+        <translation>DESCONHECIDO</translation>
     </message>
 </context>
 <context>
@@ -354,12 +354,12 @@
     <message>
         <location filename="../picfile/picfile.cpp" line="38"/>
         <source>Read PIC file</source>
-        <translation type="unfinished"></translation>
+        <translation>Ler arquivo PIC</translation>
     </message>
     <message>
         <location filename="../picfile/picfile.cpp" line="44"/>
         <source>import PIC file</source>
-        <translation type="unfinished"></translation>
+        <translation>importar arquivo PIC</translation>
     </message>
 </context>
 <context>
@@ -402,7 +402,7 @@
     <message>
         <location filename="../asciifile/asciifile.cpp" line="250"/>
         <source>*.odb for Psion 2</source>
-        <translation>*. odb para Psion 2</translation>
+        <translation>*.odb para Psion 2</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="252"/>
@@ -857,9 +857,8 @@
         <translation>Plugin gráfico</translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Draw</source>
-        <translation>desenho</translation>
+        <translation type="obsolete">desenho</translation>
     </message>
 </context>
 <context>
